@@ -5,6 +5,7 @@
 
 #include "math/Vector2.h"
 #include "math/Vector3.h"
+#include "math/Matrix3.h"
 #include "math/Matrix4.h"
 #include <vector>
 
@@ -105,6 +106,8 @@ struct ShiftScaleRotation
     }
 };
 
+class IBrush;
+
 // Interface for a face plane
 class IFace
 {
@@ -112,6 +115,9 @@ public:
 	// Destructor
 	virtual ~IFace() {}
 
+    // Returns a reference to the brush containing this face
+    virtual IBrush& getBrush() = 0;
+
 	// Submits the current state to the UndoSystem, to make further actions undo-able
 	virtual void undoSave() = 0;
 
@@ -136,6 +142,13 @@ public:
 	// Rotates the texture by the given angle
 	virtual void rotateTexdef(float angle) = 0;
 
+    // Returns the amount of texture pixels per game unit shown on this face
+    // This is based on the image returned by the material, usually the editor image
+    virtual Vector2 getTexelScale() const = 0;
+
+    // Returns the texture aspect ratio width/height
+    virtual float getTextureAspectRatio() const = 0;
+
 	// Fits the texture on this face
 	virtual void fitTexture(float s_repeat, float t_repeat) = 0;
 
@@ -156,6 +169,12 @@ public:
 	// If possible, aligns the assigned texture at the given anchor edge
 	virtual void alignTexture(AlignEdge alignType) = 0;
 
+    // Reverts any transform that has been applied since the last time freezeTransform() was called
+    virtual void revertTransform() = 0;
+
+    // Promotes the current transformed state to the new base state
+    virtual void freezeTransform() = 0;
+
 	// Get access to the actual Winding object
 	virtual IWinding& getWinding() = 0;
 	virtual const IWinding& getWinding() const = 0;
@@ -163,30 +182,33 @@ public:
 	virtual const Plane3& getPlane3() const = 0;
 
 	/**
-	 * Returns the 3x3 texture matrix for this face, containing shift, scale and rotation.
-	 *
-	 * xx, yx, xy and yy hold the scale and rotation
-	 * tx and ty hold the shift
+	 * The matrix used to project world coordinates to U/V space, after the winding vertices
+     * have been transformed to this face's axis base system.
+     * The components of this matrix correspond to the matrix values written to the idTech4 
+     * brushDef3 face definition (with <zx, zy> holding the translation part):
+     * e.g. ( plane ) ( ( xx yx zx ) ( yx yy zy ) ) "textures/path/to/material" 0 0 0
 	 */
-	virtual Matrix4 getTexDefMatrix() const = 0;
+	virtual Matrix3 getProjectionMatrix() const = 0;
 
-	/**
-	 * The matrix used to project world coordinates to U/V space.
-	 */
-	virtual Matrix4 getProjectionMatrix() = 0;
+	virtual void setProjectionMatrix(const Matrix3& projection) = 0;
 
-	virtual void setProjectionMatrix(const Matrix4& projection) = 0;
+    // Constructs the texture projection matrix from the given (world) vertex and texture coords.
+    // Three vertices and their UV coordinates are enough to construct the texdef.
+    virtual void setTexDefFromPoints(const Vector3 points[3], const Vector2 uvs[3]) = 0;
 
 	/**
 	 * Calculates and returns the texture definition as shift/scale/rotate.
 	 * This is not what is actually saved to the .map file, but it makes
 	 * texture manipulations in the Surface Inspector much more human-readable.
 	 */
-	virtual ShiftScaleRotation getShiftScaleRotation() = 0;
+	virtual ShiftScaleRotation getShiftScaleRotation() const = 0;
 	virtual void setShiftScaleRotation(const ShiftScaleRotation& scr) = 0;
 
     // Transforms this face plane with the given transformation matrix
     virtual void transform(const Matrix4& transformation) = 0;
+
+    // Emitted from this IFace's destructor, as last sign of life
+    virtual sigc::signal<void>& signal_faceDestroyed() = 0;
 };
 
 // Plane classification info used by splitting and CSG algorithms
@@ -228,8 +250,8 @@ public:
 	// Add a new face to this brush, using the given plane object, returns a reference to the new face
 	virtual IFace& addFace(const Plane3& plane) = 0;
 
-	// Add a new face to this brush, using the given plane, texdef matrix and shader name
-	virtual IFace& addFace(const Plane3& plane, const Matrix4& texDef, const std::string& shader) = 0;
+	// Add a new face to this brush, using the given plane, projection matrix and material name
+	virtual IFace& addFace(const Plane3& plane, const Matrix3& textureProjection, const std::string& material) = 0;
 
     // Removes all faces from this brush
     virtual void clear() = 0;
