@@ -3,8 +3,7 @@
 #include "igl.h"
 #include "imodule.h"
 #include "ishaders.h"
-
-#include "ShaderLayer.h"
+#include "ishaderlayer.h"
 
 #include "math/Vector4.h"
 
@@ -37,10 +36,13 @@ public:
         SORT_INTERACTION = 2,       // used by the DBS pass
         SORT_FULLBRIGHT = 1025,     // used by non-translucent editor passes
         SORT_TRANSLUCENT = 1026,    // used by blend-type editor passes
-        SORT_HIGHLIGHT = 1027,      // used by the (red) selection system overlay
         SORT_OVERLAY_FIRST = 1028,  // used by decals
+        SORT_OVERLAY_SECOND = 1029,  // used by merge actions
+        SORT_OVERLAY_THIRD = 1030,   // used by merge actions
+        SORT_OVERLAY_ONE_BEFORE_LAST = 2046, // used by merge actions
         SORT_OVERLAY_LAST = 2047,
-        SORT_POINT_FIRST = 2048,    // used by POINT renderers
+        SORT_HIGHLIGHT = 2048,      // used by the (red) selection system overlay
+        SORT_POINT_FIRST = 2049,    // used by POINT renderers
         SORT_POINT_LAST = 3071,
         SORT_GUI0 = 3072,           // used by selection system controls, pivots (visible)
         SORT_GUI1 = 3073,           // used by selection system controls, pivots (obscured)
@@ -173,11 +175,11 @@ public:
      * which hold the actual values of many parameters, some of them
      * time-dependent or depending on entity parameters.
      */
-    ShaderLayerPtr stage0;
-    ShaderLayerPtr stage1;
-    ShaderLayerPtr stage2;
-    ShaderLayerPtr stage3;
-    ShaderLayerPtr stage4;
+    IShaderLayer::Ptr stage0;
+    IShaderLayer::Ptr stage1;
+    IShaderLayer::Ptr stage2;
+    IShaderLayer::Ptr stage3;
+    IShaderLayer::Ptr stage4;
 
     /**
      * \brief
@@ -212,7 +214,7 @@ public:
      * \brief
      * The cube-map texgen mode for rendering.
      */
-    ShaderLayer::CubeMapMode cubeMapMode;
+    IShaderLayer::CubeMapMode cubeMapMode;
 
     /// Default constructor
     OpenGLState()
@@ -236,6 +238,6 @@ public:
       m_linestipple_factor(1),
       m_linestipple_pattern(0xAAAA),
       glProgram(NULL),
-      cubeMapMode(ShaderLayer::CUBE_MAP_NONE)
+      cubeMapMode(IShaderLayer::CUBE_MAP_NONE)
     { }
 };
