@@ -45,11 +45,17 @@ public:
         GameConfigNeeded,
         LongRunningOperation,
         MapFileOperation,
+        MapOperationFinished,
         FileSelectionRequest,
         Notification,
         TextureChanged,
         ApplicationIsActiveQuery,
         FileOverwriteConfirmation,
+        FileSaveConfirmation,
+        UnselectSelectionRequest,
+        ManipulatorModeToggleRequest,
+        ComponentSelectionModeToggleRequest,
+        GridSnapRequest,
 
         UserDefinedMessagesGoHigherThanThis = 999,
     };
