@@ -143,6 +143,9 @@ public:
 	// greebo: returns true if the patch's shader is visible, false otherwise
 	virtual bool hasVisibleMaterial() const = 0;
 
+    // Returns the texture aspect ratio width/height
+    virtual float getTextureAspectRatio() const = 0;
+
 	/**
 	 * greebo: Sets/gets whether this patch is a patchDef3 (fixed tesselation)
 	 */
@@ -211,6 +214,22 @@ public:
 
 	// Alligns the assigned texture at the given edge (if possible)
 	virtual void alignTexture(AlignEdge type) = 0;
+
+    // Reverts any transform that has been applied since the last time freezeTransform() was called
+    virtual void revertTransform() = 0;
+
+    // Returns the transformable control point (not the one returned by ctrlAt) - this one is
+    // part of the "transformed" working set of the patch which will either be saved on freezeTransform()
+    // or discarded on revertTransform().
+    virtual PatchControl& getTransformedCtrlAt(std::size_t row, std::size_t col) = 0;
+
+    // Promotes the current transformed state to the new base state
+    virtual void freezeTransform() = 0;
+
+    // Updates the patch tesselation based on the transformed set of control vertices
+    // Setting force to true will update the tesselation even if controlPointsChanged() 
+    // hasn't been called in the meantime.
+    virtual void updateTesselation(bool force = false) = 0;
 };
 
 namespace patch
