@@ -214,7 +214,7 @@ typedef std::shared_ptr<RendererLight> RendererLightPtr;
 /// Debug stream insertion for RendererLight
 inline std::ostream& operator<< (std::ostream& os, const RendererLight& l)
 {
-    return os << "RendererLight(origin=" << l.getLightOrigin().pp()
+    return os << "RendererLight(origin=" << math::pp(l.getLightOrigin())
               << ", lightAABB=" << l.lightAABB() << ")";
 }
 
