@@ -18,12 +18,8 @@
 #include "icounter.h"
 #include "icurve.h"
 #include "idatastream.h"
-#include "idialogmanager.h"
 #include "ieclass.h"
 #include "ientity.h"
-#include "ientityinspector.h"
-#include "ieventmanager.h"
-#include "ifilechooser.h"
 #include "ifilesystem.h"
 #include "ifiletypes.h"
 #include "ifilter.h"
@@ -33,22 +29,17 @@
 #include "iglprogram.h"
 #include "iglrender.h"
 #include "igrid.h"
-#include "igroupdialog.h"
 #include "igroupnode.h"
 #include "iimage.h"
 #include "iinteractiveview.h"
 #include "ilayer.h"
 #include "ilightnode.h"
-#include "imainframe.h"
-#include "imainframelayout.h"
 #include "imap.h"
 #include "imapformat.h"
 #include "imapinfofile.h"
 #include "imapresource.h"
 #include "imd5anim.h"
 #include "imd5model.h"
-#include "imediabrowser.h"
-#include "imenu.h"
 #include "imessagebus.h"
 #include "imodel.h"
 #include "imodelcache.h"
@@ -60,7 +51,6 @@
 #include "inameobserver.h"
 #include "inamespace.h"
 #include "inode.h"
-#include "iorthocontextmenu.h"
 #include "iorthoview.h"
 #include "iparticlenode.h"
 #include "iparticles.h"
@@ -73,7 +63,6 @@
 #include "irender.h"
 #include "irenderable.h"
 #include "irendersystemfactory.h"
-#include "iresourcechooser.h"
 #include "iscenegraph.h"
 #include "iscenegraphfactory.h"
 #include "iselectable.h"
@@ -92,7 +81,7 @@
 #include "itransformnode.h"
 #include "iundo.h"
 #include "ivolumetest.h"
-#include "mapfile.h"
+#include "imapfilechangetracker.h"
 #include "modelskin.h"
 #include "ModResource.h"
 #include "ishaderlayer.h"
