@@ -91,8 +91,32 @@ class Walker(dr.SelectionVisitor) :
 visitor = Walker()
 GlobalSelectionSystem.foreachSelected(visitor)
 
+# Visit every selected face
+class FaceVisitor(dr.SelectedFaceVisitor) :
+	def visitFace(self, face):
+		print(face.getShader())
+
+visitor = FaceVisitor()
+GlobalSelectionSystem.foreachSelectedFace(visitor)
+
 print('Map name is ' + GlobalMap.getMapName())
 
+print(GlobalMap.getEditMode())
+
+# Switching Map Modes
+GlobalMap.setEditMode(MapEditMode.Merge)
+GlobalMap.setEditMode(MapEditMode.Normal)
+
+# Point File Management is visible
+print(GlobalMap.showPointFile("test.lin"))
+print(GlobalMap.isPointTraceVisible())
+
+# Enumerate the point files available for the current map
+print("Point files found: " + str(len(GlobalMap.getPointFileList())))
+
+for path in GlobalMap.getPointFileList:
+	print("Pointfile: " + path)
+
 # Try to find the map's worldspawn
 worldspawn = GlobalMap.getWorldSpawn()
 
@@ -153,19 +177,19 @@ print(filecontents)
 print('Current grid size = ' + str(GlobalGrid.getGridSize()))
 
 # Test the ShaderSystem interface
-class TestShaderVisitor(dr.ShaderVisitor) :
+class TestMaterialVisitor(dr.MaterialVisitor) :
 	def visit(self, shader):
 		if not shader.isNull():
 			print('Found shader: ' + shader.getName() + ' defined in ' + shader.getShaderFileName())
 
 # Disabled code, takes very long in TDM
-# shadervisitor = TestShaderVisitor()
-# GlobalMaterialManager.foreachShader(shadervisitor)
+# materialVisitor = TestMaterialVisitor()
+# GlobalMaterialManager.foreachMaterial(materialVisitor)
 
-shader = GlobalMaterialManager.getMaterialForName('bc_rat')
+material = GlobalMaterialManager.getMaterialForName('bc_rat')
 
-if not shader.isNull():
-	print('Shader ' + shader.getName() + ' is defined in ' + shader.getShaderFileName())
+if not material.isNull():
+	print('Material ' + material.getName() + ' is defined in ' + material.getShaderFileName())
 
 # Test finding a model
 class ModelFinder(dr.SceneNodeVisitor) :
