@@ -29,14 +29,24 @@ public:
 	  colour(1.0, 1.0, 1.0)
 	{}
 
-	/// Initialising constructor.
-	ArbitraryMeshVertex(const Vertex3f& v, const Normal3f& n, const TexCoord2f& t)
-    : texcoord(t),
-      normal(n),
-      vertex(v),
-      tangent(0, 0, 0),
-      bitangent(0, 0, 0),
-      colour(1.0, 1.0, 1.0)
+	/// Initialising constructor, leaves colour at 1,1,1 and tangent vectors at 0,0,0
+	ArbitraryMeshVertex(const Vertex3f& v, const Normal3f& n, const TexCoord2f& t) : 
+        texcoord(t),
+        normal(n),
+        vertex(v),
+        tangent(0, 0, 0),
+        bitangent(0, 0, 0),
+        colour(1.0, 1.0, 1.0)
+    {}
+
+	/// Initialising constructor, leaves tangent vectors at 0,0,0
+    ArbitraryMeshVertex(const Vertex3f& v, const Normal3f& n, const TexCoord2f& t, const Vector3& c) : 
+        texcoord(t),
+        normal(n),
+        vertex(v),
+        tangent(0, 0, 0),
+        bitangent(0, 0, 0),
+        colour(c)
     {}
 
     /// Cast to simple Vertex3f, throwing away other components
@@ -138,7 +148,7 @@ inline std::ostream& operator<< (std::ostream& os, const ArbitraryMeshVertex& v)
 {
 	os << "ArbitraryMeshVertex { "
 	   << " vertex = " << v.vertex << ", normal = " << v.normal
-	   << ", texcoord = " << v.texcoord
+	   << ", texcoord = " << v.texcoord << ", colour = " << v.colour
 	   << " }";
 
 	return os;
@@ -158,7 +168,7 @@ inline void ArbitraryMeshTriangle_calcTangents(const ArbitraryMeshVertex& a,
 		bVec.set(b.vertex.x(), b.texcoord.s(), b.texcoord.t());
 		cVec.set(c.vertex.x(), c.texcoord.s(), c.texcoord.t());
 
-		Vector3 cross( (bVec-aVec).crossProduct(cVec-aVec) );
+		Vector3 cross( (bVec-aVec).cross(cVec-aVec) );
 
 		if(fabs(cross.x()) > 0.000001f) {
 			s.x() = -cross.y() / cross.x();
@@ -174,7 +184,7 @@ inline void ArbitraryMeshTriangle_calcTangents(const ArbitraryMeshVertex& a,
 		bVec.set(b.vertex.y(), b.texcoord.s(), b.texcoord.t());
 		cVec.set(c.vertex.y(), c.texcoord.s(), c.texcoord.t());
 
-		Vector3 cross( (bVec-aVec).crossProduct(cVec-aVec));
+		Vector3 cross( (bVec-aVec).cross(cVec-aVec));
 
 		if(fabs(cross.x()) > 0.000001f) {
 			s.y() = -cross.y() / cross.x();
@@ -190,7 +200,7 @@ inline void ArbitraryMeshTriangle_calcTangents(const ArbitraryMeshVertex& a,
 		bVec.set(b.vertex.z(), b.texcoord.s(), b.texcoord.t());
 		cVec.set(c.vertex.z(), c.texcoord.s(), c.texcoord.t());
 
-		Vector3 cross( (bVec-aVec).crossProduct(cVec-aVec));
+		Vector3 cross( (bVec-aVec).cross(cVec-aVec));
 
 		if(fabs(cross.x()) > 0.000001f) {
 			s.z() = -cross.y() / cross.x();
