@@ -276,21 +276,23 @@ void Node::onChildRemoved(const INodePtr& child)
 void Node::onInsertIntoScene(IMapRootNode& root)
 {
 	_instantiated = true;
+    connectUndoSystem(root.getUndoSystem());
 }
 
 void Node::onRemoveFromScene(IMapRootNode& root)
 {
+    disconnectUndoSystem(root.getUndoSystem());
 	_instantiated = false;
 }
 
-void Node::connectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Node::connectUndoSystem(IUndoSystem& undoSystem)
 {
-    _children.connectUndoSystem(changeTracker);
+    _children.connectUndoSystem(undoSystem);
 }
 
-void Node::disconnectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Node::disconnectUndoSystem(IUndoSystem& undoSystem)
 {
-    _children.disconnectUndoSystem(changeTracker);
+    _children.disconnectUndoSystem(undoSystem);
 }
 
 TraversableNodeSet& Node::getTraversable() {
