@@ -1,23 +1,3 @@
-/*
-Copyright (C) 2001-2006, William Joseph.
-All Rights Reserved.
-
-This file is part of GtkRadiant.
-
-GtkRadiant is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-GtkRadiant is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with GtkRadiant; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-*/
 #pragma once
 
 /// \file
@@ -25,18 +5,14 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <cstring>
 
-/// \brief Returns true if [\p string, \p string + \p n) is lexicographically equal to [\p other, \p other + \p n).
-/// O(n)
-inline bool string_equal_n(const char* string, const char* other, std::size_t n)
+namespace string
 {
-  return std::strncmp(string, other, n) == 0;
-}
 
 /// \brief Returns <0 if \p string is lexicographically less than \p other after converting both to lower-case.
 /// Returns >0 if \p string is lexicographically greater than \p other after converting both to lower-case.
 /// Returns 0 if \p string is lexicographically equal to \p other after converting both to lower-case.
 /// O(n)
-inline int string_compare_nocase(const char* string, const char* other)
+inline int icmp(const char* string, const char* other)
 {
 #ifdef WIN32
   return _stricmp(string, other);
@@ -45,6 +21,24 @@ inline int string_compare_nocase(const char* string, const char* other)
 #endif
 }
 
+/// Case-insensitive comparison functor for use with data structures
+struct ILess
+{
+    bool operator() (const std::string& lhs, const std::string& rhs) const
+    {
+        return icmp(lhs.c_str(), rhs.c_str()) < 0;
+    }
+};
+
+}
+
+/// \brief Returns true if [\p string, \p string + \p n) is lexicographically equal to [\p other, \p other + \p n).
+/// O(n)
+inline bool string_equal_n(const char* string, const char* other, std::size_t n)
+{
+  return std::strncmp(string, other, n) == 0;
+}
+
 /// \brief Returns <0 if [\p string, \p string + \p n) is lexicographically less than [\p other, \p other + \p n).
 /// Returns >0 if [\p string, \p string + \p n) is lexicographically greater than [\p other, \p other + \p n).
 /// Returns 0 if [\p string, \p string + \p n) is lexicographically equal to [\p other, \p other + \p n).
@@ -59,20 +53,20 @@ inline int string_compare_nocase_n(const char* string, const char* other, std::s
 #endif
 }
 
-/// \brief Returns true if \p string is lexicographically equal to \p other.
-/// Treats all ascii characters as lower-case during comparisons.
-/// O(n)
-inline bool string_equal_nocase(const char* string, const char* other)
-{
-  return string_compare_nocase(string, other) == 0;
-}
-
 /// \brief Returns true if [\p string, \p string + \p n) is lexicographically equal to [\p other, \p other + \p n).
 /// Treats all ascii characters as lower-case during comparisons.
 /// O(n)
 inline bool string_equal_nocase_n(const char* string, const char* other, std::size_t n)
 {
-  return string_compare_nocase_n(string, other, n) == 0;
+    return string_compare_nocase_n(string, other, n) == 0;
+}
+
+/// \brief Returns true if \p string is lexicographically equal to \p other.
+/// Treats all ascii characters as lower-case during comparisons.
+/// O(n)
+inline bool string_equal_nocase(const char* string, const char* other)
+{
+  return string::icmp(string, other) == 0;
 }
 
 /// \brief Returns true if \p string is lexicographically less than \p other.
@@ -80,5 +74,5 @@ inline bool string_equal_nocase_n(const char* string, const char* other, std::si
 /// O(n)
 inline bool string_less_nocase(const char* string, const char* other)
 {
-  return string_compare_nocase(string, other) < 0;
-}
+  return string::icmp(string, other) < 0;
+}
\ No newline at end of file
