@@ -11,34 +11,12 @@ class IdentityTransform :
 {
 public:
 	/// \brief Returns the identity matrix.
-	const Matrix4& localToParent() const
+	Matrix4 localToParent() const
 	{
 		return Matrix4::getIdentity();
 	}
 };
 
-/// \brief A transform node which stores a generic transformation matrix.
-class MatrixTransform :
-	public ITransformNode
-{
-	Matrix4 _localToParent;
-public:
-	MatrixTransform() :
-		_localToParent(Matrix4::getIdentity())
-	{}
-
-	Matrix4& localToParent()
-	{
-		return _localToParent;
-	}
-
-	/// \brief Returns the stored local->parent transform.
-	const Matrix4& localToParent() const
-	{
-		return _localToParent;
-	}
-};
-
 namespace scene
 {
 
