@@ -8,20 +8,22 @@ namespace util
 class ScopedBoolLock
 {
     bool& _target;
+    bool _previousValue;
 
 public:
 
     /// Construct and set target to true
     ScopedBoolLock(bool& target) :
-        _target(target)
+        _target(target),
+        _previousValue(target)
     {
         _target = true;
     }
 
-    /// Destroy and set target to false
+    /// Destroy and set target to the previous value
     ~ScopedBoolLock()
     {
-        _target = false;
+        _target = _previousValue;
     }
 };
 
