@@ -1,7 +1,10 @@
 #pragma once
 
 #include <string>
+#if 0
 #include <wx/string.h>
+#endif
+#include "string/encoding.h"
 
 #include <cassert>
 
@@ -25,8 +28,12 @@ public:
 	 */
 	static std::string localeToUTF8(const std::string& input)
 	{
+#if 1
+		return string::mb_to_utf8(input);
+#else
 		wxString inp(input);
 		return inp.ToUTF8().data();
+#endif
 	}
 
 	/**
@@ -35,7 +42,11 @@ public:
 	 */
 	static std::string localeFromUTF8(const std::string& input)
 	{
+#if 1
+		return string::utf8_to_mb(input);
+#else
 		return wxString::FromUTF8(input.c_str()).ToStdString();
+#endif
 	}
 };
 
