@@ -10,12 +10,18 @@
 namespace wxutil
 {
 
+namespace
+{
+    constexpr const int APPLY_FILTER_TEXT_DELAY_MSEC = 250;
+}
+
 ResourceTreeViewToolbar::ResourceTreeViewToolbar(wxWindow* parent, ResourceTreeView* treeView) :
     wxPanel(parent, wxID_ANY),
     _treeView(nullptr),
     _filterEntry(nullptr),
     _showAll(nullptr),
-    _showFavourites(nullptr)
+    _showFavourites(nullptr),
+    _applyFilterTimer(this)
 {
     auto* grid = new wxFlexGridSizer(2);
     grid->AddGrowableCol(1);
@@ -74,6 +80,8 @@ ResourceTreeViewToolbar::ResourceTreeViewToolbar(wxWindow* parent, ResourceTreeV
     grid->Add(_rightSizer, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 6);
 
     AssociateToTreeView(treeView);
+
+    Bind(wxEVT_TIMER, &ResourceTreeViewToolbar::_onFilterTimeoutReached, this);
 }
 
 wxSizer* ResourceTreeViewToolbar::GetLeftSizer()
@@ -95,11 +103,18 @@ void ResourceTreeViewToolbar::EnableFavouriteManagement(bool enable)
 void ResourceTreeViewToolbar::AssociateToTreeView(ResourceTreeView* treeView)
 {
     _treeView = treeView;
+
+    if (_treeView != nullptr)
+    {
+        _treeView->Bind(EV_TREEVIEW_FILTERTEXT_CLEARED, &ResourceTreeViewToolbar::_onTreeViewFilterTextCleared, this);
+    }
+
     UpdateFromTreeView();
 }
 
 void ResourceTreeViewToolbar::ClearFilter()
 {
+    _applyFilterTimer.Stop();
     _filterEntry->SetValue("");
 
     if (_treeView != nullptr)
@@ -160,6 +175,41 @@ void ResourceTreeViewToolbar::HandleFilterEntryChanged()
         return;
     }
 
+    // Put in a slight delay before actually firing off the search (#5745)
+    _applyFilterTimer.Start(APPLY_FILTER_TEXT_DELAY_MSEC, true);
+}
+
+void ResourceTreeViewToolbar::_onFilterButtonToggled(wxCommandEvent& ev)
+{
+    if (_treeView == nullptr) return;
+
+    _treeView->SetTreeMode(_showAll->GetValue() ?
+        ResourceTreeView::TreeMode::ShowAll :
+        ResourceTreeView::TreeMode::ShowFavourites);
+
+    _filterEntry->Clear();
+    HandleFilterEntryChanged();
+}
+
+void ResourceTreeViewToolbar::_onTreeViewFilterTextCleared(wxCommandEvent& ev)
+{
+    // Tree view cleared the filter, clear our entry box
+    _filterEntry->Clear();
+    _applyFilterTimer.Stop();
+    ev.Skip();
+}
+
+void ResourceTreeViewToolbar::UpdateFromTreeView()
+{
+    if (_treeView == nullptr) return;
+
+    auto mode = _treeView->GetTreeMode();
+    _showAll->SetValue(mode == ResourceTreeView::TreeMode::ShowAll);
+    _showFavourites->SetValue(mode == ResourceTreeView::TreeMode::ShowFavourites);
+}
+
+void ResourceTreeViewToolbar::_onFilterTimeoutReached(wxTimerEvent& ev)
+{
     auto filterText = _filterEntry->GetValue();
     bool filterResult = _treeView->SetFilterText(filterText);
 
@@ -176,25 +226,4 @@ void ResourceTreeViewToolbar::HandleFilterEntryChanged()
     _filterEntry->Refresh();
 }
 
-void ResourceTreeViewToolbar::_onFilterButtonToggled(wxCommandEvent& ev)
-{
-    if (_treeView == nullptr) return;
-
-    _treeView->SetTreeMode(_showAll->GetValue() ?
-        ResourceTreeView::TreeMode::ShowAll :
-        ResourceTreeView::TreeMode::ShowFavourites);
-
-    _filterEntry->Clear();
-    HandleFilterEntryChanged();
-}
-
-void ResourceTreeViewToolbar::UpdateFromTreeView()
-{
-    if (_treeView == nullptr) return;
-
-    auto mode = _treeView->GetTreeMode();
-    _showAll->SetValue(mode == ResourceTreeView::TreeMode::ShowAll);
-    _showFavourites->SetValue(mode == ResourceTreeView::TreeMode::ShowFavourites);
-}
-
 }
