@@ -18,6 +18,7 @@ namespace wxutil
 namespace
 {
 	const int MSECS_TO_AUTO_CLOSE_POPUP = 6000;
+	const int MSECS_TO_HIGHLIGHT_MATCH = 250;
 }
 
 class TreeView::Search :
@@ -28,6 +29,7 @@ private:
 	SearchPopupWindow* _popup;
 	wxDataViewItem _curSearchMatch;
 	wxTimer _closeTimer;
+	wxTimer _highlightSearchTimer;
 
 public:
 	Search(TreeView& treeView);
@@ -51,7 +53,8 @@ private:
 
 TreeView::TreeView(wxWindow* parent, wxDataViewModel* model, long style) :
 	wxDataViewCtrl(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, style),
-	_collapseRecursively(true)
+	_collapseRecursively(true),
+    _searchPopupEnabled(true)
 {
 	EnableAutoColumnWidthFix();
 
@@ -177,6 +180,16 @@ bool TreeView::HasActiveSearchPopup()
     return _search != nullptr;
 }
 
+void TreeView::EnableSearchPopup(bool enabled)
+{
+    _searchPopupEnabled = enabled;
+
+    if (!_searchPopupEnabled)
+    {
+        CloseSearch();
+    }
+}
+
 #if !defined(__linux__)
 void TreeView::Rebuild()
 {
@@ -257,6 +270,7 @@ void TreeView::_onItemActivated(wxDataViewEvent& ev)
 	if (!IsExpanded(ev.GetItem()))
 	{
 		Expand(ev.GetItem());
+        ev.Skip(); // let parent dialogs handle double clicks (e.g. auto close)
 	}
 	else
 	{
@@ -419,7 +433,8 @@ private:
 
 TreeView::Search::Search(TreeView& treeView) :
 	_treeView(treeView),
-	_closeTimer(this)
+	_closeTimer(this),
+    _highlightSearchTimer(this)
 {
 	_popup = new SearchPopupWindow(&_treeView, *this);
 	_popup->Show();
@@ -461,10 +476,20 @@ void TreeView::Search::_onTreeViewCharHook(wxKeyEvent& ev)
 
 void TreeView::Search::_onIntervalReached(wxTimerEvent& ev)
 {
-	// Disconnect the timing event
-	_closeTimer.Stop();
+    if (ev.GetTimer().GetId() == _closeTimer.GetId())
+    {
+        // Disconnect the timing event
+        _closeTimer.Stop();
 
-	_treeView.CloseSearch();
+        _treeView.CloseSearch();
+    }
+    else if (ev.GetTimer().GetId() == _highlightSearchTimer.GetId())
+    {
+        auto* model = dynamic_cast<TreeModel*>(_treeView.GetModel());
+        if (model == nullptr) return;
+
+        HighlightMatch(model->FindNextString(_popup->GetSearchString(), _treeView._colsToSearch));
+    }
 }
 
 void TreeView::Search::HighlightMatch(const wxDataViewItem& item)
@@ -502,7 +527,8 @@ void TreeView::Search::HandleKeyEvent(wxKeyEvent& ev)
 		{
 			_popup->SetSearchString(_popup->GetSearchString() + ev.GetUnicodeKey());
 
-			HighlightMatch(model->FindNextString(_popup->GetSearchString(), _treeView._colsToSearch));
+            // Perform the actual search a bit later (#5745)
+            _highlightSearchTimer.Start(MSECS_TO_HIGHLIGHT_MATCH, true);
 		}
 		else if (ev.GetKeyCode() == WXK_ESCAPE)
 		{
@@ -511,8 +537,9 @@ void TreeView::Search::HandleKeyEvent(wxKeyEvent& ev)
 		else if (ev.GetKeyCode() == WXK_BACK)
 		{
 			_popup->SetSearchString(_popup->GetSearchString().RemoveLast(1));
-
-			HighlightMatch(model->FindNextString(_popup->GetSearchString(), _treeView._colsToSearch));
+            
+            // Perform the actual search a bit later (#5745)
+            _highlightSearchTimer.Start(MSECS_TO_HIGHLIGHT_MATCH, true);
 		}
 		else
 		{
@@ -560,6 +587,7 @@ void TreeView::Search::HighlightPrevMatch()
 
 void TreeView::Search::Close()
 {
+    _highlightSearchTimer.Stop();
 	_treeView.CloseSearch();
 }
 
@@ -570,7 +598,7 @@ void TreeView::CloseSearch()
 
 void TreeView::_onChar(wxKeyEvent& ev)
 {
-	if (GetModel() == nullptr || _colsToSearch.empty())
+	if (!_searchPopupEnabled || GetModel() == nullptr || _colsToSearch.empty())
 	{
 		ev.Skip();
 		return;
@@ -630,5 +658,4 @@ void TreeView::JumpToSearchMatch(const wxDataViewItem& item)
         SendSelectionChangeEvent(item);
 	}
 }
-
 } // namespace
