@@ -1,8 +1,10 @@
 #include "DialogBase.h"
 
+#include "AutoSaveRequestBlocker.h"
+
 namespace wxutil
 {
-    
+
     namespace
     {
         inline wxWindow* FindTopLevelWindow()
@@ -11,30 +13,31 @@ namespace wxutil
             {
                 return GlobalMainFrame().getWxTopLevelWindow();
             }
-            
+
             return nullptr;
         }
     }
 
-void DialogBase::_onDelete(wxCloseEvent& ev)
-{
-    if (_onDeleteEvent())
-    {
-        ev.Veto();
-    }
-    else
-    {
-        EndModal(wxID_CANCEL);
-    }
-}
-
 DialogBase::DialogBase(const std::string& title, wxWindow* parent)
 : wxDialog(parent ? parent : FindTopLevelWindow(),
            wxID_ANY, title, wxDefaultPosition, wxDefaultSize,
            wxCAPTION | wxSYSTEM_MENU | wxRESIZE_BORDER)
 {
-    Connect(wxEVT_CLOSE_WINDOW, wxCloseEventHandler(DialogBase::_onDelete),
-            nullptr, this);
+    // Allow subclasses to override close event
+    Bind(wxEVT_CLOSE_WINDOW, [this](wxCloseEvent& e) {
+        if (_onDeleteEvent())
+            e.Veto();
+        else
+            EndModal(wxID_CANCEL);
+    });
+
+    // Allow ESC to close all dialogs
+    Bind(wxEVT_CHAR_HOOK, [this](wxKeyEvent& e) {
+        if (e.GetKeyCode() == WXK_ESCAPE)
+            Close();
+        else
+            e.Skip();
+    });
 }
 
 void DialogBase::FitToScreen(float xProp, float yProp)
@@ -56,4 +59,12 @@ void DialogBase::FitToScreen(float xProp, float yProp)
     CenterOnScreen();
 }
 
+int DialogBase::ShowModal()
+{
+    // While this dialog is active, block any auto save requests
+    AutoSaveRequestBlocker blocker("Modal Dialog is active");
+
+    return wxDialog::ShowModal();
+}
+
 }
