@@ -5,6 +5,7 @@
 #include "imodel.h"
 #include "imap.h"
 
+#include <sigc++/signal.h>
 #include <string>
 #include <map>
 
@@ -21,6 +22,17 @@ namespace wxutil
 class ModelPreview
 : public RenderPreview
 {
+private:
+	// TRUE when the scene, model and skin have been set up
+	// is set back to FALSE if the model or skin config is changed
+	bool _sceneIsReady;
+
+	// The name of the model to render
+	std::string _model;
+
+	// The name of the skin to render
+	std::string _skin;
+
     scene::IMapRootNodePtr _rootNode;
 
     // The parent entity
@@ -38,6 +50,8 @@ class ModelPreview
 
 	float _defaultCamDistanceFactor;
 
+	sigc::signal<void, const model::ModelNodePtr&> _modelLoadedSignal;
+
 private:
 
     // Creates parent entity etc.
@@ -46,6 +60,8 @@ private:
     bool onPreRender() override;
     RenderStateFlags getRenderFlagsFill() override;
 
+	void prepareScene();
+
 protected:
     virtual void onModelRotationChanged() override;
 
@@ -54,6 +70,12 @@ public:
     /// Construct a ModelPreview widget.
     ModelPreview(wxWindow* parent);
 
+	// Returns the name of the current model
+	const std::string& getModel() const;
+
+	// Returns the name of the current skin
+	const std::string& getSkin() const;
+
     /**
      * Set the widget to display the given model. If the model name is the
      * empty string, the widget will release the currently displayed model.
@@ -75,6 +97,9 @@ public:
     {
         return _modelNode;
     }
+
+	// Signal emitted when the preview is done loading a new model
+	sigc::signal<void, const model::ModelNodePtr&>& signal_ModelLoaded();
 };
 typedef std::shared_ptr<ModelPreview> ModelPreviewPtr;
 
