@@ -8,12 +8,12 @@
 #include "../XmlResourceBasedWidget.h"
 
 #include "igl.h"
-#include "ifiltermenu.h"
 #include "iscenegraph.h"
 #include "irender.h"
 
 #include "../FreezePointer.h"
 #include "render/NopVolumeTest.h"
+#include "render/CamRenderer.h"
 
 class wxToolBarToolBase;
 
@@ -23,12 +23,12 @@ namespace wxutil
 class GLWidget;
 
 /**
- * greebo: This class acts as base for widgets featuring 
+ * greebo: This class acts as base for widgets featuring
  * a real time openGL render preview. It offers
  * its own local SceneGraph, backend and frontend renderer
  * plus all the logic for camera handling and filtering.
  *
- * Override the protected methods to have the scene set up 
+ * Override the protected methods to have the scene set up
  * in special ways or add custom toolbar items.
  *
  * After construction the local scene graph will be empty.
@@ -86,7 +86,11 @@ private:
 
 	bool _renderGrid;
 
+    render::CamRenderer::HighlightShaders _shaders;
+
 protected:
+    const unsigned int MSEC_PER_FRAME = 16;
+
     // The backend rendersystem instance
     RenderSystemPtr _renderSystem;
 
@@ -117,7 +121,6 @@ protected:
 	wxSizer* _toolbarSizer;
 
     // The filters menu
-    ui::IFilterMenuPtr _filtersMenu;
 	wxToolBarToolBase* _filterTool;
 
     IGLFont::Ptr _glFont;
@@ -132,7 +135,6 @@ protected:
     // the rendersystem can be associated. This is called after initialisePreview()
     virtual void setupSceneGraph();
 
-    virtual Matrix4 getProjectionMatrix(float near_z, float far_z, float fieldOfView, int width, int height);
     virtual const Matrix4& getModelViewMatrix();
 
     virtual Matrix4 calculateModelViewMatrix();
@@ -148,6 +150,9 @@ protected:
     // Override this to deliver accurate scene bounds, used for mousewheel-zooming
     virtual AABB getSceneBounds();
 
+    // Defaults to getSceneBounds().getOrigin()
+    virtual Vector3 getGridOrigin();
+
     // Called right before rendering, returning false will cancel the render algorithm
     virtual bool onPreRender();
 
@@ -163,6 +168,9 @@ protected:
 
     void associateRenderSystem();
 
+    // Base method will return true, which will also make the corresponding button appear on the toolbar
+    virtual bool canDrawGrid();
+
     // Can be overridden by subclasses to update their scene/models
     virtual void onRenderModeChanged() {}
 
