@@ -2,9 +2,8 @@
 
 #include "i18n.h"
 #include "itextstream.h"
-#include "ieventmanager.h"
 #include "icommandsystem.h"
-#include "imenumanager.h"
+#include "ui/imenumanager.h"
 #include "generic/callback.h"
 #include "debugging/debugging.h"
 
