@@ -212,7 +212,7 @@ void DifficultySettingsManager::saveSettings()
         }
 
         // Create and insert a new entity node into the scenegraph root
-        IEntityNodePtr entNode = GlobalEntityCreator().createEntity(diffEclass);
+        IEntityNodePtr entNode = GlobalEntityModule().createEntity(diffEclass);
         GlobalSceneGraph().root()->addChildNode(entNode);
 
         // Add the entity to the list
