@@ -1,11 +1,10 @@
 #include "imodule.h"
 
 #include "i18n.h"
-#include "ieventmanager.h"
 #include "itextstream.h"
 #include "ieclass.h"
 #include "iscenegraph.h"
-#include "imenumanager.h"
+#include "ui/imenumanager.h"
 #include "iregistry.h"
 #include "iselection.h"
 #include "iradiant.h"
