@@ -3,11 +3,12 @@
 #include "i18n.h"
 #include "iselection.h"
 #include "ieclass.h"
+#include "imap.h"
 #include "itextstream.h"
-#include "ientityinspector.h"
-#include "imainframe.h"
+#include "ui/ientityinspector.h"
+#include "ui/imainframe.h"
 #include "iundo.h"
-#include "igroupdialog.h"
+#include "ui/igroupdialog.h"
 #include "selectionlib.h"
 
 #include "SpawnargLinkedCheckbox.h"
@@ -281,9 +282,9 @@ void AIEditingPanel::onMainFrameConstructed()
 	Instance()._tempParent->Destroy();
 	Instance()._tempParent = nullptr;
 
-	Instance()._undoHandler = GlobalUndoSystem().signal_postUndo().connect(
+	Instance()._undoHandler = GlobalMapModule().signal_postUndo().connect(
 		sigc::mem_fun(Instance(), &AIEditingPanel::updateWidgetsFromSelection));
-	Instance()._redoHandler = GlobalUndoSystem().signal_postRedo().connect(
+	Instance()._redoHandler = GlobalMapModule().signal_postRedo().connect(
 		sigc::mem_fun(Instance(), &AIEditingPanel::updateWidgetsFromSelection));
 }
 
@@ -307,7 +308,7 @@ Entity* AIEditingPanel::getEntityFromSelection()
 		{
 			Entity* candidate = Node_getEntity(node);
 
-			if (candidate->isOfType("atdm:ai_base"))
+			if (candidate != nullptr && candidate->isOfType("atdm:ai_base"))
 			{
 				entity = candidate;
 			}
@@ -428,8 +429,7 @@ void AIEditingPanel::onBrowseButton(wxCommandEvent& ev, const std::string& key)
 	if (_entity == nullptr) return;
 
 	// Look up the property editor dialog
-	IPropertyEditorPtr editor = GlobalEntityInspector().getRegisteredPropertyEditor(key);
-	IPropertyEditorDialogPtr dialog = std::dynamic_pointer_cast<IPropertyEditorDialog>(editor);
+    IPropertyEditorDialog::Ptr dialog = GlobalEntityInspector().createDialog(key);
 
 	if (dialog)
 	{
