@@ -1,7 +1,7 @@
 #include "FixupMapDialog.h"
 
 #include "i18n.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "wxutil/dialog/MessageBox.h"
 
 #include "string/string.h"
