@@ -1,6 +1,6 @@
 #include "ObjectiveConditionsDialog.h"
 
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "i18n.h"
 #include "itextstream.h"
 
