@@ -7,9 +7,8 @@
 #include "i18n.h"
 #include "itextstream.h"
 #include "iradiant.h"
-#include "ieventmanager.h"
-#include "imainframe.h"
-#include "igroupdialog.h"
+#include "ui/imainframe.h"
+#include "ui/igroupdialog.h"
 #include "iundo.h"
 
 #include "interfaces/MathInterface.h"
