@@ -4,8 +4,7 @@
 #include "ibrush.h"
 #include "iclipper.h"
 #include "icolourscheme.h"
-#include "ieventmanager.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "itextstream.h"
 #include "iorthoview.h"
 #include "icameraview.h"
@@ -123,6 +122,11 @@ CamWnd::CamWnd(wxWindow* parent) :
 
     _glExtensionsInitialisedNotifier = GlobalRenderSystem().signal_extensionsInitialised().connect(
         sigc::mem_fun(this, &CamWnd::onGLExtensionsInitialised));
+
+    _textureChangedHandler = GlobalRadiantCore().getMessageBus().addListener(
+        radiant::IMessage::Type::TextureChanged,
+        radiant::TypeListener<radiant::TextureChangedMessage>(
+            sigc::mem_fun(this, &CamWnd::handleTextureChanged)));
 }
 
 wxWindow* CamWnd::getMainWidget() const
@@ -242,6 +246,8 @@ void CamWnd::constructGUIComponents()
 
 CamWnd::~CamWnd()
 {
+    GlobalRadiantCore().getMessageBus().removeListener(_textureChangedHandler);
+
     const wxToolBarToolBase* gridButton = getToolBarToolByLabel(_camToolbar, "drawGridButton");
     auto toggleCameraGridEvent = GlobalEventManager().findEvent("ToggleCameraGrid");
     toggleCameraGridEvent->disconnectToolItem(gridButton);
@@ -1389,6 +1395,11 @@ void CamWnd::rotateRightDiscrete()
     setCameraAngles(angles);
 }
 
+void CamWnd::handleTextureChanged(radiant::TextureChangedMessage& msg)
+{
+    queueDraw();
+}
+
 // -------------------------------------------------------------------------------
 
 render::CamRenderer::HighlightShaders CamWnd::_shaders;
