@@ -3,7 +3,7 @@
 #include "iscenegraph.h"
 #include "imousetool.h"
 #include "icameraview.h"
-#include "ieventmanager.h"
+#include "ui/ieventmanager.h"
 #include "igl.h"
 #include "irender.h"
 #include "wxutil/GLWidget.h"
@@ -27,6 +27,7 @@
 #include "tools/CameraMouseToolEvent.h"
 #include "render/RenderStatistics.h"
 #include "render/CamRenderer.h"
+#include "messages/TextureChanged.h"
 
 const int CAMWND_MINSIZE_X = 240;
 const int CAMWND_MINSIZE_Y = 200;
@@ -107,6 +108,8 @@ class CamWnd :
 
     IGLFont::Ptr _glFont;
 
+    std::size_t _textureChangedHandler;
+
 public:
     // Constructor and destructor
     CamWnd(wxWindow* parent);
@@ -253,6 +256,8 @@ private:
     // Gets called with the accumulated delta values, as buffered by wxutil::DeferredMotionDelta
     void onDeferredMotionDelta(int x, int y);
     void performFreeMove(int dx, int dy);
+
+    void handleTextureChanged(radiant::TextureChangedMessage& msg);
 };
 
 /**
