@@ -1,7 +1,7 @@
 #include "FloatingCamWnd.h"
 
 #include "i18n.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 
 #include <wx/sizer.h>
 
