@@ -5,15 +5,21 @@
 #include "imousetoolmanager.h"
 #include "xmlutil/Node.h"
 #include "MouseToolGroup.h"
+#include <wx/event.h>
+#include <wx/timer.h>
+#include "wxutil/event/SingleIdleCallback.h"
 
 namespace ui
 {
 
+class ModifierHintPopup;
+
 /**
 * Implementation of the IMouseToolManager interface.
 * This is used by the GlobalXYWnd and GlobalCamera instances.
 */
 class MouseToolManager :
+    public wxutil::SingleIdleCallback,
     public IMouseToolManager
 {
 protected:
@@ -22,6 +28,10 @@ protected:
 
     unsigned int _activeModifierState;
 
+    wxTimer _hintCloseTimer;
+    ModifierHintPopup* _hintPopup;
+    bool _shouldClosePopup;
+
 public:
     MouseToolManager();
 
@@ -43,6 +53,10 @@ public:
     void updateStatusbar(unsigned int newState);
 
     void resetBindingsToDefault();
+    void closeHintPopup();
+
+protected:
+    void onIdle() override;
 
 private:
     void onMainFrameConstructed();
@@ -51,6 +65,8 @@ private:
 	void loadGroupMapping(MouseToolGroup::Type type, const xml::NodeList& userMappings, const xml::NodeList& defaultMappings);
 
     void saveToolMappings();
+
+    void onCloseTimerIntervalReached(wxTimerEvent& ev);
 };
 
 } // namespace
