@@ -10,11 +10,11 @@
 #include "imap.h"
 #include "ibrush.h"
 #include "ipatch.h"
-#include "iorthocontextmenu.h"
-#include "ieventmanager.h"
+#include "ui/ieventmanager.h"
 #include "imousetool.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "ishaders.h"
+#include "icameraview.h"
 
 #include "wxutil/menu/CommandMenuItem.h"
 #include "wxutil/MultiMonitor.h"
@@ -51,6 +51,7 @@
 #include "ui/patch/CapDialog.h"
 #include "ui/patch/PatchThickenDialog.h"
 #include "textool/TexTool.h"
+#include "modelexport/ConvertModelDialog.h"
 #include "modelexport/ExportAsModelDialog.h"
 #include "modelexport/ExportCollisionModelDialog.h"
 #include "ui/filters/FilterOrthoContextMenuItem.h"
@@ -77,12 +78,12 @@ namespace
 	const char* const LAYER_ICON = "layers.png";
 	const char* const CREATE_LAYER_TEXT = N_("Create Layer...");
 
-	const char* const ADD_TO_LAYER_TEXT = N_("Add to Layer...");
-	const char* const MOVE_TO_LAYER_TEXT = N_("Move to Layer...");
-	const char* const REMOVE_FROM_LAYER_TEXT = N_("Remove from Layer...");
+	const char* const ADD_TO_LAYER_TEXT = N_("Add to Layer");
+	const char* const MOVE_TO_LAYER_TEXT = N_("Move to Layer");
+	const char* const REMOVE_FROM_LAYER_TEXT = N_("Remove from Layer");
 
-	const char* const SELECT_BY_FILTER_TEXT = N_("Select by Filter...");
-	const char* const DESELECT_BY_FILTER_TEXT = N_("Deselect by Filter...");
+    const char* const SELECT_BY_FILTER_TEXT = N_( "Select by Filter" );
+    const char* const DESELECT_BY_FILTER_TEXT = N_( "Deselect by Filter" );
 }
 
 const std::string& UserInterfaceModule::getName() const
@@ -191,6 +192,7 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
 	_autoSaveRequestHandler.reset(new AutoSaveRequestHandler);
 	_fileSelectionRequestHandler.reset(new FileSelectionRequestHandler);
     _fileOverwriteConfirmationHandler.reset(new FileOverwriteConfirmationHandler);
+    _fileSaveConfirmationHandler.reset(new FileSaveConfirmationHandler);
 
 	initialiseEntitySettings();
 
@@ -199,10 +201,6 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
 		radiant::TypeListener<radiant::CommandExecutionFailedMessage>(
 			sigc::mem_fun(this, &UserInterfaceModule::handleCommandExecutionFailure)));
 
-	_textureChangedListener = GlobalRadiantCore().getMessageBus().addListener(
-		radiant::IMessage::Type::TextureChanged,
-        radiant::TypeListener<radiant::TextureChangedMessage>(UserInterfaceModule::HandleTextureChanged));
-
 	_notificationListener = GlobalRadiantCore().getMessageBus().addListener(
 		radiant::IMessage::Type::Notification,
         radiant::TypeListener<radiant::NotificationMessage>(UserInterfaceModule::HandleNotificationMessage));
@@ -215,8 +213,10 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
 	_mruMenu.reset(new MRUMenu);
 	_shaderClipboardStatus.reset(new statusbar::ShaderClipboardStatus);
 	_editStopwatchStatus.reset(new statusbar::EditingStopwatchStatus);
+    _commandStatus.reset(new statusbar::CommandStatus);
     _mapStatisticsStatus.reset(new statusbar::MapStatistics);
 	_manipulatorToggle.reset(new ManipulatorToggle);
+    _textureToolModeToggles.reset(new TexToolModeToggles);
 	_selectionModeToggle.reset(new SelectionModeToggle);
 
 	MouseToolRegistrationHelper::RegisterTools();
@@ -226,13 +226,25 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
     _mapEditModeChangedConn = GlobalMapModule().signal_editModeChanged().connect(
         sigc::ptr_fun(&MergeControlDialog::OnMapEditModeChanged)
     );
+
+    _autosaveTimer.reset(new map::AutoSaveTimer);
+    _autosaveTimer->initialise();
+
+#ifdef WIN32
+    // Hide the local user guide item in Windows
+    GlobalMainFrame().signal_MainFrameConstructed().connect([&]()
+    {
+        GlobalMenuManager().setVisibility("main/help/userGuideLocal", false);
+    });
+#endif
 }
 
 void UserInterfaceModule::shutdownModule()
 {
+    _autosaveTimer.reset();
+
 	wxTheApp->Unbind(DISPATCH_EVENT, &UserInterfaceModule::onDispatchEvent, this);
 
-	GlobalRadiantCore().getMessageBus().removeListener(_textureChangedListener);
 	GlobalRadiantCore().getMessageBus().removeListener(_execFailedListener);
 	GlobalRadiantCore().getMessageBus().removeListener(_notificationListener);
 
@@ -242,14 +254,17 @@ void UserInterfaceModule::shutdownModule()
 
 	_longOperationHandler.reset();
 	_mapFileProgressHandler.reset();
+    _fileSaveConfirmationHandler.reset();
     _fileOverwriteConfirmationHandler.reset();
 	_fileSelectionRequestHandler.reset();
 	_autoSaveRequestHandler.reset();
 	_shaderClipboardStatus.reset();
     _mapStatisticsStatus.reset();
 	_editStopwatchStatus.reset();
+	_commandStatus.reset();
 	_manipulatorToggle.reset();
 	_selectionModeToggle.reset();
+    _textureToolModeToggles.reset();
 
 	_mruMenu.reset();
 }
@@ -392,7 +407,12 @@ void UserInterfaceModule::registerUICommands()
 	GlobalCommandSystem().addCommand("ShowCommandList", CommandList::ShowDialog);
 	GlobalCommandSystem().addCommand("About", AboutDialog::showDialog);
 	GlobalCommandSystem().addCommand("ShowUserGuide", Documentation::showUserGuide);
+	GlobalCommandSystem().addCommand("OpenForumUrl", Documentation::OpenForumUrl);
+#ifndef WIN32
+	GlobalCommandSystem().addCommand("ShowOfflineUserGuide", Documentation::showOfflineUserGuide);
+#endif
 	GlobalCommandSystem().addCommand("ExportSelectedAsModelDialog", ExportAsModelDialog::ShowDialog);
+	GlobalCommandSystem().addCommand("ConvertModelDialog", ConvertModelDialog::ShowDialog);
 
 	GlobalCommandSystem().addCommand("EntityClassTree", EClassTree::ShowDialog);
 	GlobalCommandSystem().addCommand("EntityList", EntityList::toggle);
@@ -429,11 +449,6 @@ void UserInterfaceModule::registerUICommands()
 	GlobalCommandSystem().addCommand("OpenMapFromProject", ui::MapSelector::OpenMapFromProject);
 }
 
-void UserInterfaceModule::HandleTextureChanged(radiant::TextureChangedMessage& msg)
-{
-	SurfaceInspector::update();
-}
-
 // Static module registration
 module::StaticModule<UserInterfaceModule> userInterfaceModule;
 
