@@ -3,9 +3,8 @@
 #include "i18n.h"
 #include "iaasfile.h"
 #include "iradiant.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "itextstream.h"
-#include "ieventmanager.h"
 #include "imap.h"
 
 #include <wx/button.h>
