@@ -1,7 +1,7 @@
 #include "RenderableAasFile.h"
 
 #include "iregistry.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "ivolumetest.h"
 
 #include "registry/registry.h"
