@@ -1,7 +1,7 @@
 #include "QuerySidesDialog.h"
 
 #include "i18n.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "selectionlib.h"
 #include "command/ExecutionNotPossible.h"
 #include "command/ExecutionFailure.h"
