@@ -32,12 +32,13 @@ ShaderChooser::ShaderChooser(wxWindow* parent, wxTextCtrl* targetEntry) :
 
 	_selector = new ShaderSelector(mainPanel, this, SHADER_PREFIXES);
 
-	if (_targetEntry != NULL)
+	if (_targetEntry != nullptr)
 	{
-		_initialShader = targetEntry->GetValue();
+		_initialShader = _targetEntry->GetValue();
 
 		// Set the cursor of the tree view to the currently selected shader
 		_selector->setSelection(_initialShader);
+        Bind( wxEVT_DATAVIEW_ITEM_ACTIVATED, &ShaderChooser::_onItemActivated, this );
 	}
 
 	// Pack in the ShaderSelector and buttons panel
@@ -58,6 +59,14 @@ void ShaderChooser::shutdown()
 	_windowPosition.saveToPath(RKEY_WINDOW_STATE);
 }
 
+void ShaderChooser::_onItemActivated( wxDataViewEvent& ev ) {
+    if ( !_selector->getSelection().empty() ) {
+        _targetEntry->SetValue( _selector->getSelection() );
+        shutdown();
+        EndModal( wxID_OK );
+    }
+}
+
 // Construct the buttons
 void ShaderChooser::createButtons(wxPanel* mainPanel, wxBoxSizer* dialogVBox)
 {
