@@ -1,11 +1,12 @@
 #include "ShaderSelector.h"
 
 #include "i18n.h"
-#include "iuimanager.h"
 
 #include "wxutil/dataview/TreeModel.h"
 #include "wxutil/dataview/TreeView.h"
 #include "wxutil/dataview/VFSTreePopulator.h"
+#include "wxutil/menu/IconTextMenuItem.h"
+#include "ui/materials/MaterialDefinitionView.h"
 
 #include "texturelib.h"
 #include "string/string.h"
@@ -14,7 +15,7 @@
 
 #include <wx/dataview.h>
 #include <wx/sizer.h>
-#include <wx/artprov.h>
+#include "wxutil/Bitmap.h"
 
 #include <GL/glew.h>
 
@@ -36,6 +37,9 @@ namespace
 {
 	const char* const FOLDER_ICON = "folder16.png";
 	const char* const TEXTURE_ICON = "icon_texture.png";
+
+    constexpr const char* const SHOW_MATERIAL_DEF_TEXT = N_("Show Material Definition");
+    constexpr const char* const SHOW_MATERIAL_DEF_ICON = "icon_script.png";
 }
 
 // Constructor creates elements
@@ -46,7 +50,8 @@ ShaderSelector::ShaderSelector(wxWindow* parent, Client* client, const std::stri
 	_glWidget(NULL),
 	_client(client),
 	_isLightTexture(isLightTexture),
-	_infoStore(new wxutil::TreeModel(_infoStoreColumns, true)) // is a listmodel
+	_infoStore(new wxutil::TreeModel(_infoStoreColumns, true)), // is a listmodel
+    _contextMenu(new wxutil::PopupMenu)
 {
 	SetSizer(new wxBoxSizer(wxVERTICAL));
 
@@ -56,6 +61,21 @@ ShaderSelector::ShaderSelector(wxWindow* parent, Client* client, const std::stri
 	// Pack in TreeView and info panel
 	createTreeView();
 	createPreview();
+
+    // Construct the context menu
+    _contextMenu->addItem(
+        new wxutil::IconTextMenuItem(_(SHOW_MATERIAL_DEF_TEXT), SHOW_MATERIAL_DEF_ICON),
+        std::bind(&ShaderSelector::_onShowShaderDefinition, this),
+        [this]() { return !getSelection().empty(); }
+    );
+}
+
+void ShaderSelector::_onShowShaderDefinition()
+{
+    // Construct a definition view and pass the material name
+    auto view = new MaterialDefinitionView(getSelection());
+    view->ShowModal();
+    view->Destroy();
 }
 
 // Return the selection to the calling code
@@ -110,9 +130,9 @@ namespace
 			_columns(columns)
 		{
 			_folderIcon.CopyFromBitmap(
-				wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + FOLDER_ICON));
+				wxutil::GetLocalBitmap(FOLDER_ICON));
 			_textureIcon.CopyFromBitmap(
-				wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + TEXTURE_ICON));
+				wxutil::GetLocalBitmap(TEXTURE_ICON));
 		}
 
 		virtual ~DataInserter() {}
@@ -176,11 +196,17 @@ void ShaderSelector::createTreeView()
     _treeView->AddSearchColumn(_shaderTreeColumns.iconAndName);
 
     // Get selection and connect the changed callback
-    _treeView->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler(ShaderSelector::_onSelChange), NULL, this);
+    _treeView->Bind(wxEVT_DATAVIEW_SELECTION_CHANGED, &ShaderSelector::_onSelChange, this);
+    _treeView->Bind(wxEVT_DATAVIEW_ITEM_CONTEXT_MENU, &ShaderSelector::_onContextMenu, this);
 
     GetSizer()->Add(_treeView, 1, wxEXPAND);
 }
 
+void ShaderSelector::_onContextMenu(wxDataViewEvent& ev)
+{
+    _contextMenu->show(_treeView);
+}
+
 // Create the preview panel (GL widget and info table)
 void ShaderSelector::createPreview()
 {
@@ -210,7 +236,7 @@ void ShaderSelector::createPreview()
 
 // Get the selected shader
 MaterialPtr ShaderSelector::getSelectedShader() {
-	return GlobalMaterialManager().getMaterialForName(getSelection());
+	return GlobalMaterialManager().getMaterial(getSelection());
 }
 
 // Update the attributes table
@@ -260,7 +286,7 @@ bool ShaderSelector::onPreviewRender()
 	// Check what part of the shader we should display in the preview
 	if (_isLightTexture) {
 		// This is a light, take the first layer texture
-		const ShaderLayer* first = shader->firstLayer();
+		const IShaderLayer* first = shader->firstLayer();
 		if (first != NULL) {
 			tex = shader->firstLayer()->getTexture();
 			glBindTexture (GL_TEXTURE_2D, tex->getGLTexNum());
@@ -344,7 +370,7 @@ void ShaderSelector::displayLightShaderInfo(const MaterialPtr& shader,
 											wxutil::TreeModel& listStore,
 											int attrCol, int valueCol)
 {
-	const ShaderLayer* first = shader->firstLayer();
+	const IShaderLayer* first = shader->firstLayer();
 	std::string texName = _("None");
 
 	if (first != NULL)
