@@ -9,16 +9,11 @@
 namespace ui
 {
 
-// Blank ctor
-BooleanPropertyEditor::BooleanPropertyEditor() :
-	_checkBox(NULL)
-{}
-
 // Constructor. Create the widgets here
-BooleanPropertyEditor::BooleanPropertyEditor(wxWindow* parent, Entity* entity,
+BooleanPropertyEditor::BooleanPropertyEditor(wxWindow* parent, IEntitySelection& entities,
 											 const std::string& name)
-: PropertyEditor(entity),
-  _checkBox(NULL),
+: PropertyEditor(entities),
+  _checkBox(nullptr),
   _key(name)
 {
 	// Construct the main widget (will be managed by the base class)
@@ -34,14 +29,14 @@ BooleanPropertyEditor::BooleanPropertyEditor(wxWindow* parent, Entity* entity,
 
 	updateFromEntity();
 
-	_checkBox->Connect(wxEVT_CHECKBOX, wxCommandEventHandler(BooleanPropertyEditor::_onToggle), NULL, this);
+	_checkBox->Bind(wxEVT_CHECKBOX, &BooleanPropertyEditor::_onToggle, this);
 
 	mainVBox->GetSizer()->Add(_checkBox, 0, wxALIGN_CENTER_VERTICAL);
 }
 
 void BooleanPropertyEditor::updateFromEntity()
 {
-	_checkBox->SetValue(_entity->getKeyValue(_key) == "1");
+	_checkBox->SetValue(_entities.getSharedKeyValue(_key, false) == "1");
 }
 
 void BooleanPropertyEditor::_onToggle(wxCommandEvent& ev)
