@@ -2,7 +2,7 @@
 
 #include "PropertyEditor.h"
 
-#include "ientityinspector.h"
+#include "ui/ientityinspector.h"
 #include "iradiant.h"
 #include "imap.h"
 #include "icommandsystem.h"
@@ -32,23 +32,26 @@ class wxTextCtrl;
 class wxBitmapButton;
 class wxDataViewColumn;
 
+namespace selection
+{
+    class CollectiveSpawnargs;
+    class EntitySelection;
+}
+
 namespace ui
 {
 
-class EntityInspector;
-typedef std::shared_ptr<EntityInspector> EntityInspectorPtr;
+class PropertyEditorFactory;
 
 /**
  * The EntityInspector class represents the GTK dialog for editing properties
  * on the selected game entity. The class is implemented as a singleton and
  * contains a method to return the current instance.
  */
-class EntityInspector :
+class EntityInspector final :
 	public IEntityInspector,
- 	public SelectionSystem::Observer,
-    public wxutil::SingleIdleCallback,
-    public Entity::Observer,
-	public std::enable_shared_from_this<EntityInspector>
+    public selection::SelectionSystem::Observer,
+    public wxutil::SingleIdleCallback
 {
 public:
 	struct TreeColumns :
@@ -58,7 +61,7 @@ public:
 			name(add(wxutil::TreeModel::Column::IconText)),
 			value(add(wxutil::TreeModel::Column::String)),
 			isInherited(add(wxutil::TreeModel::Column::Boolean)),
-			hasHelpText(add(wxutil::TreeModel::Column::Boolean)),
+			isMultiValue(add(wxutil::TreeModel::Column::Boolean)),
 			booleanValue(add(wxutil::TreeModel::Column::Boolean)),
             oldValue(add(wxutil::TreeModel::Column::String)),
             newValue(add(wxutil::TreeModel::Column::String))
@@ -67,17 +70,18 @@ public:
 		wxutil::TreeModel::Column name;
 		wxutil::TreeModel::Column value;
 		wxutil::TreeModel::Column isInherited;
-		wxutil::TreeModel::Column hasHelpText;
+		wxutil::TreeModel::Column isMultiValue; // non-unique value (when multiple entities are selected)
 		wxutil::TreeModel::Column booleanValue;
 		wxutil::TreeModel::Column oldValue; // when displaying merge changes
 		wxutil::TreeModel::Column newValue; // when displaying merge changes
 	};
 
 private:
+    std::unique_ptr<PropertyEditorFactory> _propertyEditorFactory;
 
-	// Currently selected entity, this pointer is only non-NULL if the
-	// current entity selection includes exactly 1 entity.
-	scene::INodeWeakPtr _selectedEntity;
+    // Tracking helpers to organise the selected entities and their key values
+    std::unique_ptr<selection::CollectiveSpawnargs> _spawnargs;
+    std::unique_ptr<selection::EntitySelection> _entitySelection;
 
 	// Main EntityInspector widget
 	wxPanel* _mainWidget;
@@ -126,7 +130,7 @@ private:
 	wxutil::PopupMenuPtr _contextMenu;
 
 	// Currently displayed PropertyEditor
-	IPropertyEditorPtr _currentPropertyEditor;
+	IPropertyEditor::Ptr _currentPropertyEditor;
 
 	// The clipboard for spawnargs
 	typedef std::pair<std::string, std::string> KeyValuePair;
@@ -145,15 +149,21 @@ private:
 	typedef std::map<std::string, PropertyParms> PropertyParmMap;
 	PropertyParmMap _propertyTypes;
 
-	sigc::connection _undoHandler;
-	sigc::connection _redoHandler;
 	sigc::connection _defsReloadedHandler;
 	sigc::connection _mapEditModeChangedHandler;
 
+	sigc::connection _keyValueAddedHandler;
+	sigc::connection _keyValueRemovedHandler;
+	sigc::connection _keyValueSetChangedHandler;
+
     // Maps the key names to a possible merge action that should be displayed
     std::map<std::string, scene::merge::IEntityKeyValueMergeAction::Ptr> _mergeActions;
     std::map<std::string, scene::merge::IConflictResolutionAction::Ptr> _conflictActions;
 
+    bool _selectionNeedsUpdate;
+    bool _inheritedPropertiesNeedUpdate;
+    bool _helpTextNeedsUpdate;
+
 private:
     bool canUpdateEntity();
 
@@ -201,9 +211,18 @@ private:
 	void _onContextMenu(wxDataViewEvent& ev);
 	void _onDataViewItemChanged(wxDataViewEvent& ev);
 
+    void onKeyAdded(const std::string& key, const std::string& value);
+    void onKeyRemoved(const std::string& key);
+    void onKeyValueSetChanged(const std::string& key, const std::string& uniqueValue);
+    
+    // Routines shared by onKeyAdded, onKeyRemoved and onKeyValueSetChanged
+    void onKeyUpdatedCommon(const std::string& key);
+
 	void handleShowInheritedChanged();
-	void handleShowHelpTextChanged();
+	void updateHelpTextPanel();
 	void updateHelpText(const wxutil::TreeModel::Row& row);
+	void setHelpText(const std::string& newText);
+    void updatePrimitiveNumber();
     static std::string  cleanInputString( const std::string& );
 
     // Add and remove inherited properties from the entity class
@@ -211,11 +230,8 @@ private:
     void addClassProperties();
     void removeClassProperties();
 
-    // Update our selected entity pointer from the selection system
-    void getEntityFromSelectionSystem();
-
-    // Change the selected entity pointer, setting up the observer
-    void changeSelectedEntity(const scene::INodePtr& newEntity, const scene::INodePtr& selectedNode);
+    void applyMergeActionStyle(const std::string& key, wxDataViewItemAttr& style);
+    void setOldAndNewValueColumns(wxutil::TreeModel::Row& row, const std::string& key, const wxDataViewItemAttr& style);
 
     void handleMergeActions(const scene::INodePtr& selectedNode);
     void handleKeyValueMergeAction(const scene::merge::IEntityKeyValueMergeAction::Ptr& mergeAction);
@@ -233,6 +249,9 @@ private:
 
 	// Returns property type and option for the given entity key
 	PropertyParms getPropertyParmsForKey(const std::string& key);
+	std::string getPropertyTypeForKey(const std::string& key);
+    void updateListedKeyTypes();
+    void updateKeyType(wxutil::TreeModel::Row& row);
 
     // Update tree view contents and property editor
     void updateGUIElements();
@@ -240,8 +259,6 @@ private:
     // Release the current entity and rescan the selection
     void refresh();
 
-	// Gets called after an undo operation
-	void onUndoRedoOperation();
     void onMapEditModeChanged(IMap::EditMode mode);
 	void onDefsReloaded();
 
@@ -260,17 +277,17 @@ public:
 	 */
 	void selectionChanged(const scene::INodePtr& node, bool isComponent);
 
-	void registerPropertyEditor(const std::string& key, const IPropertyEditorPtr& editor);
-	IPropertyEditorPtr getRegisteredPropertyEditor(const std::string& key);
-	void unregisterPropertyEditor(const std::string& key);
+	void registerPropertyEditor(const std::string& key, const IPropertyEditor::CreationFunc& creator) override;
+	void unregisterPropertyEditor(const std::string& key) override;
+
+    void registerPropertyEditorDialog(const std::string& key, const IPropertyEditorDialog::CreationFunc& create) override;
+    IPropertyEditorDialog::Ptr createDialog(const std::string& key) override;
+    void unregisterPropertyEditorDialog(const std::string& key) override;
 
 	void onMainFrameConstructed();
 	void onMainFrameShuttingDown();
 
-	/* Entity::Observer implementation */
-    void onKeyInsert(const std::string& key, EntityKeyValue& value);
-    void onKeyChange(const std::string& key, const std::string& value);
-    void onKeyErase(const std::string& key, EntityKeyValue& value);
+    void onKeyChange(const std::string& key, const std::string& value, bool isMultiValue = false);
 
 	// greebo: Tells the inspector to reload the window settings from the registry.
 	void restoreSettings();
@@ -280,10 +297,11 @@ public:
 	 */
 	static void toggle(const cmd::ArgumentList& args);
 
-	// RegisterableModule implementation
-	virtual const std::string& getName() const;
-	virtual const StringSet& getDependencies() const;
-	virtual void initialiseModule(const IApplicationContext& ctx);
+    // RegisterableModule implementation
+    const std::string& getName() const override;
+    const StringSet& getDependencies() const override;
+    void initialiseModule(const IApplicationContext& ctx) override;
+    void shutdownModule() override;
 };
 
 } // namespace ui
