@@ -1,10 +1,11 @@
 #include "SoundPropertyEditor.h"
 #include "PropertyEditorFactory.h"
 
-#include "iresourcechooser.h"
-#include "idialogmanager.h"
+#include "ui/iresourcechooser.h"
+#include "ui/idialogmanager.h"
 #include "i18n.h"
 #include "ientity.h"
+#include "isound.h"
 
 #include <wx/panel.h>
 #include <wx/button.h>
@@ -14,14 +15,19 @@ namespace ui
 {
 
 // Main constructor
-SoundPropertyEditor::SoundPropertyEditor(wxWindow* parent, Entity* entity,
+SoundPropertyEditor::SoundPropertyEditor(wxWindow* parent, IEntitySelection& entities,
 									     const std::string& name,
 									     const std::string& options)
-: PropertyEditor(entity),
+: PropertyEditor(entities),
   _key(name)
 {
 	constructBrowseButtonPanel(parent, _("Choose sound..."),
 		PropertyEditorFactory::getBitmapFor("sound"));
+
+    if (!module::GlobalModuleRegistry().moduleExists(MODULE_SOUNDMANAGER))
+    {
+        getWidget()->Disable();
+    }
 }
 
 void SoundPropertyEditor::onBrowseButtonClick()
