@@ -1,7 +1,6 @@
 #include "EntityList.h"
 
-#include "ieventmanager.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "icommandsystem.h"
 
 #include "registry/Widgets.h"
