@@ -2,8 +2,9 @@
 
 #include <string>
 #include "icommandsystem.h"
-#include "wxutil/dialog/DialogBase.h"
+#include "wxutil/window/TransientWindow.h"
 #include "wxutil/XmlResourceBasedWidget.h"
+#include <sigc++/trackable.h>
 
 class wxTextCtrl;
 class wxButton;
@@ -17,9 +18,13 @@ namespace ui
  * greebo: The dialog providing the Find & Replace shader functionality.
  */
 class FindAndReplaceShader :
-	public wxutil::DialogBase,
-	private wxutil::XmlResourceBasedWidget
+	public wxutil::TransientWindow,
+	private wxutil::XmlResourceBasedWidget,
+    public sigc::trackable
 {
+private:
+    wxTextCtrl* _lastFocusedEntry;
+
 public:
 	// Constructor
 	FindAndReplaceShader();
@@ -31,6 +36,8 @@ public:
 	static void ShowDialog(const cmd::ArgumentList& args);
 
 private:
+    void onShaderClipboardChanged();
+
 	// This is called to initialise the dialog window / create the widgets
 	void populateWindow();
 
@@ -45,7 +52,12 @@ private:
 	void onChooseFind(wxCommandEvent& ev);
 	void onChooseReplace(wxCommandEvent& ev);
 
+    void onChoosePick(wxCommandEvent& ev);
+
 	void onEntryChanged(wxCommandEvent& ev);
+    void onEntryFocusChanged(wxFocusEvent& ev);
+
+    std::string getPickHelpText();
 };
 
 } // namespace ui
