@@ -2,9 +2,8 @@
 
 #include "i18n.h"
 #include "itextstream.h"
-#include "ieventmanager.h"
 #include "ilayer.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "iselection.h"
 
 #include "registry/registry.h"
