@@ -45,8 +45,6 @@ private:
 public:
 	LayerControlDialog();
 
-	void onRadiantShutdown();
-
 	// Re-populates the window
 	void refresh();
 
@@ -57,13 +55,15 @@ public:
 	static void toggle(const cmd::ArgumentList& args);
 
 	// Checks if dialog should be shown after startup
-	static void onRadiantStartup();
+	static void onMainFrameConstructed();
 
 	static LayerControlDialog& Instance();
 
 private:
 	static LayerControlDialogPtr& InstancePtr();
 
+	void onMainFrameShuttingDown();
+
 	// TransientWindow events
 	void _preShow() override;
 	void _postHide() override;
