@@ -6,7 +6,7 @@
 #include "igame.h"
 #include "ishaders.h"
 #include "iradiant.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "iselection.h"
 #include "iundo.h"
 
@@ -207,7 +207,7 @@ void LightInspector::update()
     // light entities
 
     class LightEntityFinder
-    : public SelectionSystem::Visitor
+    : public selection::SelectionSystem::Visitor
     {
         // List of light entities to add to
         EntityList& _entityList;
@@ -274,9 +274,9 @@ void LightInspector::_preShow()
     _redoHandler.disconnect();
 
     // Register self as observer to receive events
-    _undoHandler = GlobalUndoSystem().signal_postUndo().connect(
+    _undoHandler = GlobalMapModule().signal_postUndo().connect(
         sigc::mem_fun(this, &LightInspector::update));
-    _redoHandler = GlobalUndoSystem().signal_postRedo().connect(
+    _redoHandler = GlobalMapModule().signal_postRedo().connect(
         sigc::mem_fun(this, &LightInspector::update));
 
     // Register self to the SelSystem to get notified upon selection changes.
