@@ -2,11 +2,10 @@
 
 #include "i18n.h"
 #include "itextstream.h"
-#include "ieventmanager.h"
-#include "imenumanager.h"
-#include "igroupdialog.h"
-#include "imainframe.h"
-#include "ientityinspector.h"
+#include "ui/imenumanager.h"
+#include "ui/igroupdialog.h"
+#include "ui/imainframe.h"
+#include "ui/ientityinspector.h"
 
 #include <wx/sizer.h>
 #include <wx/splitter.h>
