@@ -1,11 +1,11 @@
 #include "MainFrame.h"
 
 #include "i18n.h"
-#include "igroupdialog.h"
+#include "ui/igroupdialog.h"
 #include "imap.h"
-#include "ieventmanager.h"
+#include "ui/ieventmanager.h"
 #include "ipreferencesystem.h"
-#include "ientityinspector.h"
+#include "ui/ientityinspector.h"
 #include "ieclass.h"
 #include "iorthoview.h"
 #include "iregistry.h"
@@ -21,6 +21,7 @@
 #include "ui/mainframe/ScreenUpdateBlocker.h"
 #include "ui/mainframe/AuiLayout.h"
 #include "ui/mainframe/TopLevelFrame.h"
+#include "textool/TexTool.h"
 
 #include "module/StaticModule.h"
 #include "messages/ApplicationShutdownRequest.h"
@@ -69,7 +70,6 @@ const StringSet& MainFrame::getDependencies() const
 		_dependencies.insert(MODULE_MAINFRAME_LAYOUT_MANAGER);
 		_dependencies.insert(MODULE_XMLREGISTRY);
 		_dependencies.insert(MODULE_PREFERENCESYSTEM);
-		_dependencies.insert(MODULE_EVENTMANAGER);
 		_dependencies.insert(MODULE_COMMANDSYSTEM);
 		_dependencies.insert(MODULE_ORTHOVIEWMANAGER);
 		_dependencies.insert(MODULE_ECLASSMANAGER);
@@ -524,6 +524,18 @@ void MainFrame::updateAllWindows(bool force)
     }
 
     GlobalXYWndManager().updateAllViews(force);
+
+    if (TexTool::Instance().IsShown())
+    {
+        if (force)
+        {
+            TexTool::Instance().forceRedraw();
+        }
+        else
+        {
+            TexTool::Instance().queueDraw();
+        }
+    }
 }
 
 void MainFrame::setActiveLayoutName(const std::string& name)
