@@ -1,11 +1,10 @@
 #include "RegularLayout.h"
 
 #include "itextstream.h"
-#include "ieventmanager.h"
-#include "imenumanager.h"
-#include "igroupdialog.h"
-#include "imainframe.h"
-#include "ientityinspector.h"
+#include "ui/imenumanager.h"
+#include "ui/igroupdialog.h"
+#include "ui/imainframe.h"
+#include "ui/ientityinspector.h"
 
 #include "camera/CameraWndManager.h"
 #include "camera/CamWnd.h"
