@@ -2,11 +2,11 @@
 
 #include "i18n.h"
 #include "itextstream.h"
-#include "ieventmanager.h"
-#include "imenumanager.h"
-#include "igroupdialog.h"
-#include "imainframe.h"
-#include "ientityinspector.h"
+#include "ui/ieventmanager.h"
+#include "ui/imenumanager.h"
+#include "ui/igroupdialog.h"
+#include "ui/imainframe.h"
+#include "ui/ientityinspector.h"
 
 #include "registry/registry.h"
 
