@@ -2,9 +2,9 @@
 
 #include "itextstream.h"
 #include "i18n.h"
-#include "imenumanager.h"
-#include "istatusbarmanager.h"
-#include "itoolbarmanager.h"
+#include "ui/imenumanager.h"
+#include "ui/istatusbarmanager.h"
+#include "ui/itoolbarmanager.h"
 #include "wxutil/Bitmap.h"
 #include <wx/toolbar.h>
 #include <wx/menu.h>
