@@ -1,13 +1,12 @@
 #include "MediaBrowser.h"
 
 #include "i18n.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "imap.h"
-#include "igroupdialog.h"
+#include "ui/igroupdialog.h"
 #include "ipreferencesystem.h"
 #include "ishaders.h"
 #include "ishaderclipboard.h"
-#include "ieventmanager.h"
 #include "ifavourites.h"
 
 #include "wxutil/MultiMonitor.h"
@@ -175,7 +174,6 @@ const StringSet& MediaBrowser::getDependencies() const
     static StringSet _dependencies
     {
         MODULE_COMMANDSYSTEM,
-        MODULE_EVENTMANAGER,
         MODULE_SHADERSYSTEM,
         MODULE_GROUPDIALOG,
         MODULE_SHADERCLIPBOARD,
