@@ -1,7 +1,7 @@
 #include "ParticleEditor.h"
 
 #include "i18n.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "iparticles.h"
 #include "iparticlestage.h"
 #include "igame.h"
