@@ -2,7 +2,7 @@
 
 #include "i18n.h"
 #include "itextstream.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "iundo.h"
 
 #include <wx/sizer.h>
@@ -52,9 +52,6 @@ PatchInspector::PatchInspector() :
 	// Create all the widgets and pack them into the window
 	populateWindow();
 
-	// Update the widget status
-	rescanSelection();
-
 	InitialiseWindowPosition(410, 480, RKEY_WINDOW_STATE);
 }
 
@@ -275,9 +272,9 @@ void PatchInspector::_preShow()
 	// Register self to the SelSystem to get notified upon selection changes.
 	GlobalSelectionSystem().addObserver(this);
 	
-	_undoHandler = GlobalUndoSystem().signal_postUndo().connect(
+	_undoHandler = GlobalMapModule().signal_postUndo().connect(
 		sigc::mem_fun(this, &PatchInspector::queueUpdate));
-	_redoHandler = GlobalUndoSystem().signal_postRedo().connect(
+	_redoHandler = GlobalMapModule().signal_postRedo().connect(
 		sigc::mem_fun(this, &PatchInspector::queueUpdate));
 
 	// Check for selection changes before showing the dialog again
