@@ -2,10 +2,10 @@
 #include <wx/frame.h>
 
 #include "iscript.h"
-#include "imenumanager.h"
-#include "imainframe.h"
+#include "ui/imenumanager.h"
+#include "ui/imainframe.h"
 #include "i18n.h"
-#include "igroupdialog.h"
+#include "ui/igroupdialog.h"
 #include "module/StaticModule.h"
 
 #include "ScriptMenu.h"
