@@ -2,24 +2,20 @@
 
 #include "i18n.h"
 
-#include <wx/panel.h>
-#include <wx/sizer.h>
-#include <wx/button.h>
-#include "wxutil/Bitmap.h"
-#include <wx/stattext.h>
-#include <wx/bmpbuttn.h>
-#include <wx/spinctrl.h>
-#include <wx/tglbtn.h>
+#include <wx/wx.h>
+#include <wx/statline.h>
 
 #include "iscenegraph.h"
-#include "ieventmanager.h"
+#include "ui/ieventmanager.h"
 #include "itextstream.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "iundo.h"
 
+#include "wxutil/Bitmap.h"
 #include "wxutil/ControlButton.h"
 #include "wxutil/dialog/MessageBox.h"
 #include "wxutil/Button.h"
+#include "wxutil/BitmapToggleButton.h"
 
 #include "registry/Widgets.h"
 #include "selectionlib.h"
@@ -53,20 +49,20 @@ namespace
     const char* const FOLDER_ICON = "treeView16.png";
     const char* const LABEL_STEP = N_("Step:");
 
-    const char* LABEL_FIT_TEXTURE = N_("Fit Texture:");
+    const char* LABEL_FIT_TEXTURE = N_("Fit:");
     const char* LABEL_FIT = N_("Fit");
 
-    const char* LABEL_ALIGN_TEXTURE = N_("Align Texture:");
+    const char* LABEL_ALIGN_TEXTURE = N_("Align:");
     const char* LABEL_ALIGN_TOP = N_("Top");
     const char* LABEL_ALIGN_BOTTOM = N_("Bottom");
     const char* LABEL_ALIGN_RIGHT = N_("Right");
     const char* LABEL_ALIGN_LEFT = N_("Left");
 
-    const char* LABEL_FLIP_TEXTURE = N_("Flip Texture:");
+    const char* LABEL_FLIP_TEXTURE = N_("Flip:");
     const char* LABEL_FLIPX = N_("Flip Horizontal");
     const char* LABEL_FLIPY = N_("Flip Vertical");
 
-    const char* LABEL_MODIFY_TEXTURE = N_("Modify Texture:");
+    const char* LABEL_MODIFY_TEXTURE = N_("Modify:");
     const char* LABEL_NATURAL = N_("Natural");
     const char* LABEL_NORMALISE = N_("Normalise");
 
@@ -86,6 +82,30 @@ namespace
     const std::string RKEY_WINDOW_STATE = RKEY_ROOT + "window";
 
     const double MAX_FLOAT_RESOLUTION = 1.0E-5;
+
+    // Widget minimum sizes. Different values needed on Linux (which has various
+    // GTK styles) vs Windows.
+#ifdef __WXMSW__
+    const int SPINBOX_WIDTH_CHARS = 7;
+#else
+    const int SPINBOX_WIDTH_CHARS = 16;
+#endif
+
+    // Minimum pixel size for a widget. Converts to a wxSize of the specified
+    // dimensions on Windows, and wxDefaultSize on Linux (because pixel sizes
+    // don't work with GTK themes and variable DPI)
+    struct PixelSize: public wxSize
+    {
+#if defined(__WXMSW__)
+        PixelSize(int width, int height)
+        : wxSize(width, height)
+        {}
+#else
+        PixelSize(int width, int height)
+        : wxSize(wxDefaultSize.GetX(), wxDefaultSize.GetY())
+        {}
+#endif
+    };
 }
 
 void SurfaceInspector::ManipulatorRow::setValue(double v)
@@ -196,14 +216,38 @@ void SurfaceInspector::connectEvents()
 	wxutil::button::connectToCommand(_manipulators[HSHIFT].larger, "TexShiftRight");
 	wxutil::button::connectToCommand(_manipulators[VSHIFT].larger, "TexShiftUp");
 	wxutil::button::connectToCommand(_manipulators[VSHIFT].smaller, "TexShiftDown");
-	wxutil::button::connectToCommand(_manipulators[HSCALE].smaller, "TexScaleLeft");
-	wxutil::button::connectToCommand(_manipulators[HSCALE].larger, "TexScaleRight");
-	wxutil::button::connectToCommand(_manipulators[VSCALE].larger, "TexScaleUp");
-	wxutil::button::connectToCommand(_manipulators[VSCALE].smaller, "TexScaleDown");
+
+    _manipulators[HSCALE].smaller->Bind(wxEVT_BUTTON, [this](wxCommandEvent&) { onScale(HSCALE, false); });
+    _manipulators[HSCALE].larger->Bind(wxEVT_BUTTON, [this](wxCommandEvent&) { onScale(HSCALE, true); });
+    _manipulators[VSCALE].smaller->Bind(wxEVT_BUTTON, [this](wxCommandEvent&) { onScale(VSCALE, true); });
+    _manipulators[VSCALE].larger->Bind(wxEVT_BUTTON, [this](wxCommandEvent&) { onScale(VSCALE, false); });
+
 	wxutil::button::connectToCommand(_manipulators[ROTATION].larger, "TexRotateClock");
 	wxutil::button::connectToCommand(_manipulators[ROTATION].smaller, "TexRotateCounter");
 }
 
+void SurfaceInspector::onScale(const std::string& scaleId, bool larger)
+{
+    if (_scaleLinkToggle->GetValue())
+    {
+        auto scaleValue = string::convert<float>(_manipulators[HSCALE].stepEntry->GetValue().ToStdString());
+        scaleValue *= larger ? -1 : 1;
+
+        GlobalCommandSystem().executeCommand("TexScale", Vector2(scaleValue, scaleValue));
+    }
+    else
+    {
+        if (scaleId == HSCALE)
+        {
+            GlobalCommandSystem().executeCommand(larger ? "TexScaleLeft" : "TexScaleRight");
+        }
+        else
+        {
+            GlobalCommandSystem().executeCommand(larger ? "TexScaleUp" : "TexScaleDown");
+        }
+    }
+}
+
 void SurfaceInspector::keyChanged()
 {
 	// Avoid callback loops
@@ -223,21 +267,24 @@ wxSpinCtrlDouble* SurfaceInspector::makeFitSpinBox(Axis axis)
     wxSpinCtrlDouble* box = new wxSpinCtrlDouble(this, wxID_ANY);
 
     // Set visual parameters
-    box->SetMinSize(wxSize(box->GetCharWidth() * 16, -1));
-    box->SetRange(1.0, 1000.0);
+    box->SetMinSize(wxSize(box->GetCharWidth() * SPINBOX_WIDTH_CHARS, -1));
+    box->SetRange(0.0, 1000.0);
     box->SetIncrement(1.0);
     box->SetValue(1.0);
     box->SetDigits(2);
 
     // Perform a fit operation when the value changes
-    box->Bind(wxEVT_SPINCTRLDOUBLE, [=](wxSpinDoubleEvent&) { onFit(axis); });
+    box->Bind(wxEVT_SPINCTRLDOUBLE, [=](wxSpinDoubleEvent& e) {
+                  if (e.GetValue() > 0)
+                      onFit(axis);
+              });
 
     return box;
 }
 
 wxBoxSizer* SurfaceInspector::createFitTextureRow()
 {
-	wxBoxSizer* fitTextureHBox = new wxBoxSizer(wxHORIZONTAL);
+	auto* fitTextureHBox = new wxBoxSizer(wxHORIZONTAL);
 
     // Create widgets from left to right
 	_fitTexture.label = new wxStaticText(this, wxID_ANY, _(LABEL_FIT_TEXTURE));
@@ -265,18 +312,52 @@ wxBoxSizer* SurfaceInspector::createFitTextureRow()
           "other axis automatically to preserve texture aspect ratio")
     );
 
+    _fitTexture.preserveAspectButton->SetMinSize(PixelSize(30, -1));
+    _fitTexture.fitButton->SetMinSize(PixelSize(30, -1));
+
     // Add widgets to the sizer
-    fitTextureHBox->Add(_fitTexture.width, 1, wxALIGN_CENTER_VERTICAL);
-    fitTextureHBox->Add(_fitTexture.x, 0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 3);
-    fitTextureHBox->Add(_fitTexture.height, 1, wxALIGN_CENTER_VERTICAL);
-    fitTextureHBox->Add(_fitTexture.preserveAspectButton, 0,
-                        wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
-    fitTextureHBox->Add(_fitTexture.fitButton, 1,
-                        wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
+    auto* widthTimesHeight = new wxBoxSizer(wxHORIZONTAL);
+
+    widthTimesHeight->Add(_fitTexture.width, 1, wxALIGN_CENTER_VERTICAL);
+    widthTimesHeight->Add(_fitTexture.x, 0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 3);
+    widthTimesHeight->Add(_fitTexture.height, 1, wxALIGN_CENTER_VERTICAL);
+
+    fitTextureHBox->Add(widthTimesHeight, 1, wxALIGN_CENTER_VERTICAL);
+    fitTextureHBox->Add(_fitTexture.preserveAspectButton, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
+    fitTextureHBox->Add(_fitTexture.fitButton, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
 
     return fitTextureHBox;
 }
 
+void SurfaceInspector::createScaleLinkButtons(wxutil::FormLayout& table)
+{
+    auto scaleLinkSizer = new wxBoxSizer(wxHORIZONTAL);
+
+    _useHorizScale = new wxBitmapButton(this, wxID_ANY,
+                                        wxutil::GetLocalBitmap("link_scale_down.png"));
+    _useHorizScale->SetToolTip(_("Assign horizontal scale to vertical scale"));
+    scaleLinkSizer->Add(_useHorizScale, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 0);
+
+    _useVertScale = new wxBitmapButton(this, wxID_ANY,
+                                       wxutil::GetLocalBitmap("link_scale_up.png"));
+    _useVertScale->SetToolTip(_("Assign vertical scale to horizontal scale"));
+    scaleLinkSizer->Add(_useVertScale, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
+
+    _useHorizScale->Bind(wxEVT_BUTTON, [&](wxCommandEvent& ev) { onHarmoniseScale(true); });
+    _useVertScale->Bind(wxEVT_BUTTON, [&](wxCommandEvent& ev) { onHarmoniseScale(false); });
+
+    auto linkToggle = new wxutil::BitmapToggleButton(this,
+                                                     wxutil::GetLocalBitmap("link_active.png"),
+                                                     wxutil::GetLocalBitmap("link_inactive.png"));
+    linkToggle->SetToolTip(_("Linked Scaling: when active, scale changes will affect horizontal "
+                             "and vertical values proportionally"));
+    linkToggle->SetMaxClientSize(wxSize(35, -1));
+    _scaleLinkToggle = linkToggle;
+    scaleLinkSizer->Add(_scaleLinkToggle, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
+
+    table.add(scaleLinkSizer);
+}
+
 void SurfaceInspector::populateWindow()
 {
 	wxBoxSizer* dialogVBox = new wxBoxSizer(wxVERTICAL);
@@ -285,16 +366,11 @@ void SurfaceInspector::populateWindow()
 	wxStaticText* topLabel = new wxStaticText(this, wxID_ANY, _(LABEL_PROPERTIES));
 	topLabel->SetFont(topLabel->GetFont().Bold());
 
-	// 6x2 table with 12 pixel hspacing and 6 pixels vspacing
-	wxFlexGridSizer* table = new wxFlexGridSizer(6, 2, 6, 12);
-	table->AddGrowableCol(1);
-
-	// Create the entry field and pack it into the first table row
-	wxStaticText* shaderLabel = new wxStaticText(this, wxID_ANY, _(LABEL_SHADER));
-	table->Add(shaderLabel, 0, wxALIGN_CENTER_VERTICAL);
+    // Two-column form layout
+	wxutil::FormLayout table(this);
 
+    // Shader entry box
 	wxBoxSizer* shaderHBox = new wxBoxSizer(wxHORIZONTAL);
-
 	_shaderEntry = new wxTextCtrl(this, wxID_ANY, "", wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER);
 	_shaderEntry->SetMinSize(wxSize(100, -1));
 	_shaderEntry->Connect(wxEVT_TEXT_ENTER, wxCommandEventHandler(SurfaceInspector::onShaderEntryActivate), NULL, this);
@@ -308,25 +384,33 @@ void SurfaceInspector::populateWindow()
         _("Choose shader using the shader selection dialog"))
     ;
     _selectShaderButton->Connect(
-        wxEVT_BUTTON, wxCommandEventHandler(SurfaceInspector::onShaderSelect),
-        NULL, this
+        wxEVT_BUTTON, wxCommandEventHandler(SurfaceInspector::onShaderSelect), NULL, this
     );
     shaderHBox->Add(_selectShaderButton, 0, wxLEFT, 6);
 
-	table->Add(shaderHBox, 1, wxEXPAND);
+	table.add(_(LABEL_SHADER), shaderHBox);
 
 	// Pack everything into the vbox
 	dialogVBox->Add(topLabel, 0, wxEXPAND | wxBOTTOM, 6);
-	dialogVBox->Add(table, 0, wxEXPAND | wxLEFT, 18); // 18 pixels left indentation
+	dialogVBox->Add(table.getSizer(), 0, wxEXPAND | wxLEFT, 18); // 18 pixels left indentation
 
-	// Populate the table with the according widgets
-	_manipulators[HSHIFT] = createManipulatorRow(this, _(LABEL_HSHIFT), table);
-	_manipulators[VSHIFT] = createManipulatorRow(this, _(LABEL_VSHIFT), table);
-	_manipulators[HSCALE] = createManipulatorRow(this, _(LABEL_HSCALE), table);
-	_manipulators[VSCALE] = createManipulatorRow(this, _(LABEL_VSCALE), table);
-	_manipulators[ROTATION] = createManipulatorRow(this, _(LABEL_ROTATION), table);
+	// Initial parameter editing rows
+    _manipulators[HSHIFT] = createManipulatorRow(_(LABEL_HSHIFT), table, "arrow_left_blue.png",
+                                                 "arrow_right_blue.png");
+    _manipulators[VSHIFT] = createManipulatorRow(_(LABEL_VSHIFT), table, "arrow_down_blue.png",
+                                                 "arrow_up_blue.png");
+    _manipulators[ROTATION] = createManipulatorRow(_(LABEL_ROTATION), table, "rotate_cw.png",
+                                                   "rotate_ccw.png");
 
-	// ======================== Texture Operations ====================================
+    // Scale rows separated by a line
+    table.addFullWidth(new wxStaticLine(this));
+    _manipulators[HSCALE] = createManipulatorRow(_(LABEL_HSCALE), table, "hscale_down.png",
+                                                 "hscale_up.png");
+    createScaleLinkButtons(table);
+    _manipulators[VSCALE] = createManipulatorRow(_(LABEL_VSCALE), table, "vscale_down.png",
+                                                 "vscale_up.png");
+
+    // ======================== Texture Operations ====================================
 
 	// Create the texture operations label (bold font)
 	wxStaticText* operLabel = new wxStaticText(this, wxID_ANY, _(LABEL_OPERATIONS));
@@ -338,6 +422,7 @@ void SurfaceInspector::populateWindow()
 	operTable->AddGrowableCol(1);
 
     // Pack label & table into the dialog
+    dialogVBox->AddSpacer(6);
 	dialogVBox->Add(operLabel, 0, wxEXPAND | wxTOP | wxBOTTOM, 6);
 	dialogVBox->Add(operTable, 0, wxEXPAND | wxLEFT, 18); // 18 pixels left indentation
 
@@ -356,7 +441,12 @@ void SurfaceInspector::populateWindow()
 	_alignTexture.left = new wxButton(this, wxID_ANY, _(LABEL_ALIGN_LEFT));
 	_alignTexture.right = new wxButton(this, wxID_ANY, _(LABEL_ALIGN_RIGHT));
 
-	wxGridSizer* alignTextureBox = new wxGridSizer(1, 4, 0, 6);
+    _alignTexture.top->SetMinSize(PixelSize(20, -1));
+    _alignTexture.bottom->SetMinSize(PixelSize(20, -1));
+    _alignTexture.left->SetMinSize(PixelSize(20, -1));
+    _alignTexture.right->SetMinSize(PixelSize(20, -1));
+
+	auto* alignTextureBox = new wxGridSizer(1, 4, 0, 6);
 
 	alignTextureBox->Add(_alignTexture.top, 1, wxEXPAND);
 	alignTextureBox->Add(_alignTexture.bottom, 1, wxEXPAND);
@@ -401,7 +491,7 @@ void SurfaceInspector::populateWindow()
 	wxStaticText* defaultScaleLabel = new wxStaticText(this, wxID_ANY, _(LABEL_DEFAULT_SCALE));
 
 	_defaultTexScale = new wxSpinCtrlDouble(this, wxID_ANY);
-	_defaultTexScale->SetMinSize(wxSize(55, -1));
+	_defaultTexScale->SetMinSize(wxSize(50, -1));
 	_defaultTexScale->SetRange(0.0, 1000.0);
 	_defaultTexScale->SetIncrement(0.1);
 	_defaultTexScale->SetDigits(3);
@@ -425,36 +515,34 @@ void SurfaceInspector::populateWindow()
 	SetSizerAndFit(border);
 }
 
-SurfaceInspector::ManipulatorRow SurfaceInspector::createManipulatorRow(
-	wxWindow* parent, const std::string& label, wxFlexGridSizer* table)
+SurfaceInspector::ManipulatorRow
+SurfaceInspector::createManipulatorRow(const std::string& label, wxutil::FormLayout& table,
+                                       const std::string& bitmapSmaller,
+                                       const std::string& bitmapLarger)
 {
 	ManipulatorRow manipRow;
 
-	wxStaticText* text = new wxStaticText(parent, wxID_ANY, label);
-	table->Add(text, 0, wxALIGN_CENTER_VERTICAL);
-
 	wxBoxSizer* hbox = new wxBoxSizer(wxHORIZONTAL);
 
 	// Create the entry field
-	manipRow.value = new wxTextCtrl(parent, wxID_ANY, "", wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER);
-	manipRow.value->SetMinSize(wxSize(60, -1));
-	manipRow.value->Connect(wxEVT_TEXT_ENTER, wxCommandEventHandler(SurfaceInspector::onValueEntryActivate), NULL, this);
+	manipRow.value = new wxTextCtrl(this, wxID_ANY, "", wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER);
+	manipRow.value->SetMinSize(PixelSize(50, -1));
+	manipRow.value->Bind(wxEVT_TEXT_ENTER, &SurfaceInspector::onValueEntryActivate, this);
 
     // Create the nudge buttons
 	wxBoxSizer* controlButtonBox = new wxBoxSizer(wxHORIZONTAL);
-    manipRow.smaller = new wxutil::ControlButton(parent,
-        wxutil::GetLocalBitmap("arrow_left.png"));
-    controlButtonBox->Add(manipRow.smaller, 0);
+    manipRow.smaller = new wxutil::ControlButton(this, wxutil::GetLocalBitmap(bitmapSmaller));
+    controlButtonBox->Add(manipRow.smaller, 0, wxEXPAND);
     controlButtonBox->AddSpacer(2);
-    manipRow.larger = new wxutil::ControlButton(parent,
-        wxutil::GetLocalBitmap("arrow_right.png"));
-    controlButtonBox->Add(manipRow.larger, 0);
+    manipRow.larger = new wxutil::ControlButton(this, wxutil::GetLocalBitmap(bitmapLarger));
+    controlButtonBox->Add(manipRow.larger, 0, wxEXPAND);
 
 	// Create the label
-	wxStaticText* steplabel = new wxStaticText(parent, wxID_ANY, _(LABEL_STEP));
+	wxStaticText* steplabel = new wxStaticText(this, wxID_ANY, _(LABEL_STEP));
 
 	// Create the entry field
-	manipRow.stepEntry = new wxTextCtrl(parent, wxID_ANY, "");
+	manipRow.stepEntry = new wxTextCtrl(this, wxID_ANY, "");
+    manipRow.stepEntry->SetMinSize(PixelSize(30, -1));
 
 	// Arrange all items in a row
     hbox->Add(manipRow.value, 1, wxALIGN_CENTER_VERTICAL);
@@ -463,7 +551,7 @@ SurfaceInspector::ManipulatorRow SurfaceInspector::createManipulatorRow(
 	hbox->Add(manipRow.stepEntry, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 6);
 
 	// Pack the hbox into the table
-	table->Add(hbox, 1, wxEXPAND);
+    table.add(label, hbox);
 
 	// Return the filled structure
 	return manipRow;
@@ -487,6 +575,25 @@ SurfaceInspector& SurfaceInspector::Instance()
 	return *instancePtr;
 }
 
+void SurfaceInspector::onHarmoniseScale(bool useHorizontal)
+{
+    auto horizValue = _manipulators[HSCALE].value->GetValue();
+    auto vertValue = _manipulators[VSCALE].value->GetValue();
+
+    if (horizValue == vertValue) return; // nothing to do
+
+    if (useHorizontal)
+    {
+        _manipulators[VSCALE].value->SetValue(horizValue);
+    }
+    else
+    {
+        _manipulators[HSCALE].value->SetValue(vertValue);
+    }
+
+    emitTexDef();
+}
+
 void SurfaceInspector::emitShader()
 {
 	// Apply it to the selection
@@ -510,13 +617,6 @@ void SurfaceInspector::emitTexDef()
 	{
 		face.setShiftScaleRotation(shiftScaleRotate);
 	});
-
-	SceneChangeNotify();
-
-	// Update the Texture Tools
-	radiant::TextureChangedMessage::Send();
-	// Update the TexTool instance as well
-	ui::TexTool::Instance().draw();
 }
 
 void SurfaceInspector::updateTexDef()
@@ -583,9 +683,14 @@ void SurfaceInspector::doUpdate()
 	_manipulators[VSCALE].value->Enable(valueSensitivity);
 	_manipulators[ROTATION].value->Enable(valueSensitivity);
 
-	// The fit widget sensitivity
+    _useHorizScale->Enable(valueSensitivity);
+    _useVertScale->Enable(valueSensitivity);
+
+    // The fit widget sensitivity
     _fitTexture.enable(haveSelection);
 
+    _scaleLinkToggle->Enable(haveSelection);
+
 	// The align texture widget sensitivity
 	_alignTexture.bottom->Enable(haveSelection);
 	_alignTexture.left->Enable(haveSelection);
@@ -610,10 +715,6 @@ void SurfaceInspector::doUpdate()
 	{
 		updateTexDef();
 	}
-
-	// Update the TexTool instance as well
-	ui::TexTool::Instance().draw();
-	ui::PatchInspector::Instance().queueUpdate();
 }
 
 void SurfaceInspector::fitTexture(Axis axis)
@@ -730,9 +831,9 @@ void SurfaceInspector::_preShow()
 	_selectionChanged = GlobalSelectionSystem().signal_selectionChanged().connect(
 		[this] (const ISelectable&) { doUpdate(); });
 
-	_undoHandler = GlobalUndoSystem().signal_postUndo().connect(
+	_undoHandler = GlobalMapModule().signal_postUndo().connect(
 		sigc::mem_fun(this, &SurfaceInspector::doUpdate));
-	_redoHandler = GlobalUndoSystem().signal_postRedo().connect(
+	_redoHandler = GlobalMapModule().signal_postRedo().connect(
 		sigc::mem_fun(this, &SurfaceInspector::doUpdate));
 
 	// Get notified about texture changes
