@@ -5,6 +5,7 @@
 #include "iregistry.h"
 #include "iradiant.h"
 #include "wxutil/window/TransientWindow.h"
+#include "wxutil/FormLayout.h"
 #include "ui/common/ShaderChooser.h"
 #include "messages/TextureChanged.h"
 
@@ -92,6 +93,9 @@ class SurfaceInspector :
 
 	wxSpinCtrlDouble* _defaultTexScale;
 	wxToggleButton* _texLockButton;
+    wxButton* _useHorizScale;
+    wxToggleButton* _scaleLinkToggle;
+    wxButton* _useVertScale;
 
 	// To avoid key changed loopbacks when the registry is updated
 	bool _callbackActive;
@@ -141,12 +145,14 @@ private:
 	 *
 	 * @returns: the structure containing the widget pointers.
 	 */
-	ManipulatorRow createManipulatorRow(wxWindow* parent,
-		const std::string& label, wxFlexGridSizer* table);
+    ManipulatorRow createManipulatorRow(const std::string& label, wxutil::FormLayout& table,
+                                        const std::string& bitmapSmaller,
+                                        const std::string& bitmapLarger);
 
     // Widget construction
 	void populateWindow();
     wxBoxSizer* createFitTextureRow();
+    void createScaleLinkButtons(wxutil::FormLayout& table);
 
 	// Connect IEvents to the widgets
 	void connectEvents();
@@ -183,6 +189,9 @@ private:
 
 	void handleTextureChangedMessage(radiant::TextureChangedMessage& msg);
 
+    void onScale(const std::string& scaleId, bool larger);
+    void onHarmoniseScale(bool useHorizontal);
+
 }; // class SurfaceInspector
 
 } // namespace
