@@ -1,16 +1,15 @@
 #include "TextureBrowser.h"
 
 #include "i18n.h"
-#include "ieventmanager.h"
 #include "itextstream.h"
-#include "imainframe.h"
-#include "itoolbarmanager.h"
+#include "ui/imainframe.h"
+#include "ui/itoolbarmanager.h"
 #include "icolourscheme.h"
-#include "igroupdialog.h"
+#include "ui/igroupdialog.h"
 #include "iradiant.h"
 #include "ifavourites.h"
 #include "ipreferencesystem.h"
-#include "imediabrowser.h"
+#include "ui/imediabrowser.h"
 #include "ishaderclipboard.h"
 
 #include "wxutil/menu/IconTextMenuItem.h"
@@ -23,6 +22,7 @@
 #include "shaderlib.h"
 
 #include "string/predicate.h"
+#include "string/split.h"
 #include <functional>
 
 #include <wx/panel.h>
@@ -72,7 +72,7 @@ public:
         return _owner.materialIsVisible(material);
     }
 
-    void render()
+    void render(bool drawName)
     {
         if (!isVisible())
         {
@@ -88,7 +88,8 @@ public:
         {
             drawBorder();
             drawTextureQuad(texture->getGLTexNum());
-            drawTextureName();
+            if (drawName)
+                drawTextureName();
         }
     }
 
@@ -226,6 +227,7 @@ TextureBrowser::TextureBrowser(wxWindow* parent) :
     _showTextureScrollbar(registry::getValue<bool>(RKEY_TEXTURE_SHOW_SCROLLBAR)),
     _hideUnused(registry::getValue<bool>(RKEY_TEXTURES_HIDE_UNUSED)),
     _showFavouritesOnly(registry::getValue<bool>(RKEY_TEXTURES_SHOW_FAVOURITES_ONLY)),
+    _showNamesKey(RKEY_TEXTURES_SHOW_NAMES),
     _textureScale(50),
     _useUniformScale(registry::getValue<bool>(RKEY_TEXTURE_USE_UNIFORM_SCALE)),
     _showOtherMaterials(registry::getValue<bool>(RKEY_TEXTURES_SHOW_OTHER_MATERIALS)),
@@ -253,7 +255,7 @@ TextureBrowser::TextureBrowser(wxWindow* parent) :
     _popupMenu->addItem(_shaderLabel, []() {}, []()->bool { return false; }); // always insensitive
 
     // Construct the popup context menu
-    _seekInMediaBrowser = new wxutil::IconTextMenuItem(_(SEEK_IN_MEDIA_BROWSER_TEXT), 
+    _seekInMediaBrowser = new wxutil::IconTextMenuItem(_(SEEK_IN_MEDIA_BROWSER_TEXT),
 		TEXTURE_ICON);
 
     _popupMenu->addItem(_seekInMediaBrowser,
@@ -318,6 +320,7 @@ TextureBrowser::TextureBrowser(wxWindow* parent) :
 
         _wxGLWidget->Bind(wxEVT_SIZE, &TextureBrowser::onGLResize, this);
         _wxGLWidget->Bind(wxEVT_MOUSEWHEEL, &TextureBrowser::onGLMouseScroll, this);
+        _wxGLWidget->Bind(wxEVT_MOTION, [=](wxMouseEvent& e) { SetToolTip("Moved"); });
 
         _wxGLWidget->Bind(wxEVT_LEFT_DOWN, &TextureBrowser::onGLMouseButtonPress, this);
         _wxGLWidget->Bind(wxEVT_LEFT_DCLICK, &TextureBrowser::onGLMouseButtonPress, this);
@@ -473,7 +476,7 @@ int TextureBrowser::getTextureWidth(const Texture& tex) const
     else
     {
         // Otherwise, preserve the texture's aspect ratio
-        return static_cast<int>(_uniformTextureSize * 
+        return static_cast<int>(_uniformTextureSize *
             (static_cast<float>(tex.getWidth()) / tex.getHeight())
         );
     }
@@ -589,10 +592,11 @@ bool TextureBrowser::materialIsVisible(const MaterialPtr& material)
         return false;
     }
 
-    if (!getFilter().empty())
+    auto filterText = getFilter();
+
+    if (!filterText.empty())
     {
-        std::string textureNameCache(materialName);
-        std::string textureName = shader_get_textureName(textureNameCache.c_str()); // can't use temporary material->getName() here
+        std::string textureName = shader_get_textureName(materialName.c_str());
 
 		if (_filterIgnoresTexturePath)
         {
@@ -606,9 +610,20 @@ bool TextureBrowser::materialIsVisible(const MaterialPtr& material)
 
 		string::to_lower(textureName);
 
+        // Split the filter text into words, every word must match (#5738)
+        std::vector<std::string> filters;
+        string::split(filters, string::to_lower_copy(filterText), " ");
+
 		// case insensitive substring match
-		if (textureName.find(string::to_lower_copy(getFilter())) == std::string::npos)
-			return false;
+        for (const auto& filter : filters)
+        {
+            if (textureName.find(filter) == std::string::npos)
+            {
+                return false;
+            }
+        }
+		
+		return true;
     }
 
     return true;
@@ -787,10 +802,10 @@ void TextureBrowser::draw()
     Vector3 colorBackground = GlobalColourSchemeManager().getColour("texture_background");
     glClearColor(colorBackground[0], colorBackground[1], colorBackground[2], 0);
     glViewport(0, 0, _viewportSize.x(), _viewportSize.y());
-    
+
 	glMatrixMode(GL_MODELVIEW);
 	glLoadIdentity();
-	
+
 	glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
 
@@ -807,7 +822,7 @@ void TextureBrowser::draw()
 
     for (TextureTile& tile : _tiles)
     {
-        tile.render();
+        tile.render(_showNamesKey.get());
     }
 
 	debug::assertNoGlErrors();
@@ -960,7 +975,7 @@ void TextureBrowser::onGLMouseButtonPress(wxMouseEvent& ev)
 {
 	if (ev.RightDown())
     {
-        _freezePointer.startCapture(_wxGLWidget, 
+        _freezePointer.startCapture(_wxGLWidget,
 			std::bind(&TextureBrowser::onFrozenMouseMotion, this, std::placeholders::_1, std::placeholders::_2, std::placeholders::_3),
 			std::bind(&TextureBrowser::onFrozenMouseCaptureLost, this));
 
