@@ -3,13 +3,12 @@
 #include "i18n.h"
 #include "iscenegraph.h"
 #include "iundo.h"
-#include "ieventmanager.h"
-#include "imainframe.h"
+#include "ui/imainframe.h"
 #include "icolourscheme.h"
 #include "ientity.h"
 #include "igrid.h"
 #include "iregion.h"
-#include "istatusbarmanager.h"
+#include "ui/istatusbarmanager.h"
 
 #include "wxutil/MouseButton.h"
 #include "wxutil/GLWidget.h"
@@ -50,7 +49,9 @@ double two_to_the_power(int power) {
     return pow(2.0f, power);
 }
 
-inline float screen_normalised(int pos, unsigned int size) {
+// Converts a pixel dimensions into device coords, maps [0..size] to [-1..+1]
+inline float screen_normalised(int pos, unsigned int size)
+{
     return ((2.0f * pos) / size) - 1.0f;
 }
 
@@ -172,7 +173,8 @@ void XYWnd::destroyXYView()
     _wxGLWidget = nullptr;
 }
 
-void XYWnd::setScale(float f) {
+void XYWnd::setScale(float f) 
+{
     _scale = f;
     updateProjection();
     updateModelview();
@@ -327,11 +329,11 @@ void XYWnd::setOrigin(const Vector3& origin) {
     queueDraw();
 }
 
-void XYWnd::scroll(int x, int y)
+void XYWnd::scrollByPixels(int x, int y)
 {
     int nDim1 = (_viewType == YZ) ? 1 : 0;
     int nDim2 = (_viewType == XY) ? 1 : 2;
-    _origin[nDim1] += x / _scale;
+    _origin[nDim1] -= x / _scale;
     _origin[nDim2] += y / _scale;
     updateModelview();
     queueDraw();
@@ -344,9 +346,7 @@ void XYWnd::scroll(int x, int y)
 void XYWnd::performChaseMouse()
 {
 	float multiplier = _chaseMouseTimer.Time() / 10.0f;
-	scroll(float_to_integer(multiplier * _chasemouseDeltaX), float_to_integer(multiplier * -_chasemouseDeltaY));
-
-	//rMessage() << "chasemouse: multiplier=" << multiplier << " x=" << _chasemouseDeltaX << " y=" << _chasemouseDeltaY << std::endl;
+    scrollByPixels(float_to_integer(-multiplier * _chasemouseDeltaX), float_to_integer(multiplier * -_chasemouseDeltaY));
 
 	handleGLMouseMotion(_chasemouseCurrentX, _chasemouseCurrentY, _eventState, false);
 
@@ -1546,32 +1546,52 @@ void XYWnd::mouseToPoint(int x, int y, Vector3& point)
 // NOTE: the zoom out factor is 4/5, we could think about customizing it
 //  we don't go below a zoom factor corresponding to 10% of the max world size
 //  (this has to be computed against the window size)
+float XYWnd::getZoomedScale(int steps)
+{
+    const float min_scale = std::min(getWidth(), getHeight()) / (1.1f * (_maxWorldCoord - _minWorldCoord));
+    const float max_scale = GlobalXYWnd().maxZoomFactor();
+    const float fZoom = pow(5.0f / 4.0f, steps);
+    const float scale = getScale() * fZoom;
+
+    if (scale > max_scale)
+    {
+        return max_scale;
+    }
+
+    if (scale < min_scale)
+    {
+        return min_scale;
+    }
+
+    return scale;
+}
+
 void XYWnd::zoomOut()
 {
-    float min_scale = std::min(getWidth(),getHeight()) / ( 1.1f * (_maxWorldCoord - _minWorldCoord));
-    float scale = getScale() * 4.0f / 5.0f;
-    if (scale < min_scale) {
-        if (getScale() != min_scale) {
-            setScale(min_scale);
-        }
-    } else {
-        setScale(scale);
-    }
+    setScale( getZoomedScale( -1 ) );
 }
 
 void XYWnd::zoomIn()
 {
-    float max_scale = GlobalXYWnd().maxZoomFactor();
-    float scale = getScale() * 5.0f / 4.0f;
+    setScale( getZoomedScale( 1 ) );
+}
 
-    if (scale > max_scale) {
-        if (getScale() != max_scale) {
-            setScale(max_scale);
-        }
-    }
-    else {
-        setScale(scale);
-    }
+void XYWnd::zoomInOn(wxPoint cursor, int zoom)
+{
+    const float newScale = getZoomedScale(zoom);
+
+    int dim1 = _viewType == YZ ? 1 : 0;
+    int dim2 = _viewType == XY ? 1 : 2;
+
+    // worldPos = origin + devicePos * device2WorldScale
+    // devicePos and worldPos should remain constant. device2WorldScale is known before 
+    // and after zooming, so the origin delta can be calculated from what we have
+    auto scaleAdjustment = (1 / _scale - 1 / newScale);
+
+    _origin[dim1] += screen_normalised(cursor.x, _width) * _width / 2 * scaleAdjustment;
+    _origin[dim2] -= screen_normalised(cursor.y, _height) * _height / 2 * scaleAdjustment;
+
+    setScale(newScale);
 }
 
 // ================ CALLBACKS ======================================
@@ -1621,6 +1641,17 @@ bool XYWnd::onRender()
 
 void XYWnd::onGLWindowScroll(wxMouseEvent& ev)
 {
+    if (!ev.ShiftDown() && GlobalXYWnd().zoomCenteredOnMouseCursor())
+    {
+        // The mouse position passed in the scroll event is not accurate on some systems,
+        // it fails to send widget-relative coordinates (even got negative numbers, see #5792)
+        // Translate the mouse coordinates on our own
+        auto clientPos = _wxGLWidget->ScreenToClient(wxGetMousePosition());
+
+        zoomInOn(clientPos, ev.GetWheelRotation() > 0 ? 1 : -1);
+        return;
+    }
+
 	if (ev.GetWheelRotation() > 0)
 	{
 		zoomIn();
