@@ -9,6 +9,7 @@
 #include "log/LogStream.h"
 #include "log/LogWriter.h"
 #include "log/LogFile.h"
+#include "log/SegFaultHandler.h"
 #include "module/StaticModule.h"
 #include "messagebus/MessageBus.h"
 #include "settings/LanguageManager.h"
@@ -35,6 +36,10 @@ Radiant::Radiant(IApplicationContext& context) :
 	// Attach the logfile to the logwriter
 	createLogFile();
 
+#ifdef POSIX
+    applog::SegFaultHandler::Install();
+#endif
+
 	_moduleRegistry.reset(new module::ModuleRegistry(_context));
 
 	_languageManager.reset(new language::LanguageManager);
