@@ -38,7 +38,6 @@ namespace {
 Brush::Brush(BrushNode& owner) :
     _owner(owner),
     _undoStateSaver(nullptr),
-    _mapFileChangeTracker(nullptr),
     _faceCentroidPoints(GL_POINTS),
     _uniqueVertexPoints(GL_POINTS),
     _uniqueEdgePoints(GL_POINTS),
@@ -54,7 +53,6 @@ Brush::Brush(BrushNode& owner) :
 Brush::Brush(BrushNode& owner, const Brush& other) :
     _owner(owner),
     _undoStateSaver(nullptr),
-    _mapFileChangeTracker(nullptr),
     _faceCentroidPoints(GL_POINTS),
     _uniqueVertexPoints(GL_POINTS),
     _uniqueEdgePoints(GL_POINTS),
@@ -96,11 +94,11 @@ IFace& Brush::addFace(const Plane3& plane)
     return *m_faces.back();
 }
 
-IFace& Brush::addFace(const Plane3& plane, const Matrix4& texDef, const std::string& shader)
+IFace& Brush::addFace(const Plane3& plane, const Matrix3& textureProjection, const std::string& material)
 {
     // Allocate a new Face
     undoSave();
-    push_back(FacePtr(new Face(*this, plane, texDef, shader)));
+    push_back(FacePtr(new Face(*this, plane, textureProjection, material)));
 
     return *m_faces.back();
 }
@@ -144,29 +142,24 @@ void Brush::forEachVisibleFace(const std::function<void(Face&)>& functor) const
     }
 }
 
-void Brush::connectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Brush::connectUndoSystem(IUndoSystem& undoSystem)
 {
     assert(_undoStateSaver == nullptr);
 
-    // Keep a reference around, we need it when faces are changing
-    _mapFileChangeTracker = &changeTracker;
+	_undoStateSaver = undoSystem.getStateSaver(*this);
 
-	_undoStateSaver = GlobalUndoSystem().getStateSaver(*this, changeTracker);
-
-    // Notify each face that we have a tracker
-    forEachFace([&](Face& face) { face.connectUndoSystem(changeTracker); });
+    forEachFace([&](Face& face) { face.connectUndoSystem(undoSystem); });
 }
 
-void Brush::disconnectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Brush::disconnectUndoSystem(IUndoSystem& undoSystem)
 {
     assert(_undoStateSaver != nullptr);
 
     // Notify each face
-    forEachFace([&](Face& face) { face.disconnectUndoSystem(changeTracker); });
+    forEachFace([&](Face& face) { face.disconnectUndoSystem(undoSystem); });
 
-    _mapFileChangeTracker = nullptr;
     _undoStateSaver = nullptr;
-    GlobalUndoSystem().releaseStateSaver(*this);
+    undoSystem.releaseStateSaver(*this);
 }
 
 void Brush::setShader(const std::string& newShader) {
@@ -270,18 +263,18 @@ const AABB& Brush::localAABB() const {
     return m_aabb_local;
 }
 
-void Brush::renderComponents(SelectionSystem::EComponentMode mode, RenderableCollector& collector,
+void Brush::renderComponents(selection::ComponentSelectionMode mode, RenderableCollector& collector,
 	const VolumeTest& volume, const Matrix4& localToWorld) const
 {
     switch (mode)
 	{
-        case SelectionSystem::eVertex:
+        case selection::ComponentSelectionMode::Vertex:
             collector.addRenderable(*m_state_point, _uniqueVertexPoints, localToWorld);
             break;
-        case SelectionSystem::eEdge:
+        case selection::ComponentSelectionMode::Edge:
             collector.addRenderable(*m_state_point, _uniqueEdgePoints, localToWorld);
             break;
-        case SelectionSystem::eFace:
+        case selection::ComponentSelectionMode::Face:
             collector.addRenderable(*m_state_point, _faceCentroidPoints, localToWorld);
             break;
         default:
@@ -342,7 +335,7 @@ void Brush::undoSave()
 {
     if (_undoStateSaver != nullptr)
 	{
-        _undoStateSaver->save(*this);
+        _undoStateSaver->saveState();
     }
 }
 
@@ -436,7 +429,7 @@ void Brush::push_back(Faces::value_type face) {
 
     if (_undoStateSaver)
     {
-        m_faces.back()->connectUndoSystem(*_mapFileChangeTracker);
+        m_faces.back()->connectUndoSystem(_undoStateSaver->getUndoSystem());
     }
 
     for (Observers::iterator i = m_observers.begin(); i != m_observers.end(); ++i) {
@@ -449,7 +442,7 @@ void Brush::pop_back()
 {
     if (_undoStateSaver)
     {
-        m_faces.back()->disconnectUndoSystem(*_mapFileChangeTracker);
+        m_faces.back()->disconnectUndoSystem(_undoStateSaver->getUndoSystem());
     }
 
     m_faces.pop_back();
@@ -463,7 +456,7 @@ void Brush::erase(std::size_t index)
 {
     if (_undoStateSaver)
     {
-        m_faces[index]->disconnectUndoSystem(*_mapFileChangeTracker);
+        m_faces[index]->disconnectUndoSystem(_undoStateSaver->getUndoSystem());
     }
 
     m_faces.erase(m_faces.begin() + index);
@@ -506,7 +499,7 @@ void Brush::clear()
     undoSave();
     if (_undoStateSaver)
     {
-        forEachFace([&](Face& face) { face.disconnectUndoSystem(*_mapFileChangeTracker); });
+        forEachFace([&](Face& face) { face.disconnectUndoSystem(_undoStateSaver->getUndoSystem()); });
     }
 
     m_faces.clear();
@@ -1134,7 +1127,7 @@ bool Brush::buildWindings() {
                 }
 
                 // update texture coordinates
-                f.EmitTextureCoordinates();
+                f.emitTextureCoordinates();
             }
 
             // greebo: Update the winding, now that it's constructed
