@@ -94,7 +94,6 @@ private:
 	typedef std::set<BrushObserver*> Observers;
 	Observers m_observers;
 	IUndoStateSaver* _undoStateSaver;
-	IMapFileChangeTracker* _mapFileChangeTracker;
 
 	// state
 	Faces m_faces;
@@ -162,8 +161,8 @@ public:
 	IFace& getFace(std::size_t index);
 	const IFace& getFace(std::size_t index) const;
 
-	IFace& addFace(const Plane3& plane);
-	IFace& addFace(const Plane3& plane, const Matrix4& texDef, const std::string& shader);
+	IFace& addFace(const Plane3& plane) override;
+	IFace& addFace(const Plane3& plane, const Matrix3& textureProjection, const std::string& material) override;
 
     // Translatable implementation
 	void translate(const Vector3& translation);
@@ -177,8 +176,8 @@ public:
     // but are forcedly visible due to the brush being selected)
     void forEachVisibleFace(const std::function<void(Face&)>& functor) const;
 
-	void connectUndoSystem(IMapFileChangeTracker& map);
-	void disconnectUndoSystem(IMapFileChangeTracker& map);
+	void connectUndoSystem(IUndoSystem& undoSystem);
+	void disconnectUndoSystem(IUndoSystem& undoSystem);
 
 	// Face observer callbacks
 	void onFacePlaneChanged();
@@ -212,7 +211,7 @@ public:
 
 	const AABB& localAABB() const;
 
-	void renderComponents(SelectionSystem::EComponentMode mode, RenderableCollector& collector, const VolumeTest& volume, const Matrix4& localToWorld) const;
+	void renderComponents(selection::ComponentSelectionMode mode, RenderableCollector& collector, const VolumeTest& volume, const Matrix4& localToWorld) const;
 
 	void transform(const Matrix4& matrix);
 
