@@ -5,6 +5,7 @@
 #include "iradiant.h"
 #include "icounter.h"
 #include "iclipper.h"
+#include "imap.h"
 #include "ientity.h"
 #include "math/Frustum.h"
 #include "math/Hash.h"
@@ -90,13 +91,13 @@ std::string BrushNode::getFingerprint()
         hash.addString(face->getShader());
 
         // Texture Matrix
-        auto texdef = face->getTexDefMatrix();
+        auto texdef = face->getProjectionMatrix();
         hash.addDouble(texdef.xx(), SignificantDigits);
         hash.addDouble(texdef.yx(), SignificantDigits);
-        hash.addDouble(texdef.tx(), SignificantDigits);
+        hash.addDouble(texdef.zx(), SignificantDigits);
         hash.addDouble(texdef.xy(), SignificantDigits);
         hash.addDouble(texdef.yy(), SignificantDigits);
-        hash.addDouble(texdef.ty(), SignificantDigits);
+        hash.addDouble(texdef.zy(), SignificantDigits);
     }
 
     return hash;
@@ -141,57 +142,59 @@ bool BrushNode::isSelectedComponents() const {
 	return false;
 }
 
-void BrushNode::setSelectedComponents(bool select, SelectionSystem::EComponentMode mode) {
+void BrushNode::setSelectedComponents(bool select, selection::ComponentSelectionMode mode)
+{
 	for (FaceInstances::iterator i = m_faceInstances.begin(); i != m_faceInstances.end(); ++i) {
 		i->setSelected(mode, select);
 	}
 }
 
-void BrushNode::invertSelectedComponents(SelectionSystem::EComponentMode mode)
+void BrushNode::invertSelectedComponents(selection::ComponentSelectionMode mode)
 {
 	// Component mode, invert the component selection
 	switch (mode)
 	{
-	case SelectionSystem::eVertex:
+	case selection::ComponentSelectionMode::Vertex:
 		for (brush::VertexInstance& vertex : m_vertexInstances)
 		{
 			vertex.invertSelected();
 		}
 		break;
-	case SelectionSystem::eEdge:
+	case selection::ComponentSelectionMode::Edge:
 		for (EdgeInstance& edge : m_edgeInstances)
 		{
 			edge.invertSelected();
 		}
 		break;
-	case SelectionSystem::eFace:
+	case selection::ComponentSelectionMode::Face:
 		for (FaceInstance& face : m_faceInstances)
 		{
 			face.invertSelected();
 		}
 		break;
-	case SelectionSystem::eDefault:
+	case selection::ComponentSelectionMode::Default:
 		break;
 	} // switch
 }
 
-void BrushNode::testSelectComponents(Selector& selector, SelectionTest& test, SelectionSystem::EComponentMode mode) {
+void BrushNode::testSelectComponents(Selector& selector, SelectionTest& test, selection::ComponentSelectionMode mode)
+{
 	test.BeginMesh(localToWorld());
 
 	switch (mode) {
-		case SelectionSystem::eVertex: {
+		case selection::ComponentSelectionMode::Vertex: {
 				for (VertexInstances::iterator i = m_vertexInstances.begin(); i != m_vertexInstances.end(); ++i) {
 					i->testSelect(selector, test);
 				}
 			}
 		break;
-		case SelectionSystem::eEdge: {
+		case selection::ComponentSelectionMode::Edge: {
 				for (EdgeInstances::iterator i = m_edgeInstances.begin(); i != m_edgeInstances.end(); ++i) {
 					i->testSelect(selector, test);
 				}
 			}
 			break;
-		case SelectionSystem::eFace: {
+		case selection::ComponentSelectionMode::Face: {
 				if (test.getVolume().fill()) {
 					for (FaceInstances::iterator i = m_faceInstances.begin(); i != m_faceInstances.end(); ++i) {
 						i->testSelect(selector, test);
@@ -267,7 +270,7 @@ scene::INodePtr BrushNode::clone() const {
 
 void BrushNode::onInsertIntoScene(scene::IMapRootNode& root)
 {
-    m_brush.connectUndoSystem(root.getUndoChangeTracker());
+    m_brush.connectUndoSystem(root.getUndoSystem());
 	GlobalCounters().getCounter(counterBrushes).increment();
 
     // Update the origin information needed for transformations
@@ -282,12 +285,12 @@ void BrushNode::onRemoveFromScene(scene::IMapRootNode& root)
 	setSelected(false);
 
 	// De-select all child components as well
-	setSelectedComponents(false, SelectionSystem::eVertex);
-	setSelectedComponents(false, SelectionSystem::eEdge);
-	setSelectedComponents(false, SelectionSystem::eFace);
+	setSelectedComponents(false, selection::ComponentSelectionMode::Vertex);
+	setSelectedComponents(false, selection::ComponentSelectionMode::Edge);
+	setSelectedComponents(false, selection::ComponentSelectionMode::Face);
 
 	GlobalCounters().getCounter(counterBrushes).decrement();
-    m_brush.disconnectUndoSystem(root.getUndoChangeTracker());
+    m_brush.disconnectUndoSystem(root.getUndoSystem());
 
 	SelectableNode::onRemoveFromScene(root);
 }
@@ -350,7 +353,7 @@ void BrushNode::renderComponents(RenderableCollector& collector, const VolumeTes
 
 	const Matrix4& l2w = localToWorld();
 
-	if (volume.fill() && GlobalSelectionSystem().ComponentMode() == SelectionSystem::eFace)
+	if (volume.fill() && GlobalSelectionSystem().ComponentMode() == selection::ComponentSelectionMode::Face)
 	{
 		evaluateViewDependent(volume, l2w);
 		collector.addRenderable(*m_brush.m_state_point, _faceCentroidPointsCulled, l2w);
@@ -540,16 +543,18 @@ void BrushNode::renderSelectedPoints(RenderableCollector& collector,
 	}
 }
 
-void BrushNode::evaluateTransform() {
-	Matrix4 matrix(calculateTransform());
-	//rMessage() << "matrix: " << matrix << "\n";
+void BrushNode::evaluateTransform()
+{
+    if (getTransformationType() == NoTransform)
+    {
+        return;
+    }
 
 	if (getType() == TRANSFORM_PRIMITIVE)
     {
         // If this is a pure translation (no other bits set), call the specialised method
         if (getTransformationType() == Translation)
         {
-            // TODO: Take care of texture lock
             for (auto face : m_brush)
             {
                 face->translate(getTranslation());
@@ -557,11 +562,12 @@ void BrushNode::evaluateTransform() {
         }
         else
         {
-            m_brush.transform(matrix);
+            m_brush.transform(calculateTransform());
         }
 	}
-	else {
-		transformComponents(matrix);
+	else
+    {
+		transformComponents(calculateTransform());
 	}
 }
 
@@ -612,6 +618,20 @@ bool BrushNode::facesAreForcedVisible()
     return isForcedVisible();
 }
 
+void BrushNode::onPostUndo()
+{
+    // The windings are usually lazy-evaluated when some code
+    // is calling localAABB() during rendering.
+    // To avoid the texture tool from rendering old texture coords
+    // We evaluate the windings right after undo
+    m_brush.evaluateBRep();
+}
+
+void BrushNode::onPostRedo()
+{
+    m_brush.evaluateBRep();
+}
+
 void BrushNode::_onTransformationChanged()
 {
 	m_brush.transformChanged();
