@@ -5,15 +5,18 @@
 #include "itextstream.h"
 #include "irenderable.h"
 
+#include "math/Matrix3.h"
 #include "shaderlib.h"
+#include "texturelib.h"
 #include "Winding.h"
+#include "selection/algorithm/Texturing.h"
 
 #include "Brush.h"
 #include "BrushNode.h"
 #include "BrushModule.h"
 
 // The structure that is saved in the undostack
-class Face::SavedState :
+class Face::SavedState final :
     public IUndoMemento
 {
 public:
@@ -26,15 +29,6 @@ public:
         _texdefState(face.getProjection()),
         _materialName(face.getShader())
     {}
-
-    virtual ~SavedState() {}
-
-    void exportState(Face& face) const
-    {
-        _planeState.exportState(face.getPlane());
-        face.setShader(_materialName);
-        face.getProjection().assign(_texdefState);
-    }
 };
 
 Face::Face(Brush& owner) :
@@ -84,17 +78,16 @@ Face::Face(Brush& owner, const Plane3& plane) :
     shaderChanged();
 }
 
-Face::Face(Brush& owner, const Plane3& plane, const Matrix4& texdef,
-           const std::string& shader) :
+Face::Face(Brush& owner, const Plane3& plane, const Matrix3& textureProjection, const std::string& material) :
     _owner(owner),
-    _shader(shader, _owner.getBrushNode().getRenderSystem()),
+    _shader(material, _owner.getBrushNode().getRenderSystem()),
     _undoStateSaver(nullptr),
     _faceIsVisible(true)
 {
     setupSurfaceShader();
     m_plane.setPlane(plane);
 
-    _texdef.matrix = TextureMatrix(texdef);
+    _texdef.setTransform(textureProjection);
 
     planeChanged();
     shaderChanged();
@@ -118,6 +111,13 @@ Face::Face(Brush& owner, const Face& other) :
 Face::~Face()
 {
     _surfaceShaderRealised.disconnect();
+    _sigDestroyed.emit();
+    _sigDestroyed.clear();
+}
+
+sigc::signal<void>& Face::signal_faceDestroyed()
+{
+    return _sigDestroyed;
 }
 
 void Face::setupSurfaceShader()
@@ -132,7 +132,12 @@ void Face::setupSurfaceShader()
     }
 }
 
-Brush& Face::getBrush()
+IBrush& Face::getBrush()
+{
+    return _owner;
+}
+
+Brush& Face::getBrushInternal()
 {
     return _owner;
 }
@@ -148,20 +153,20 @@ void Face::realiseShader()
     _owner.onFaceShaderChanged();
 }
 
-void Face::connectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Face::connectUndoSystem(IUndoSystem& undoSystem)
 {
     assert(!_undoStateSaver);
 
     _shader.setInUse(true);
 
-    _undoStateSaver = GlobalUndoSystem().getStateSaver(*this, changeTracker);
+    _undoStateSaver = undoSystem.getStateSaver(*this);
 }
 
-void Face::disconnectUndoSystem(IMapFileChangeTracker& changeTracker)
+void Face::disconnectUndoSystem(IUndoSystem& undoSystem)
 {
     assert(_undoStateSaver);
     _undoStateSaver = nullptr;
-    GlobalUndoSystem().releaseStateSaver(*this);
+    undoSystem.releaseStateSaver(*this);
 
     _shader.setInUse(false);
 }
@@ -170,21 +175,25 @@ void Face::undoSave()
 {
     if (_undoStateSaver)
     {
-        _undoStateSaver->save(*this);
+        _undoStateSaver->saveState();
     }
 }
 
 // undoable
 IUndoMementoPtr Face::exportState() const
 {
-    return IUndoMementoPtr(new SavedState(*this));
+    return std::make_shared<SavedState>(*this);
 }
 
 void Face::importState(const IUndoMementoPtr& data)
 {
     undoSave();
 
-    std::static_pointer_cast<SavedState>(data)->exportState(*this);
+    auto state = std::static_pointer_cast<SavedState>(data);
+
+    state->_planeState.exportState(getPlane());
+    setShader(state->_materialName);
+    _texdef = state->_texdefState;
 
     planeChanged();
     _owner.onFaceConnectivityChanged();
@@ -248,28 +257,54 @@ void Face::setRenderSystem(const RenderSystemPtr& renderSystem)
     }
 }
 
+void Face::transformTexDefLocked(const Matrix4& transform)
+{
+    Vector3 vertices[3] =
+    {
+        m_winding[0].vertex,
+        m_winding[1].vertex,
+        m_winding[2].vertex
+    };
+
+    Vector2 texcoords[3] =
+    {
+        m_winding[0].texcoord,
+        m_winding[1].texcoord,
+        m_winding[2].texcoord
+    };
+
+    // Transform the vertices
+    vertices[0] = transform.transformPoint(vertices[0]);
+    vertices[1] = transform.transformPoint(vertices[1]);
+    vertices[2] = transform.transformPoint(vertices[2]);
+
+    // Keep the texture coords, recalculate the texture projection
+    m_texdefTransformed.calculateFromPoints(vertices, texcoords, m_planeTransformed.getPlane().normal());
+}
+
 void Face::translate(const Vector3& translation)
 {
-    if (GlobalBrush().textureLockEnabled())
+    m_planeTransformed.translate(translation);
+    
+    if (GlobalBrush().textureLockEnabled() && m_winding.size() >= 3)
     {
-        m_texdefTransformed.transformLocked(_shader.getWidth(), _shader.getHeight(),
-            m_plane.getPlane(), Matrix4::getTranslation(translation));
+        transformTexDefLocked(Matrix4::getTranslation(translation));
     }
 
-    m_planeTransformed.translate(translation);
     _owner.onFacePlaneChanged();
     updateWinding();
 }
 
-void Face::transform(const Matrix4& matrix)
+void Face::transform(const Matrix4& transform)
 {
-    if (GlobalBrush().textureLockEnabled())
+    // Transform the FacePlane using the given matrix (before the tex def is recalculated)
+    m_planeTransformed.transform(transform);
+
+    if (GlobalBrush().textureLockEnabled() && m_winding.size() >= 3)
     {
-        m_texdefTransformed.transformLocked(_shader.getWidth(), _shader.getHeight(), m_plane.getPlane(), matrix);
+        transformTexDefLocked(transform);
     }
 
-    // Transform the FacePlane using the given matrix
-    m_planeTransformed.transform(matrix);
     _owner.onFacePlaneChanged();
     updateWinding();
 }
@@ -290,9 +325,11 @@ void Face::revertTransform()
     planepts_assign(m_move_planeptsTransformed, m_move_planepts);
     m_texdefTransformed = _texdef;
     updateWinding();
+    emitTextureCoordinates();
 }
 
-void Face::freezeTransform() {
+void Face::freezeTransform()
+{
     undoSave();
     m_plane = m_planeTransformed;
     planepts_assign(m_move_planepts, m_move_planeptsTransformed);
@@ -343,7 +380,7 @@ void Face::testSelect_centroid(SelectionTest& test, SelectionIntersection& best)
 
 void Face::shaderChanged()
 {
-    EmitTextureCoordinates();
+    emitTextureCoordinates();
     _owner.onFaceShaderChanged();
 
     // Update the visibility flag, but leave out the contributes() check
@@ -370,7 +407,19 @@ const std::string& Face::getShader() const
 void Face::setShader(const std::string& name)
 {
     undoSave();
+
+    auto ssr = getShiftScaleRotation();
+
     _shader.setMaterialName(name);
+
+    // Adjust the scale to match the previous material
+    auto newSsr = getShiftScaleRotation();
+
+    newSsr.scale[0] = ssr.scale[0];
+    newSsr.scale[1] = ssr.scale[1];
+
+    setShiftScaleRotation(newSsr);
+
     shaderChanged();
 }
 
@@ -382,7 +431,7 @@ void Face::revertTexdef()
 void Face::texdefChanged()
 {
     revertTexdef();
-    EmitTextureCoordinates();
+    emitTextureCoordinates();
 
     // Fire the signal to update the Texture Tools
     signal_texdefChanged().emit();
@@ -398,14 +447,14 @@ TextureProjection& Face::getProjection()
     return _texdef;
 }
 
-Matrix4 Face::getProjectionMatrix()
+Matrix3 Face::getProjectionMatrix() const
 {
-    return getProjection().getTransform();
+    return getProjection().getMatrix();
 }
 
-void Face::setProjectionMatrix(const Matrix4& projection)
+void Face::setProjectionMatrix(const Matrix3& projection)
 {
-    getProjection().setTransform(1, 1, projection);
+    getProjection().setTransform(projection);
     texdefChanged();
 }
 
@@ -417,93 +466,151 @@ void Face::GetTexdef(TextureProjection& projection) const
 void Face::SetTexdef(const TextureProjection& projection)
 {
     undoSave();
-    _texdef.assign(projection);
+    _texdef = projection;
     texdefChanged();
 }
 
-void Face::setTexdef(const TexDef& texDef)
+ShiftScaleRotation Face::getShiftScaleRotation() const
 {
-    TextureProjection projection;
-
-    // Construct the BPTexDef out of the TexDef by using the according constructor
-    projection.matrix = TextureMatrix(texDef);
-
-    // The bprimitive texdef needs to be scaled using our current texture dims
-    auto width = static_cast<double>(_shader.getWidth());
-    auto height = static_cast<double>(_shader.getHeight());
-
-    projection.matrix.coords[0][0] /= width;
-    projection.matrix.coords[0][1] /= width;
-    projection.matrix.coords[0][2] /= width;
-    projection.matrix.coords[1][0] /= height;
-    projection.matrix.coords[1][1] /= height;
-    projection.matrix.coords[1][2] /= height;
-
-    SetTexdef(projection);
+    return _texdef.getShiftScaleRotation(_shader.getWidth(), _shader.getHeight());
 }
 
-ShiftScaleRotation Face::getShiftScaleRotation()
+void Face::setShiftScaleRotation(const ShiftScaleRotation& ssr)
 {
-    TextureProjection curProjection = _texdef;
+    undoSave();
 
-    // Multiply the texture dimensions to the projection matrix such that
-    // the shift/scale/rotation represent pixel values within the image.
-    Vector2 shaderDims(_shader.getWidth(), _shader.getHeight());
+    // Construct the matrix from the adjusted shift/scale/rotate values
+    _texdef.setFromShiftScaleRotate(ssr, _shader.getWidth(), _shader.getHeight());
 
-    TextureMatrix bpTexDef = curProjection.matrix;
-    bpTexDef.applyShaderDimensions(static_cast<std::size_t>(shaderDims[0]), static_cast<std::size_t>(shaderDims[1]));
+    texdefChanged();
+}
 
-    // Calculate the "fake" texture properties (shift/scale/rotation)
-    TexDef texdef = bpTexDef.getFakeTexCoords();
+Vector2 Face::getTexelScale() const
+{
+    auto imageWidth = _shader.getWidth();
+    auto imageHeight = _shader.getHeight();
 
-    if (shaderDims != Vector2(0, 0))
+    auto textureMatrix = _texdef.getMatrix();
+
+    // Multiplying the image dimensions onto the texture matrix yields
+    // the base vectors in texel space. Take the length to get the covered texels per world unit
+    return Vector2(
+        Vector2(textureMatrix.xx() * imageWidth, textureMatrix.xy() * imageHeight).getLength(),
+        Vector2(textureMatrix.yx() * imageWidth, textureMatrix.yy() * imageHeight).getLength()
+    );
+}
+
+float Face::getTextureAspectRatio() const
+{
+    return _shader.getTextureAspectRatio();
+}
+
+// Returns the index pair forming an edge, keeping the winding direction intact
+inline std::pair<std::size_t, std::size_t> getEdgeIndexPair(std::size_t first, std::size_t second, std::size_t windingSize)
+{
+    if (first > second || second == windingSize - 1 && first == 0)
     {
-        // normalize again to hide the ridiculously high scale values that get created when using texlock
-        texdef.normalise(shaderDims[0], shaderDims[1]);
+        std::swap(first, second);
     }
 
-    return texdef.getShiftScaleRotation();
-}
-
-void Face::setShiftScaleRotation(const ShiftScaleRotation& scr)
-{
-    setTexdef(TexDef::CreateFromShiftScaleRotation(scr));
+    return std::make_pair(first, second);
 }
 
 void Face::applyShaderFromFace(const Face& other)
 {
+    undoSave();
+
+    // Apply the material of the other face
+    setShader(other.getShader());
+
     // Retrieve the textureprojection from the source face
     TextureProjection projection;
     other.GetTexdef(projection);
 
-    setShader(other.getShader());
-    SetTexdef(projection);
-
-    // The list of shared vertices
-    std::vector<Winding::const_iterator> thisVerts, otherVerts;
+    // The list of shared vertices (other face index => this face index)
+    std::vector<std::pair<std::size_t, std::size_t>> sharedVertices;
 
     // Let's see whether this face is sharing any 3D coordinates with the other one
-    for (Winding::const_iterator i = other.m_winding.begin(); i != other.m_winding.end(); ++i) {
-        for (Winding::const_iterator j = m_winding.begin(); j != m_winding.end(); ++j) {
+    // It's important to iterate over ascending indices of the other face, since we need to keep the winding order
+    for (std::size_t i = 0; i < other.m_winding.size(); ++i)
+    {
+        for (std::size_t j = 0; j < m_winding.size(); ++j)
+        {
             // Check if the vertices are matching
-            if (math::isNear(j->vertex, i->vertex, 0.001))
+            if (math::isNear(m_winding[j].vertex, other.m_winding[i].vertex, 0.001))
             {
                 // Match found, add to list
-                thisVerts.push_back(j);
-                otherVerts.push_back(i);
+                sharedVertices.emplace_back(std::make_pair(i, j));
+                break;
             }
         }
     }
 
-    if (thisVerts.empty() || thisVerts.size() != otherVerts.size()) {
-        return; // nothing to do
+    // Do we have a shared edge?
+    if (sharedVertices.size() == 2)
+    {
+        auto edgeIndices = getEdgeIndexPair(sharedVertices[0].first, sharedVertices[1].first, other.m_winding.size());
+
+        // We wrap the texture around the shared edge, check the UV scale perpendicular to that edge
+        auto edgeCenter = (other.m_winding[edgeIndices.first].vertex + other.m_winding[edgeIndices.second].vertex) * 0.5;
+
+        // Construct an edge vector, following the winding direction
+        auto edge = other.m_winding[edgeIndices.second].vertex - other.m_winding[edgeIndices.first].vertex;
+
+        // Construct a vector that is orthogonal to the edge, pointing outwards
+        auto outwardsDirection = edge.cross(other.m_planeTransformed.getPlane().normal());
+
+        // Pick a point outside face, placing that orthogonal vector on the edge center
+        auto extrapolatedPoint = edgeCenter + outwardsDirection;
+        auto extrapolationLength = outwardsDirection.getLength();
+        auto extrapolatedTexcoords = other.m_texdefTransformed.getTextureCoordsForVertex(
+            extrapolatedPoint, other.m_planeTransformed.getPlane().normal(), Matrix4::getIdentity()
+        );
+
+        // Construct an edge vector on this target face, keeping the winding order
+        edgeIndices = getEdgeIndexPair(sharedVertices[0].second, sharedVertices[1].second, m_winding.size());
+
+        auto targetFaceEdge = m_winding[edgeIndices.second].vertex - m_winding[edgeIndices.first].vertex;
+        auto inwardsDirection = -targetFaceEdge.cross(m_planeTransformed.getPlane().normal()).getNormalised();
+
+        // Calculate a point on this face plane, with the same distance from the edge center as on the source face
+        auto pointOnThisFacePlane = edgeCenter + inwardsDirection * extrapolationLength;
+
+        // Now we have 3 vertices and 3 texcoords to calculate the matching texdef
+        Vector3 vertices[3] =
+        {
+            m_winding[sharedVertices[0].second].vertex,
+            m_winding[sharedVertices[1].second].vertex,
+            pointOnThisFacePlane
+        };
+
+        // Use the shared texcoords we found on the other face, and the third one we calculated
+        Vector2 texcoords[3] =
+        {
+            other.m_winding[sharedVertices[0].first].texcoord,
+            other.m_winding[sharedVertices[1].first].texcoord,
+            extrapolatedTexcoords
+        };
+
+        setTexDefFromPoints(vertices, texcoords);
+        _texdef = m_texdefTransformed; // freeze that matrix
+        return;
     }
+    else
+    {
+        // Just use the other projection, as-is
+        SetTexdef(projection);
+    }
+}
 
-    // Calculate the distance in texture space of the first shared vertices
-    Vector2 dist = thisVerts[0]->texcoord - otherVerts[0]->texcoord;
+void Face::setTexDefFromPoints(const Vector3 points[3], const Vector2 uvs[3])
+{
+    m_texdefTransformed.calculateFromPoints(points, uvs, getPlane3().normal());
 
-    // Shift the texture to match
-    shiftTexdef(static_cast<float>(dist.x()), static_cast<float>(dist.y()));
+    emitTextureCoordinates();
+
+    // Fire the signal to update the Texture Tools
+    signal_texdefChanged().emit();
 }
 
 void Face::shiftTexdef(float s, float t)
@@ -519,16 +626,14 @@ void Face::shiftTexdefByPixels(float sPixels, float tPixels)
     shiftTexdef(sPixels / _shader.getWidth(), tPixels / _shader.getHeight());
 }
 
-void Face::scaleTexdef(float sFactor, float tFactor) {
-    undoSave();
-    _texdef.scale(sFactor, tFactor, _shader.getWidth(), _shader.getHeight());
-    texdefChanged();
+void Face::scaleTexdef(float sFactor, float tFactor)
+{
+    selection::algorithm::TextureScaler::ScaleFace(*this, { sFactor, tFactor });
 }
 
-void Face::rotateTexdef(float angle) {
-    undoSave();
-    _texdef.rotate(angle, _shader.getWidth(), _shader.getHeight());
-    texdefChanged();
+void Face::rotateTexdef(float angle)
+{
+    selection::algorithm::TextureRotator::RotateFace(*this, degrees_to_radians(angle));
 }
 
 void Face::fitTexture(float s_repeat, float t_repeat) {
@@ -537,10 +642,9 @@ void Face::fitTexture(float s_repeat, float t_repeat) {
     texdefChanged();
 }
 
-void Face::flipTexture(unsigned int flipAxis) {
-    undoSave();
-    _texdef.flipTexture(flipAxis);
-    texdefChanged();
+void Face::flipTexture(unsigned int flipAxis)
+{
+    selection::algorithm::TextureFlipper::FlipFace(*this, flipAxis);
 }
 
 void Face::alignTexture(AlignEdge align)
@@ -550,13 +654,14 @@ void Face::alignTexture(AlignEdge align)
     texdefChanged();
 }
 
-void Face::EmitTextureCoordinates() {
-    m_texdefTransformed.emitTextureCoordinates(m_winding, plane3().normal(), Matrix4::getIdentity());
+void Face::emitTextureCoordinates() 
+{
+    m_texdefTransformed.emitTextureCoordinates(m_winding, m_planeTransformed.getPlane().normal(), Matrix4::getIdentity());
 }
 
 void Face::applyDefaultTextureScale()
 {
-    _texdef.matrix.addScale(_shader.getWidth(), _shader.getHeight());
+    _texdef = TextureProjection::ConstructDefault(_shader.getWidth(), _shader.getHeight());
     texdefChanged();
 }
 
@@ -594,11 +699,6 @@ const FacePlane& Face::getPlane() const {
     return m_plane;
 }
 
-Matrix4 Face::getTexDefMatrix() const
-{
-    return _texdef.matrix.getTransform();
-}
-
 SurfaceShader& Face::getFaceShader() {
     return _shader;
 }
@@ -619,34 +719,9 @@ bool Face::is_bounded() const {
     return true;
 }
 
-void Face::normaliseTexture() {
-    undoSave();
-
-    Winding::const_iterator nearest = m_winding.begin();
-
-    // Find the vertex with the minimal distance to the origin
-    for (Winding::const_iterator i = m_winding.begin(); i != m_winding.end(); ++i) {
-        if (nearest->texcoord.getLength() > i->texcoord.getLength()) {
-            nearest = i;
-        }
-    }
-
-    Vector2 texcoord = nearest->texcoord;
-
-    // The floored values
-    Vector2 floored(floor(fabs(texcoord[0])), floor(fabs(texcoord[1])));
-
-    // The signs of the original texcoords (needed to know which direction it should be shifted)
-    Vector2 sign(texcoord[0]/fabs(texcoord[0]), texcoord[1]/fabs(texcoord[1]));
-
-    Vector2 shift;
-    shift[0] = (fabs(texcoord[0]) > 1.0E-4) ? -floored[0] * sign[0] * _shader.getWidth() : 0.0f;
-    shift[0] = (fabs(texcoord[1]) > 1.0E-4) ? -floored[1] * sign[1] * _shader.getHeight() : 0.0f;
-
-    // Shift the texture (note the minus sign, the FaceTexDef negates it yet again).
-    _texdef.shift(static_cast<float>(-shift[0]), static_cast<float>(shift[1]));
-
-    texdefChanged();
+void Face::normaliseTexture()
+{
+    selection::algorithm::TextureNormaliser::NormaliseFace(*this);
 }
 
 bool Face::isVisible() const
