@@ -2,7 +2,6 @@
 
 #include "irender.h"
 #include "iundo.h"
-#include "mapfile.h"
 #include "iselectiontest.h"
 #include <sigc++/connection.h>
 
@@ -61,6 +60,8 @@ private:
 	// Cached visibility flag, queried during front end rendering
 	bool _faceIsVisible;
 
+    sigc::signal<void> _sigDestroyed;
+
 public:
 
 	// Constructors
@@ -69,8 +70,7 @@ public:
 		const std::string& shader, const TextureProjection& projection);
 
 	Face(Brush& owner, const Plane3& plane);
-	Face(Brush& owner, const Plane3& plane, const Matrix4& texdef,
-		 const std::string& shader);
+	Face(Brush& owner, const Plane3& plane, const Matrix3& textureProjection, const std::string& material);
 
 	// Copy Constructor
 	Face(Brush& owner, const Face& other);
@@ -79,15 +79,19 @@ public:
 	virtual ~Face();
 
 	// Get the parent brush object
-	Brush& getBrush();
+	IBrush& getBrush() override;
+
+    Brush& getBrushInternal();
+
+    sigc::signal<void>& signal_faceDestroyed() override;
 
 	void planeChanged();
 
 	// greebo: Emits the updated normals to the Winding class.
 	void updateWinding();
 
-    void connectUndoSystem(IMapFileChangeTracker& changeTracker);
-    void disconnectUndoSystem(IMapFileChangeTracker& changeTracker);
+    void connectUndoSystem(IUndoSystem& undoSystem);
+    void disconnectUndoSystem(IUndoSystem& undoSystem);
 
 	void undoSave();
 
@@ -114,8 +118,8 @@ public:
 	void assign_planepts(const PlanePoints planepts);
 
 	/// \brief Reverts the transformable state of the brush to identity.
-	void revertTransform();
-	void freezeTransform();
+	void revertTransform() override;
+	void freezeTransform() override;
 
 	void update_move_planepts_vertex(std::size_t index, PlanePoints planePoints);
 
@@ -138,12 +142,12 @@ public:
 	void GetTexdef(TextureProjection& projection) const;
 	void SetTexdef(const TextureProjection& projection);
 
-    // Applies the given shift/scale/rotation values to this face's texture projection
-    // The incoming values are measured in pixels and will be scaled internally.
-    void setTexdef(const TexDef& texDef);
+    // Constructs the texture projection matrix from the given (world) vertex and texture coords.
+    // Three vertices and their UV coordinates are enough to construct the texdef.
+    void setTexDefFromPoints(const Vector3 points[3], const Vector2 uvs[3]);
 
-	ShiftScaleRotation getShiftScaleRotation() override;
-	void setShiftScaleRotation(const ShiftScaleRotation& scr) override;
+	ShiftScaleRotation getShiftScaleRotation() const override;
+	void setShiftScaleRotation(const ShiftScaleRotation& ssr) override;
 
 	/**
 	 * greebo: Copies the shader (texdef) from the other face,
@@ -162,6 +166,10 @@ public:
     // Passing s=1.05 will scale the texture to 105% in the s dimension
 	void scaleTexdef(float sFactor, float tFactor) override;
 	void rotateTexdef(float angle) override;
+
+    Vector2 getTexelScale() const override;
+    float getTextureAspectRatio() const override;
+
 	void fitTexture(float s_repeat, float t_repeat) override;
 	void flipTexture(unsigned int flipAxis) override;
 	void alignTexture(AlignEdge alignType) override;
@@ -171,7 +179,7 @@ public:
 	 */
 	void normaliseTexture();
 
-	void EmitTextureCoordinates();
+	void emitTextureCoordinates();
 
     // When constructing faces with a default-constructed TextureProjection the scale is very small
     // fix that by calling this method.
@@ -192,10 +200,8 @@ public:
 	FacePlane& getPlane();
 	const FacePlane& getPlane() const;
 
-	Matrix4 getTexDefMatrix() const;
-
-	Matrix4 getProjectionMatrix() override;
-	void setProjectionMatrix(const Matrix4& projection) override;
+	Matrix3 getProjectionMatrix() const override;
+	void setProjectionMatrix(const Matrix3& projection) override;
 
 	SurfaceShader& getFaceShader();
 	const SurfaceShader& getFaceShader() const;
@@ -216,4 +222,8 @@ private:
 	// Connects surface shader signals and calls realiseShader() if possible
 	void setupSurfaceShader();
 
+    // Transforms the texdef using the given world transform, with the goal
+    // to keep the texture coordinates of the winding unaltered by the transform
+    void transformTexDefLocked(const Matrix4& transform);
+
 }; // class Face
