@@ -17,7 +17,7 @@ public:
     // IColourManager implementation
 
     void addOverrideColour(const std::string& eclass, const Vector3& colour) override;
-    void applyColours(IEntityClass& eclass) override;
+    bool applyColours(IEntityClass& eclass) override;
     void foreachOverrideColour(const std::function<void(const std::string&, const Vector3&)>& functor) override;
     void removeOverrideColour(const std::string& eclass) override;
     void clearOverrideColours() override;
