@@ -12,7 +12,7 @@
 
 #include "string/replace.h"
 
-#include "Doom3Entity.h"
+#include "SpawnArgs.h"
 
 #include "light/LightNode.h"
 #include "doom3group/Doom3GroupNode.h"
@@ -235,7 +235,7 @@ IEntityNodePtr Doom3EntityModule::createEntityFromSelection(const std::string& n
             string::to_string(bounds.getExtents()));
     }
 
-    // Check for auto-setting key values. TODO: use forEachClassAttribute
+    // Check for auto-setting key values. TODO: use forEachAttribute
     // directly here.
     eclass::AttributeList list = eclass::getSpawnargsWithPrefix(
         *entityClass, "editor_setKeyValue"
