@@ -3,6 +3,7 @@
 #include <sigc++/connection.h>
 #include "ientity.h"
 #include "inamespace.h"
+#include "icomparablenode.h"
 #include "Bounded.h"
 
 #include "scene/SelectableNode.h"
@@ -19,10 +20,10 @@
 
 namespace entity
 {
-	
+
 class EntityNode;
 typedef std::shared_ptr<EntityNode> EntityNodePtr;
- 
+
 /**
  * greebo: This is the common base class of all map entities.
  */
@@ -33,16 +34,17 @@ class EntityNode :
 	public Namespaced,
 	public TargetableNode,
 	public Transformable,
-	public MatrixTransform,	// influences local2world of child nodes
-	public scene::Cloneable // all entities are cloneable, to be implemented in subclasses
+    public scene::IComparableNode
 {
 protected:
 	// The entity class
 	IEntityClassPtr _eclass;
 
 	// The actual entity (which contains the key/value pairs)
-	// TODO: Rename this to "spawnargs"?
-	Doom3Entity _entity;
+	SpawnArgs _spawnArgs;
+
+    // Transformation applied to this node and its children
+    Matrix4 _localToParent = Matrix4::getIdentity();
 
 	// The class taking care of all the namespace-relevant stuff
 	NamespaceManager _namespaceManager;
@@ -62,7 +64,7 @@ protected:
 	KeyObserverDelegate _modelKeyObserver;
 	KeyObserverDelegate _skinKeyObserver;
 
-	// A helper class managing the collection of KeyObservers attached to the Doom3Entity
+	// A helper class managing the collection of KeyObservers attached to the SpawnArgs
 	KeyObserverMap _keyObservers;
 
 	// Helper class observing the "shaderParmNN" spawnargs and caching their values
@@ -77,7 +79,20 @@ protected:
 
 	sigc::connection _eclassChangedConn;
 
-protected:
+    // List of attached sub-entities that we will submit for rendering (but are
+    // otherwise non-interactable).
+    //
+    // Although scene::Node already has the ability to store children, this is a
+    // separate list of entity nodes for two reasons: (1) there is a lot of
+    // other code which walks the scene graph for various reasons (e.g. map
+    // saving), and I don't want to have to audit the entire codebase to make
+    // sure that everything will play nicely with entities as children of other
+    // entities, and (2) storing entity node pointers instead of generic node
+    // pointers avoids some extra dynamic_casting.
+    using AttachedEntities = std::list<IEntityNodePtr>;
+    AttachedEntities _attachedEnts;
+
+  protected:
 	// The Constructor needs the eclass
 	EntityNode(const IEntityClassPtr& eclass);
 
@@ -90,11 +105,19 @@ public:
 	// IEntityNode implementation
 	Entity& getEntity() override;
 	virtual void refreshModel() override;
+    void transformChanged() override;
 
 	// RenderEntity implementation
 	virtual float getShaderParm(int parmNum) const override;
 	virtual const Vector3& getDirection() const override;
 
+    // IMatrixTransform implementation
+    Matrix4 localToParent() const override { return _localToParent; }
+    Matrix4& localToParent() override { return _localToParent; }
+
+    // IComparableNode implementation
+    std::string getFingerprint() override;
+
 	// SelectionTestable implementation
 	virtual void testSelect(Selector& selector, SelectionTest& test) override;
 
@@ -168,6 +191,36 @@ private:
 
     void acquireShaders();
     void acquireShaders(const RenderSystemPtr& renderSystem);
-};
+
+    // Create entity nodes for all attached entities
+    void createAttachedEntities();
+
+    // Render all attached entities
+    template <typename RenderFunc> void renderAttachments(RenderFunc func) const
+    {
+        for (const IEntityNodePtr& ent: _attachedEnts)
+        {
+            // Attached entities might themselves have child nodes (e.g. func_static
+            // which has its model as a child node), so we must traverse() the
+            // attached entities, not just render them alone
+            struct ChildRenderer : public scene::NodeVisitor
+            {
+                RenderFunc _func;
+                ChildRenderer(RenderFunc f): _func(f)
+                {}
+
+                bool pre(const scene::INodePtr& node)
+                {
+                    _func(node);
+                    return true;
+                }
+            };
+
+            ChildRenderer cr(func);
+            ent->traverse(cr);
+        }
+    }
+
+    };
 
 } // namespace entity
