@@ -6,9 +6,6 @@
 #include "itextstream.h"
 #include "iscenegraph.h"
 #include "icameraview.h"
-#include "imainframe.h"
-#include "idialogmanager.h"
-#include "ieventmanager.h"
 #include "imodel.h"
 #include "igrid.h"
 #include "ifilesystem.h"
@@ -46,6 +43,8 @@
 #include "map/algorithm/Skins.h"
 #include "messages/ScopedLongRunningOperation.h"
 #include "messages/FileOverwriteConfirmation.h"
+#include "messages/FileSaveConfirmation.h"
+#include "messages/MapOperationMessage.h"
 #include "selection/algorithm/Primitives.h"
 #include "selection/algorithm/Group.h"
 #include "scene/Group.h"
@@ -82,12 +81,48 @@ void Map::clearMapResource()
     // Map is unnamed or load failed, reset map resource node to empty
     _resource->clear();
 
-    _resource->getRootNode()->getUndoChangeTracker().save();
+    _resource->getRootNode()->getUndoChangeTracker().setSavedChangeCount();
 
     // Rename the map to "unnamed" in any case to avoid overwriting the failed map
     setMapName(_(MAP_UNNAMED_STRING));
 }
 
+void Map::connectToUndoSystem()
+{
+    _modifiedStatusListener.disconnect();
+    _undoEventListener.disconnect();
+
+    _modifiedStatusListener = _resource->signal_modifiedStatusChanged().connect(
+        [this](bool newStatus) { setModified(newStatus); }
+    );
+
+    if (!_resource->getRootNode()) return;
+
+    _undoEventListener = _resource->getRootNode()->getUndoSystem().signal_undoEvent().connect(
+        sigc::mem_fun(this, &Map::onUndoEvent)
+    );
+}
+
+void Map::onUndoEvent(IUndoSystem::EventType type, const std::string& operationName)
+{
+    switch (type)
+    {
+    case IUndoSystem::EventType::OperationRecorded:
+        OperationMessage::Send(operationName);
+        break;
+
+    case IUndoSystem::EventType::OperationUndone:
+        _mapPostUndoSignal.emit();
+        OperationMessage::Send(fmt::format(_("Undo: {0}"), operationName));
+        break;
+
+    case IUndoSystem::EventType::OperationRedone:
+        _mapPostRedoSignal.emit();
+        OperationMessage::Send(fmt::format(_("Redo: {0}"), operationName));
+        break;
+    }
+}
+
 void Map::loadMapResourceFromPath(const std::string& path)
 {
     // Create a MapLocation defining a physical file, and forward the call
@@ -115,10 +150,7 @@ void Map::loadMapResourceFromLocation(const MapLocation& location)
         GlobalMapResourceManager().createFromArchiveFile(location.path, location.archiveRelativePath) :
         GlobalMapResourceManager().createFromPath(location.path);
 
-    if (!_resource)
-    {
-        return;
-    }
+    assert(_resource);
 
     try
     {
@@ -135,6 +167,8 @@ void Map::loadMapResourceFromLocation(const MapLocation& location)
         clearMapResource();
     }
 
+    connectToUndoSystem();
+
     // Take the new node and insert it as map root
     GlobalSceneGraph().setRoot(_resource->getRootNode());
 
@@ -153,6 +187,8 @@ void Map::loadMapResourceFromLocation(const MapLocation& location)
     // Map loading finished, emit the signal
     emitMapEvent(MapLoaded);
 
+    OperationMessage::Send(_("Map loaded"));
+
     rMessage() << "--- LoadMapFile ---\n";
     rMessage() << _mapName << "\n";
 
@@ -363,11 +399,11 @@ void Map::setEditMode(EditMode mode)
     if (_editMode == EditMode::Merge)
     {
         GlobalSelectionSystem().setSelectedAll(false);
-        GlobalSelectionSystem().SetMode(SelectionSystem::eMergeAction);
+        GlobalSelectionSystem().SetMode(selection::SelectionSystem::eMergeAction);
     }
     else
     {
-        GlobalSelectionSystem().SetMode(SelectionSystem::ePrimitive);
+        GlobalSelectionSystem().SetMode(selection::SelectionSystem::ePrimitive);
     }
 
     signal_editModeChanged().emit(_editMode);
@@ -400,6 +436,14 @@ MapFormatPtr Map::getFormat()
     return GlobalMapFormatManager().getMapFormatForFilename(_mapName);
 }
 
+MapFormatPtr Map::getMapFormatForFilenameSafe(const std::string& filename)
+{
+    auto candidate = GlobalMapFormatManager().getMapFormatForFilename(filename);
+
+    // Fall back to the format of the current map if the selection is empty (#5808)
+    return candidate ? candidate : getFormat();
+}
+
 // free all map elements, reinitialize the structures that depend on them
 void Map::freeMap()
 {
@@ -417,6 +461,7 @@ void Map::freeMap()
     emitMapEvent(MapUnloaded);
 
     // Reset the resource pointer
+    _modifiedStatusListener.disconnect();
     _resource.reset();
 }
 
@@ -444,6 +489,28 @@ sigc::signal<void>& Map::signal_modifiedChanged()
     return _mapModifiedChangedSignal;
 }
 
+sigc::signal<void>& Map::signal_postUndo()
+{
+    return _mapPostUndoSignal;
+}
+
+sigc::signal<void>& Map::signal_postRedo()
+{
+    return _mapPostRedoSignal;
+}
+
+IUndoSystem& Map::getUndoSystem()
+{
+    const auto& rootNode = _resource->getRootNode();
+
+    if (!rootNode)
+    {
+        throw std::runtime_error("No map resource loaded");
+    }
+
+    return rootNode->getUndoSystem();
+}
+
 // move the view to a certain position
 void Map::focusViews(const Vector3& point, const Vector3& angles)
 {
@@ -530,7 +597,8 @@ bool Map::save(const MapFormatPtr& mapFormat)
     }
 
     // Check if the map file has been modified in the meantime
-    if (_resource->fileHasBeenModifiedSinceLastSave() && !radiant::FileOverwriteConfirmation::SendAndReceiveAnswer(
+    if (_resource->fileOnDiskHasBeenModifiedSinceLastSave() && 
+        !radiant::FileOverwriteConfirmation::SendAndReceiveAnswer(
             fmt::format(_("The file {0} has been modified since it was last saved,\nperhaps by another application. "
                 "Do you really want to overwrite the file?"), _mapName), _("File modification detected")))
     {
@@ -561,6 +629,7 @@ bool Map::save(const MapFormatPtr& mapFormat)
     }
 
     emitMapEvent(MapSaved);
+    OperationMessage::Send(_("Map saved"));
 
     _saveInProgress = false;
 
@@ -581,6 +650,7 @@ void Map::createNewMap()
 
     setModified(false);
 
+    OperationMessage::Send(_("Empty Map created"));
     focusViews(Vector3(0,0,30), Vector3(0,0,0));
 }
 
@@ -631,7 +701,7 @@ void Map::saveDirect(const std::string& filename, const MapFormatPtr& mapFormat)
 
 	if (!mapFormat)
 	{
-		format = GlobalMapFormatManager().getMapFormatForFilename(filename);
+		format = getMapFormatForFilenameSafe(filename);
 	}
 
     try
@@ -656,7 +726,7 @@ void Map::saveSelected(const std::string& filename, const MapFormatPtr& mapForma
 
 	if (!format)
 	{
-		format = GlobalMapFormatManager().getMapFormatForFilename(filename);
+		format = getMapFormatForFilenameSafe(filename);
 	}
 
     try
@@ -709,20 +779,14 @@ bool Map::askForSave(const std::string& title)
     }
 
     // Ask the user
-    auto msgBox = GlobalDialogManager().createMessageBox(
-        title,
-        getSaveConfirmationText(),
-        ui::IDialog::MESSAGE_SAVECONFIRMATION
-    );
+    auto answer = radiant::FileSaveConfirmation::SendAndReceiveAnswer(getSaveConfirmationText(), title);
 
-    auto result = msgBox->run();
-
-    if (result == ui::IDialog::RESULT_CANCELLED)
+    if (answer == radiant::FileSaveConfirmation::Action::Cancel)
     {
         return false;
     }
 
-    if (result == ui::IDialog::RESULT_YES)
+    if (answer == radiant::FileSaveConfirmation::Action::SaveChanges)
     {
         // The user wants to save the map
         if (isUnnamed())
@@ -738,7 +802,7 @@ bool Map::askForSave(const std::string& title)
         }
     }
 
-    // Default behaviour: allow the save
+    // Default behaviour: allow the action
     return true;
 }
 
@@ -772,6 +836,8 @@ bool Map::saveAs()
         return false;
     }
 
+    connectToUndoSystem();
+
     // Resource save was successful, notify about this name change
     rename(fileInfo.fullPath);
 
@@ -877,15 +943,21 @@ void Map::saveMapCopyAs(const cmd::ArgumentList& args)
     if (args.size() == 0 || args[0].getString().empty())
     {
         // Use the overload without arguments, it will ask for a file name
-        GlobalMap().saveCopyAs();
+        saveCopyAs();
     }
     else
     {
         // Pass the first argument we got
-        GlobalMap().saveCopyAs(args[0].getString());
+        saveCopyAs(args[0].getString());
     }
 }
 
+void Map::saveAutomaticMapBackup(const cmd::ArgumentList& args)
+{
+    // Use the saveDirect routine to not change with the _lastCopyMapName member
+    saveDirect(args[0].getString());
+}
+
 void Map::registerCommands()
 {
     GlobalCommandSystem().addCommand("NewMap", Map::newMap);
@@ -901,8 +973,10 @@ void Map::registerCommands()
     GlobalCommandSystem().addCommand("SaveSelectedAsPrefab", Map::saveSelectedAsPrefab);
     GlobalCommandSystem().addCommand("SaveMap", std::bind(&Map::saveMapCmd, this, std::placeholders::_1));
     GlobalCommandSystem().addCommand("SaveMapAs", Map::saveMapAs);
-    GlobalCommandSystem().addCommand("SaveMapCopyAs", Map::saveMapCopyAs, { cmd::ARGTYPE_STRING | cmd::ARGTYPE_OPTIONAL });
-    GlobalCommandSystem().addCommand("ExportMap", Map::exportMap);
+    GlobalCommandSystem().addCommand("SaveMapCopyAs", std::bind(&Map::saveMapCopyAs, this, std::placeholders::_1), { cmd::ARGTYPE_STRING | cmd::ARGTYPE_OPTIONAL });
+    // Command used by the autosaver to save a copy without messing with the remembered paths
+    GlobalCommandSystem().addCommand("SaveAutomaticBackup", std::bind(&Map::saveAutomaticMapBackup, this, std::placeholders::_1), { cmd::ARGTYPE_STRING });
+    GlobalCommandSystem().addCommand("ExportMap", std::bind(&Map::exportMap, this, std::placeholders::_1));
     GlobalCommandSystem().addCommand("SaveSelected", Map::exportSelection);
 	GlobalCommandSystem().addCommand("ReloadSkins", map::algorithm::reloadSkins);
     GlobalCommandSystem().addCommand("FocusViews", std::bind(&Map::focusViewCmd, this, std::placeholders::_1), { cmd::ARGTYPE_VECTOR3, cmd::ARGTYPE_VECTOR3 });
@@ -914,6 +988,34 @@ void Map::registerCommands()
           cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL,
           cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL,
           cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL });
+
+    // Add undo commands
+    GlobalCommandSystem().addCommand("Undo", std::bind(&Map::undoCmd, this, std::placeholders::_1));
+    GlobalCommandSystem().addCommand("Redo", std::bind(&Map::redoCmd, this, std::placeholders::_1));
+}
+
+void Map::undoCmd(const cmd::ArgumentList& args)
+{
+    try
+    {
+        getUndoSystem().undo();
+    }
+    catch (const std::runtime_error& err)
+    {
+        throw cmd::ExecutionNotPossible(err.what());
+    }
+}
+
+void Map::redoCmd(const cmd::ArgumentList& args)
+{
+    try
+    {
+        getUndoSystem().redo();
+    }
+    catch (const std::runtime_error& err)
+    {
+        throw cmd::ExecutionNotPossible(err.what());
+    }
 }
 
 // Static command targets
@@ -1042,16 +1144,21 @@ void Map::exportMap(const cmd::ArgumentList& args)
 {
     auto fileInfo = MapFileManager::getMapFileSelection(false, _("Export Map"), filetype::TYPE_MAP_EXPORT);
 
-	if (!fileInfo.fullPath.empty())
+    if (!fileInfo.fullPath.empty())
 	{
-        GlobalMap().emitMapEvent(MapSaving);
+        if (!fileInfo.mapFormat)
+        {
+            fileInfo.mapFormat = getMapFormatForFilenameSafe(fileInfo.fullPath);
+        }
+
+        emitMapEvent(MapSaving);
 
         MapResource::saveFile(*fileInfo.mapFormat,
             GlobalSceneGraph().root(),
             scene::traverse,
             fileInfo.fullPath);
 
-        GlobalMap().emitMapEvent(MapSaved);
+        emitMapEvent(MapSaved);
     }
 }
 
@@ -1060,7 +1167,7 @@ void Map::exportSelection(const cmd::ArgumentList& args)
     MapFileSelection fileInfo =
         MapFileManager::getMapFileSelection(false, _("Export selection"), filetype::TYPE_MAP);
 
-	if (!fileInfo.fullPath.empty())
+    if (!fileInfo.fullPath.empty())
 	{
 		GlobalMap().saveSelected(fileInfo.fullPath, fileInfo.mapFormat);
     }
@@ -1342,17 +1449,15 @@ const std::string& Map::getName() const
 
 const StringSet& Map::getDependencies() const
 {
-    static StringSet _dependencies;
-
-    if (_dependencies.empty())
-	{
-		_dependencies.insert(MODULE_GAMEMANAGER);
-		_dependencies.insert(MODULE_SCENEGRAPH);
-		_dependencies.insert(MODULE_MAPINFOFILEMANAGER);
-		_dependencies.insert(MODULE_FILETYPES);
-		_dependencies.insert(MODULE_MAPRESOURCEMANAGER);
-        _dependencies.insert(MODULE_COMMANDSYSTEM);
-    }
+    static StringSet _dependencies
+    {
+        MODULE_GAMEMANAGER,
+        MODULE_SCENEGRAPH,
+        MODULE_MAPINFOFILEMANAGER,
+        MODULE_FILETYPES,
+        MODULE_MAPRESOURCEMANAGER,
+        MODULE_COMMANDSYSTEM
+    };
 
     return _dependencies;
 }
@@ -1397,6 +1502,8 @@ void Map::initialiseModule(const IApplicationContext& ctx)
 
 void Map::shutdownModule()
 {
+    _undoEventListener.disconnect();
+
     abortMergeOperation();
 
     GlobalRadiantCore().getMessageBus().removeListener(_shutdownListener);
@@ -1415,6 +1522,11 @@ void Map::handleShutdownRequest(radiant::ApplicationShutdownRequest& request)
     {
         request.deny();
     }
+
+    if (!request.isDenied())
+    {
+        abortMergeOperation();
+    }
 }
 
 } // namespace map
