@@ -19,6 +19,7 @@
 #include "registry/registry.h"
 #include "scene/Traverse.h"
 #include "command/ExecutionFailure.h"
+#include "Models.h"
 
 namespace map
 {
@@ -26,6 +27,20 @@ namespace map
 namespace algorithm
 {
 
+// Returns the union set of layer IDs of the current selection
+scene::LayerList getAllLayersOfSelection()
+{
+    scene::LayerList unionSet;
+
+    GlobalSelectionSystem().foreachSelected([&](const scene::INodePtr& node)
+    {
+        const auto& layers = node->getLayers();
+        unionSet.insert(layers.begin(), layers.end());
+    });
+
+    return unionSet;
+}
+
 void exportSelectedAsModel(const ModelExportOptions& options)
 {
 	if (!path_is_absolute(options.outputFilename.c_str()))
@@ -101,40 +116,59 @@ void exportSelectedAsModel(const ModelExportOptions& options)
 
     expFormat->exportToPath(outputPath, outputFile);
 
-	if (!options.replaceSelectionWithModel)
-	{
-		return; // done here
-	}
+    std::string relativeModelPath = os::getRelativePath(absOutputPath, rootPath);
 
-	std::string relativeModelPath = os::getRelativePath(absOutputPath, rootPath);
+    if (options.replaceSelectionWithModel)
+    {
+        UndoableCommand command("replaceModel");
 
-	UndoableCommand command("replaceModel");
+        // Remember the last selected entity to preserve spawnargs
+        auto lastSelectedNode = GlobalSelectionSystem().ultimateSelected();
+        auto lastSelectedEntity = Node_getEntity(lastSelectedNode);
 
-	// Remove the selection
-	selection::algorithm::deleteSelection();
+        // Remove the selection, but remember its layers first
+        auto previousLayerSet = getAllLayersOfSelection();
+        selection::algorithm::deleteSelection();
 
-	// Create a func_static in its place
-	try
-	{
-		// Place the model in the world origin, unless we set "center objects" to true
-		Vector3 modelPos(0, 0, 0);
+        // Create a func_static in its place
+        try
+        {
+            // Place the model in the world origin, unless we set "center objects" to true
+            Vector3 modelPos(0, 0, 0);
 
-		if (options.centerObjects)
-		{
-			modelPos = -exporter.getCenterTransform().tCol().getVector3();
-		}
+            if (options.centerObjects)
+            {
+                modelPos = -exporter.getCenterTransform().translation();
+            }
 
-		scene::INodePtr modelNode = GlobalEntityModule().createEntityFromSelection("func_static", modelPos);
+            auto modelNode = GlobalEntityModule().createEntityFromSelection("func_static", modelPos);
 
-		Node_getEntity(modelNode)->setKeyValue("model", relativeModelPath);
+            auto newEntity = Node_getEntity(modelNode);
+            newEntity->setKeyValue("model", relativeModelPath);
+            modelNode->assignToLayers(previousLayerSet);
 
-		// It's possible that the export overwrote a model we're already using in this map, refresh it
-		GlobalModelCache().refreshSelectedModels(false);
-	}
-	catch (cmd::ExecutionFailure& ex)
-	{
-		throw std::runtime_error(fmt::format(_("Unable to create model: {0}"), ex.what()));
-	}
+            if (lastSelectedEntity)
+            {
+                // Preserve all spawnargs of the last selected entity, except for a few
+                std::set<std::string> spawnargsToDiscard{ "model", "classname", "origin", "rotation" };
+
+                lastSelectedEntity->forEachKeyValue([&](const std::string& key, const std::string& value)
+                {
+                    if (spawnargsToDiscard.count(string::to_lower_copy(key)) > 0) return;
+
+                    rMessage() << "Replaced entity inherits the key " << key << " with value " << value << std::endl;
+                    newEntity->setKeyValue(key, value);
+                });
+            }
+        }
+        catch (cmd::ExecutionFailure& ex)
+        {
+            throw std::runtime_error(fmt::format(_("Unable to create model: {0}"), ex.what()));
+        }
+    }
+    
+    // It's possible that the export overwrote a model we're already using in this map, refresh it
+    refreshModelsByPath(relativeModelPath);
 }
 
 void exportSelectedAsModelCmd(const cmd::ArgumentList& args)
