@@ -1,7 +1,7 @@
 #pragma once
 
 #include "imapformat.h"
-#include "math/Matrix4.h"
+#include "math/Matrix3.h"
 
 namespace map
 {
@@ -15,7 +15,6 @@ public:
 
     scene::INodePtr parse(parser::DefTokeniser& tok) const;
 };
-typedef std::shared_ptr<BrushDefParser> BrushDefParserPtr;
 
 // For really old map formats, we don't even have the brushDef keyword
 class LegacyBrushDefParser :
@@ -27,8 +26,7 @@ public:
     scene::INodePtr parse(parser::DefTokeniser& tok) const;
 
 private:
-    static Matrix4 getTexDef(std::string shader, float shiftS, float shiftT, float rotation, float scaleS, float scaleT);
+    static Matrix3 calculateTextureMatrix(const std::string& shader, const Vector3& normal, const ShiftScaleRotation& ssr);
 };
-typedef std::shared_ptr<LegacyBrushDefParser> LegacyBrushDefParserPtr;
 
 }
