@@ -6,14 +6,12 @@
 #include "editable.h"
 #include "iundo.h"
 #include "irender.h"
-#include "mapfile.h"
 #include "SurfaceShader.h"
 
 #include "PatchConstants.h"
 #include "PatchControl.h"
 #include "PatchTesselation.h"
 #include "PatchRenderables.h"
-#include "brush/TexDef.h"
 #include "brush/FacePlane.h"
 #include "brush/Face.h"
 #include <sigc++/signal.h>
@@ -111,8 +109,8 @@ public:
 	void attachObserver(Observer* observer) override;
 	void detachObserver(Observer* observer) override;
 
-	void connectUndoSystem(IMapFileChangeTracker& changeTracker);
-    void disconnectUndoSystem(IMapFileChangeTracker& changeTracker);
+	void connectUndoSystem(IUndoSystem& undoSystem);
+    void disconnectUndoSystem(IUndoSystem& undoSystem);
 
 	// Allocate callback: pass the allocate call to all the observers
 	void onAllocate(std::size_t size);
@@ -146,9 +144,9 @@ public:
 	void evaluateTransform();
 
 	// Revert the changes, fall back to the saved state in <m_ctrl>
-	void revertTransform();
+	void revertTransform() override;
 	// Apply the transformed control array, save it into <m_ctrl> and overwrite the old values
-	void freezeTransform();
+	void freezeTransform() override;
 
 	// callback for changed control points
 	void controlPointsChanged() override;
@@ -172,6 +170,8 @@ public:
 	// greebo: returns true if the patch's shader is visible, false otherwise
 	bool hasVisibleMaterial() const override;
 
+    float getTextureAspectRatio() const override;
+
 	// As the name states: get the shader flags of the m_state shader
 	int getShaderFlags() const;
 
@@ -218,6 +218,8 @@ public:
 	// The same as above just for const
 	const PatchControl& ctrlAt(std::size_t row, std::size_t col) const override;
 
+    PatchControl& getTransformedCtrlAt(std::size_t row, std::size_t col) override;
+
  	/** greebo: Inserts two columns before and after the column with index <colIndex>.
  	 * 			Throws an GenericPatchException if an error occurs.
  	 */
@@ -266,7 +268,7 @@ public:
 	// This is the same as above, but with undoSave() for use in command sequences
 	void translateTexture(float s, float t) override;
 	void scaleTexture(float s, float t) override;
-	void rotateTexture(float angle) override;
+	void rotateTexture(float angle) override; // angle in degrees
 	void fitTexture(float repeatS, float repeatT) override; // call with s=1 t=1 for FIT
 
 	/* uses longest parallel chord to calculate texture coords for each row/col
@@ -359,12 +361,12 @@ public:
 	// Static signal holder, signal is emitted after any patch texture has changed
 	static sigc::signal<void>& signal_patchTextureChanged();
 
+    void updateTesselation(bool force = false);
+
 private:
 	// This notifies the surfaceinspector/patchinspector about the texture change
 	void textureChanged();
 
-	void updateTesselation();
-
 	// greebo: checks, if the shader name is valid
 	void check_shader();
 
