@@ -47,6 +47,8 @@ OpenGLRenderSystem::OpenGLRenderSystem() :
     _time(0),
     m_traverseRenderablesMutex(false)
 {
+    bool shouldRealise = false;
+
     // For the static default rendersystem, the MaterialManager is not existent yet,
     // hence it will be attached in initialiseModule().
     if (module::GlobalModuleRegistry().moduleExists(MODULE_SHADERSYSTEM))
@@ -58,17 +60,24 @@ OpenGLRenderSystem::OpenGLRenderSystem() :
 
         if (GlobalMaterialManager().isRealised())
         {
-            realise();
+            // Hold back with the realise() call until we know whether we can call 
+            // extensionsInitialised() below - this should happen before realise()
+            shouldRealise = true;
         }
     }
 
     // If the openGL module is already initialised and a shared context is created
     // trigger a call to extensionsInitialised().
-    if (GlobalRadiantCore().getModuleRegistry().moduleExists(MODULE_SHARED_GL_CONTEXT) &&
+    if (module::GlobalModuleRegistry().moduleExists(MODULE_SHARED_GL_CONTEXT) &&
         GlobalOpenGLContext().getSharedContext())
     {
         extensionsInitialised();
     }
+
+    if (shouldRealise)
+    {
+        realise();
+    }
 }
 
 OpenGLRenderSystem::~OpenGLRenderSystem()
@@ -91,13 +100,13 @@ ShaderPtr OpenGLRenderSystem::capture(const std::string& name)
     // Either the shader was not found, or the weak pointer failed to lock
     // because the shader had been deleted. Either way, create a new shader
     // and insert into the cache.
-    OpenGLShaderPtr shd(new OpenGLShader(*this));
+    OpenGLShaderPtr shd(new OpenGLShader(name, *this));
     _shaders[name] = shd;
 
     // Realise the shader if the cache is realised
     if (_realised)
     {
-        shd->realise(name);
+        shd->realise();
     }
 
     // Return the new shader
@@ -231,7 +240,7 @@ void OpenGLRenderSystem::realise()
         OpenGLShaderPtr sp = i->second;
         assert(sp);
 
-        sp->realise(i->first);
+        sp->realise();
     }
 }
 
