@@ -2,25 +2,41 @@
 
 #include "GLProgramFactory.h"
 #include "../OpenGLRenderSystem.h"
+#include "DepthFillPass.h"
 
 #include "icolourscheme.h"
 #include "ishaders.h"
 #include "ifilter.h"
 #include "irender.h"
 #include "texturelib.h"
+#include "string/predicate.h"
 
 #include <functional>
 
 namespace render
 {
 
+namespace
+{
+    TexturePtr getDefaultInteractionTexture(IShaderLayer::Type type)
+    {
+        return GlobalMaterialManager().getDefaultInteractionTexture(type);
+    }
+
+    TexturePtr getTextureOrInteractionDefault(const IShaderLayer::Ptr& layer)
+    {
+        auto texture = layer->getTexture();
+        return texture ? texture : getDefaultInteractionTexture(layer->getType());
+    }
+}
+
 // Triplet of diffuse, bump and specular shaders
 struct OpenGLShader::DBSTriplet
 {
     // DBS layers
-    ShaderLayerPtr diffuse;
-    ShaderLayerPtr bump;
-    ShaderLayerPtr specular;
+    IShaderLayer::Ptr diffuse;
+    IShaderLayer::Ptr bump;
+    IShaderLayer::Ptr specular;
 
     // Need-depth-fill flag
     bool needDepthFill;
@@ -40,12 +56,18 @@ struct OpenGLShader::DBSTriplet
     }
 };
 
-OpenGLShader::OpenGLShader(OpenGLRenderSystem& renderSystem) :
+OpenGLShader::OpenGLShader(const std::string& name, OpenGLRenderSystem& renderSystem) :
+    _name(name),
     _renderSystem(renderSystem),
     _isVisible(true),
     _useCount(0)
 {}
 
+OpenGLShader::~OpenGLShader()
+{
+    destroy();
+}
+
 OpenGLRenderSystem& OpenGLShader::getRenderSystem()
 {
     return _renderSystem;
@@ -53,6 +75,7 @@ OpenGLRenderSystem& OpenGLShader::getRenderSystem()
 
 void OpenGLShader::destroy()
 {
+    _materialChanged.disconnect();
     _material.reset();
     _shaderPasses.clear();
 }
@@ -157,15 +180,15 @@ bool OpenGLShader::isRealised()
     return _material != 0;
 }
 
-void OpenGLShader::realise(const std::string& name)
+void OpenGLShader::realise()
 {
     // Construct the shader passes based on the name
-    construct(name);
+    construct();
 
-    if (_material != NULL)
+    if (_material)
 	{
 		// greebo: Check the filtersystem whether we're filtered
-		_material->setVisible(GlobalFilterSystem().isVisible(FilterRule::TYPE_TEXTURE, name));
+		_material->setVisible(GlobalFilterSystem().isVisible(FilterRule::TYPE_TEXTURE, _name));
 
 		if (_useCount != 0)
 		{
@@ -235,6 +258,12 @@ OpenGLState& OpenGLShader::appendDefaultPass()
     return state;
 }
 
+OpenGLState& OpenGLShader::appendDepthFillPass()
+{
+    auto& pass = _shaderPasses.emplace_back(std::make_shared<DepthFillPass>(*this, _renderSystem));
+    return pass->state();
+}
+
 // Test if we can render in bump map mode
 bool OpenGLShader::canUseLightingMode() const
 {
@@ -249,38 +278,32 @@ void OpenGLShader::setGLTexturesFromTriplet(OpenGLState& pass,
     // default from the shader system.
     if (triplet.diffuse)
     {
-        pass.texture0 = triplet.diffuse->getTexture()->getGLTexNum();
+        pass.texture0 = getTextureOrInteractionDefault(triplet.diffuse)->getGLTexNum();
 		pass.stage0 = triplet.diffuse;
     }
     else
     {
-        pass.texture0 = GlobalMaterialManager().getDefaultInteractionTexture(
-            ShaderLayer::DIFFUSE
-        )->getGLTexNum();
+        pass.texture0 = getDefaultInteractionTexture(IShaderLayer::DIFFUSE)->getGLTexNum();
     }
 
     if (triplet.bump)
     {
-        pass.texture1 = triplet.bump->getTexture()->getGLTexNum();
+        pass.texture1 = getTextureOrInteractionDefault(triplet.bump)->getGLTexNum();
 		pass.stage1 = triplet.bump;
     }
     else
     {
-        pass.texture1 = GlobalMaterialManager().getDefaultInteractionTexture(
-            ShaderLayer::BUMP
-        )->getGLTexNum();
+        pass.texture1 = getDefaultInteractionTexture(IShaderLayer::BUMP)->getGLTexNum();
     }
 
     if (triplet.specular)
     {
-        pass.texture2 = triplet.specular->getTexture()->getGLTexNum();
+        pass.texture2 = getTextureOrInteractionDefault(triplet.specular)->getGLTexNum();
 		pass.stage2 = triplet.specular;
     }
     else
     {
-        pass.texture2 = GlobalMaterialManager().getDefaultInteractionTexture(
-            ShaderLayer::SPECULAR
-        )->getGLTexNum();
+        pass.texture2 = getDefaultInteractionTexture(IShaderLayer::SPECULAR)->getGLTexNum();
     }
 }
 
@@ -288,7 +311,7 @@ void OpenGLShader::setGLTexturesFromTriplet(OpenGLState& pass,
 void OpenGLShader::appendInteractionLayer(const DBSTriplet& triplet)
 {
 	// Set layer vertex colour mode and alphatest parameters
-    ShaderLayer::VertexColourMode vcolMode = ShaderLayer::VERTEX_COLOUR_NONE;
+    IShaderLayer::VertexColourMode vcolMode = IShaderLayer::VERTEX_COLOUR_NONE;
     double alphaTest = -1;
 
     if (triplet.diffuse)
@@ -297,22 +320,18 @@ void OpenGLShader::appendInteractionLayer(const DBSTriplet& triplet)
         alphaTest = triplet.diffuse->getAlphaTest();
     }
 
-    // Append a depthfill shader pass if requested (not applicable for
-    // alpha-test materials)
-    if (triplet.needDepthFill && alphaTest <= 0.0)
+    // Append a depthfill shader pass if requested
+    if (triplet.needDepthFill && triplet.diffuse)
     {
-        // Create depth-buffer fill pass
-        OpenGLState& zPass = appendDefaultPass();
-        zPass.setRenderFlag(RENDER_MASKCOLOUR);
-        zPass.setRenderFlag(RENDER_FILL);
-        zPass.setRenderFlag(RENDER_CULLFACE);
-        zPass.setRenderFlag(RENDER_DEPTHTEST);
-        zPass.setRenderFlag(RENDER_DEPTHWRITE);
-        zPass.setRenderFlag(RENDER_PROGRAM);
+        // Create depth-buffer fill pass with alpha test
+        OpenGLState& zPass = appendDepthFillPass();
 
-        zPass.setSortPosition(OpenGLState::SORT_ZFILL);
+        // Store the alpha test value
+        zPass.alphaThreshold = static_cast<GLfloat>(alphaTest);
 
-        zPass.glProgram = _renderSystem.getGLProgramFactory().getBuiltInProgram("depthFill");
+        // We need a diffuse stage to be able to performthe alpha test
+        zPass.stage0 = triplet.diffuse;
+        zPass.texture0 = getTextureOrInteractionDefault(triplet.diffuse)->getGLTexNum();
     }
 
     // Add the DBS pass
@@ -333,12 +352,12 @@ void OpenGLShader::appendInteractionLayer(const DBSTriplet& triplet)
 
     dbsPass.glProgram = _renderSystem.getGLProgramFactory().getBuiltInProgram("bumpMap");
 
-    if (vcolMode != ShaderLayer::VERTEX_COLOUR_NONE)
+    if (vcolMode != IShaderLayer::VERTEX_COLOUR_NONE)
     {
         // Vertex colours allowed
         dbsPass.setRenderFlag(RENDER_VERTEX_COLOUR);
 
-        if (vcolMode == ShaderLayer::VERTEX_COLOUR_INVERSE_MULTIPLY)
+        if (vcolMode == IShaderLayer::VERTEX_COLOUR_INVERSE_MULTIPLY)
         {
             // Vertex colours are inverted
             dbsPass.setColourInverted(true);
@@ -379,52 +398,53 @@ void OpenGLShader::constructLightingPassesFromMaterial()
     // least one DBS layer then reach the end of the layers.
 
     DBSTriplet triplet;
-    const ShaderLayerVector& allLayers = _material->getAllLayers();
+    const IShaderLayerVector allLayers = _material->getAllLayers();
 
-    for (ShaderLayerVector::const_iterator i = allLayers.begin();
-         i != allLayers.end();
-         ++i)
+    for (const auto& layer : allLayers)
     {
-		// Make sure we had at least one evaluation call to fill the material registers
-		(*i)->evaluateExpressions(0);
+        // Skip programmatically disabled layers
+        if (!layer->isEnabled()) continue;
 
-        switch ((*i)->getType())
+		// Make sure we had at least one evaluation call to fill the material registers
+		layer->evaluateExpressions(0);
+
+        switch (layer->getType())
         {
-        case ShaderLayer::DIFFUSE:
+        case IShaderLayer::DIFFUSE:
             if (triplet.diffuse)
             {
                 appendInteractionLayer(triplet);
                 triplet.reset();
             }
-            triplet.diffuse = *i;
+            triplet.diffuse = layer;
             break;
 
-        case ShaderLayer::BUMP:
+        case IShaderLayer::BUMP:
             if (triplet.bump)
             {
                 appendInteractionLayer(triplet);
                 triplet.reset();
             }
-            triplet.bump = *i;
+            triplet.bump = layer;
             break;
 
-        case ShaderLayer::SPECULAR:
+        case IShaderLayer::SPECULAR:
             if (triplet.specular)
             {
                 appendInteractionLayer(triplet);
                 triplet.reset();
             }
-            triplet.specular = *i;
+            triplet.specular = layer;
             break;
 
-        case ShaderLayer::BLEND:
+        case IShaderLayer::BLEND:
             if (triplet.specular || triplet.bump || triplet.diffuse)
             {
                 appendInteractionLayer(triplet);
                 triplet.reset();
             }
 
-            appendBlendLayer(*i);
+            appendBlendLayer(layer);
         }
     }
 
@@ -440,15 +460,15 @@ void OpenGLShader::determineBlendModeForEditorPass(OpenGLState& pass)
     bool hasDiffuseLayer = false;
 
     // Determine alphatest from first diffuse layer
-    const ShaderLayerVector& allLayers = _material->getAllLayers();
+    const IShaderLayerVector allLayers = _material->getAllLayers();
 
-    for (ShaderLayerVector::const_iterator i = allLayers.begin();
+    for (IShaderLayerVector::const_iterator i = allLayers.begin();
          i != allLayers.end();
          ++i)
     {
-        const ShaderLayerPtr& layer = *i;
+        const IShaderLayer::Ptr& layer = *i;
 
-        if (layer->getType() == ShaderLayer::DIFFUSE)
+        if (layer->getType() == IShaderLayer::DIFFUSE)
         {
             hasDiffuseLayer = true;
 
@@ -522,14 +542,17 @@ void OpenGLShader::constructEditorPreviewPassFromMaterial()
 }
 
 // Append a blend (non-interaction) layer
-void OpenGLShader::appendBlendLayer(const ShaderLayerPtr& layer)
+void OpenGLShader::appendBlendLayer(const IShaderLayer::Ptr& layer)
 {
     TexturePtr layerTex = layer->getTexture();
 
+    if (!layerTex) return;
+
     OpenGLState& state = appendDefaultPass();
     state.setRenderFlag(RENDER_FILL);
     state.setRenderFlag(RENDER_BLEND);
     state.setRenderFlag(RENDER_DEPTHTEST);
+    state.setDepthFunc(GL_LEQUAL);
 
 	// Remember the stage for later evaluation of shader expressions
 	state.stage0 = layer;
@@ -551,7 +574,7 @@ void OpenGLShader::appendBlendLayer(const ShaderLayerPtr& layer)
 
     // Set texture dimensionality (cube map or 2D)
     state.cubeMapMode = layer->getCubeMapMode();
-    if (state.cubeMapMode == ShaderLayer::CUBE_MAP_CAMERA)
+    if (state.cubeMapMode == IShaderLayer::CUBE_MAP_CAMERA)
     {
         state.setRenderFlag(RENDER_TEXTURE_CUBEMAP);
     }
@@ -598,12 +621,15 @@ void OpenGLShader::appendBlendLayer(const ShaderLayerPtr& layer)
 }
 
 // Construct a normal shader
-void OpenGLShader::constructNormalShader(const std::string& name)
+void OpenGLShader::constructNormalShader()
 {
     // Obtain the Material
-    _material = GlobalMaterialManager().getMaterialForName(name);
+    _material = GlobalMaterialManager().getMaterial(_name);
     assert(_material);
 
+    _materialChanged = _material->sig_materialChanged().connect(
+        sigc::mem_fun(this, &OpenGLShader::onMaterialChanged));
+
     // Determine whether we can render this shader in lighting/bump-map mode,
     // and construct the appropriate shader passes
     if (canUseLightingMode())
@@ -619,7 +645,7 @@ void OpenGLShader::constructNormalShader(const std::string& name)
 }
 
 // Main shader construction entry point
-void OpenGLShader::construct(const std::string& name)
+void OpenGLShader::construct()
 {
 	// Retrieve the highlight colour from the colourschemes (once)
 	const static Colour4 highLightColour(
@@ -628,15 +654,15 @@ void OpenGLShader::construct(const std::string& name)
 
     // Check the first character of the name to see if this is a special built-in
     // shader
-    switch (name[0])
+    switch (_name[0])
     {
         case '(': // fill shader
         {
             OpenGLState& state = appendDefaultPass();
-			state.setName(name);
+			state.setName(_name);
 
             Colour4 colour;
-            sscanf(name.c_str(), "(%lf %lf %lf)", &colour[0], &colour[1], &colour[2]);
+            sscanf(_name.c_str(), "(%f %f %f)", &colour[0], &colour[1], &colour[2]);
             colour[3] = 1.0f;
             state.setColour(colour);
 
@@ -652,10 +678,10 @@ void OpenGLShader::construct(const std::string& name)
         case '[':
         {
             OpenGLState& state = appendDefaultPass();
-			state.setName(name);
+			state.setName(_name);
 
             Colour4 colour;
-            sscanf(name.c_str(), "[%lf %lf %lf]", &colour[0], &colour[1], &colour[2]);
+            sscanf(_name.c_str(), "[%f %f %f]", &colour[0], &colour[1], &colour[2]);
             colour[3] = 0.5f;
             state.setColour(colour);
 
@@ -672,10 +698,10 @@ void OpenGLShader::construct(const std::string& name)
         case '<': // wireframe shader
         {
             OpenGLState& state = appendDefaultPass();
-			state.setName(name);
+			state.setName(_name);
 
             Colour4 colour;
-            sscanf(name.c_str(), "<%lf %lf %lf>", &colour[0], &colour[1], &colour[2]);
+            sscanf(_name.c_str(), "<%f %f %f>", &colour[0], &colour[1], &colour[2]);
             colour[3] = 1;
             state.setColour(colour);
 
@@ -690,9 +716,9 @@ void OpenGLShader::construct(const std::string& name)
         case '$':
         {
             OpenGLState& state = appendDefaultPass();
-			state.setName(name);
+			state.setName(_name);
 
-            if (name == "$POINT")
+            if (_name == "$POINT")
             {
               state.setRenderFlag(RENDER_POINT_COLOUR);
               state.setRenderFlag(RENDER_DEPTHWRITE);
@@ -700,7 +726,7 @@ void OpenGLShader::construct(const std::string& name)
               state.setSortPosition(OpenGLState::SORT_POINT_FIRST);
               state.m_pointsize = 4;
             }
-            else if (name == "$SELPOINT")
+            else if (_name == "$SELPOINT")
             {
               state.setRenderFlag(RENDER_POINT_COLOUR);
               state.setRenderFlag(RENDER_DEPTHWRITE);
@@ -708,7 +734,7 @@ void OpenGLShader::construct(const std::string& name)
               state.setSortPosition(OpenGLState::SORT_POINT_LAST);
               state.m_pointsize = 4;
             }
-            else if (name == "$BIGPOINT")
+            else if (_name == "$BIGPOINT")
             {
               state.setRenderFlag(RENDER_POINT_COLOUR);
               state.setRenderFlag(RENDER_DEPTHWRITE);
@@ -716,7 +742,7 @@ void OpenGLShader::construct(const std::string& name)
               state.setSortPosition(OpenGLState::SORT_POINT_FIRST);
               state.m_pointsize = 6;
             }
-            else if (name == "$PIVOT")
+            else if (_name == "$PIVOT")
             {
               state.setRenderFlags(RENDER_DEPTHTEST | RENDER_DEPTHWRITE);
               state.setSortPosition(OpenGLState::SORT_GUI0);
@@ -724,24 +750,24 @@ void OpenGLShader::construct(const std::string& name)
               state.setDepthFunc(GL_LEQUAL);
 
               OpenGLState& hiddenLine = appendDefaultPass();
-			  hiddenLine.setName(name + "_Hidden");
+			  hiddenLine.setName(_name + "_Hidden");
               hiddenLine.setRenderFlags(RENDER_DEPTHTEST | RENDER_LINESTIPPLE);
               hiddenLine.setSortPosition(OpenGLState::SORT_GUI0);
               hiddenLine.m_linewidth = 2;
               hiddenLine.setDepthFunc(GL_GREATER);
             }
-            else if (name == "$LATTICE")
+            else if (_name == "$LATTICE")
             {
               state.setColour(1, 0.5, 0, 1);
               state.setRenderFlag(RENDER_DEPTHWRITE);
               state.setSortPosition(OpenGLState::SORT_POINT_FIRST);
             }
-            else if (name == "$WIREFRAME")
+            else if (_name == "$WIREFRAME")
             {
               state.setRenderFlags(RENDER_DEPTHTEST | RENDER_DEPTHWRITE);
               state.setSortPosition(OpenGLState::SORT_FULLBRIGHT);
             }
-            else if (name == "$CAM_HIGHLIGHT")
+            else if (_name == "$CAM_HIGHLIGHT")
             {
 				// This is the shader drawing a coloured overlay
 				// over faces/polys. Its colour is configurable,
@@ -756,7 +782,7 @@ void OpenGLShader::construct(const std::string& name)
 				state.polygonOffset = 0.5f;
 				state.setDepthFunc(GL_LEQUAL);
             }
-            else if (name == "$CAM_OVERLAY")
+            else if (_name == "$CAM_OVERLAY")
             {
 				// This is the shader drawing a solid line to outline
 				// a selected item. The first pass has its depth test
@@ -777,7 +803,54 @@ void OpenGLShader::construct(const std::string& name)
 				hiddenLine.setDepthFunc(GL_GREATER);
 				hiddenLine.m_linestipple_factor = 2;
             }
-            else if (name == "$XY_OVERLAY")
+            else if (string::starts_with(_name, "$MERGE_ACTION_"))
+            {
+                Colour4 colour;
+                auto sortPosition = OpenGLState::SORT_OVERLAY_FIRST;
+                auto lineSortPosition = OpenGLState::SORT_OVERLAY_LAST;
+
+                if (string::ends_with(_name, "_ADD"))
+                {
+                    colour = Colour4(0, 0.9f, 0, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_THIRD; // render additions over removals
+                }
+                else if (string::ends_with(_name, "_REMOVE"))
+                {
+                    colour = Colour4(0.6f, 0.1f, 0, 0.5f);
+                    lineSortPosition = OpenGLState::SORT_OVERLAY_ONE_BEFORE_LAST;
+                }
+                else if (string::ends_with(_name, "_CHANGE"))
+                {
+                    colour = Colour4(0, 0.4f, 0.9f, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_SECOND;
+                }
+                else if (string::ends_with(_name, "_CONFLICT"))
+                {
+                    colour = Colour4(0.9f, 0.5f, 0.0f, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_ONE_BEFORE_LAST;
+                }
+
+                // This is the shader drawing a coloured overlay
+                // over faces/polys. Its colour is configurable,
+                // and it has depth test activated.
+                state.setRenderFlag(RENDER_FILL);
+                state.setRenderFlag(RENDER_DEPTHTEST);
+                state.setRenderFlag(RENDER_CULLFACE);
+                state.setRenderFlag(RENDER_BLEND);
+
+                state.setColour(colour);
+                state.setSortPosition(sortPosition);
+                state.polygonOffset = 0.5f;
+                state.setDepthFunc(GL_LEQUAL);
+
+                // This is the outline pass
+                auto& linesOverlay = appendDefaultPass();
+                colour[3] = 0.78f;
+                linesOverlay.setColour(colour);
+                linesOverlay.setRenderFlags(RENDER_OFFSETLINE | RENDER_DEPTHTEST | RENDER_BLEND);
+                linesOverlay.setSortPosition(lineSortPosition);
+            }
+            else if (_name == "$XY_OVERLAY")
             {
               Vector3 colorSelBrushes = GlobalColourSchemeManager().getColour("selected_brush");
               state.setColour(static_cast<float>(colorSelBrushes[0]),
@@ -785,11 +858,11 @@ void OpenGLShader::construct(const std::string& name)
                               static_cast<float>(colorSelBrushes[2]),
                               static_cast<float>(1));
               state.setRenderFlag(RENDER_LINESTIPPLE);
-              state.setSortPosition(OpenGLState::SORT_OVERLAY_FIRST);
+              state.setSortPosition(OpenGLState::SORT_HIGHLIGHT);
               state.m_linewidth = 2;
               state.m_linestipple_factor = 3;
             }
-			else if (name == "$XY_OVERLAY_GROUP")
+			else if (_name == "$XY_OVERLAY_GROUP")
 			{
 				Vector3 colorSelBrushes = GlobalColourSchemeManager().getColour("selected_group_items");
                 state.setColour(static_cast<float>(colorSelBrushes[0]),
@@ -797,33 +870,82 @@ void OpenGLShader::construct(const std::string& name)
                     static_cast<float>(colorSelBrushes[2]),
                     static_cast<float>(1));
 				state.setRenderFlag(RENDER_LINESTIPPLE);
-				state.setSortPosition(OpenGLState::SORT_OVERLAY_FIRST);
+				state.setSortPosition(OpenGLState::SORT_HIGHLIGHT);
 				state.m_linewidth = 2;
 				state.m_linestipple_factor = 3;
 			}
-            else if (name == "$DEBUG_CLIPPED")
+            else if (string::starts_with(_name, "$XY_MERGE_ACTION_"))
+            {
+                Colour4 colour;
+                auto sortPosition = OpenGLState::SORT_OVERLAY_FIRST;
+                auto lineSortPosition = OpenGLState::SORT_OVERLAY_LAST;
+
+                if (string::ends_with(_name, "_ADD"))
+                {
+                    colour = Colour4(0, 0.5f, 0, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_THIRD; // render additions over removals
+                }
+                else if (string::ends_with(_name, "_REMOVE"))
+                {
+                    colour = Colour4(0.6f, 0.1f, 0, 0.5f);
+                    lineSortPosition = OpenGLState::SORT_OVERLAY_ONE_BEFORE_LAST;
+                }
+                else if (string::ends_with(_name, "_CHANGE"))
+                {
+                    colour = Colour4(0, 0.4f, 0.9f, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_SECOND;
+                }
+                else if (string::ends_with(_name, "_CONFLICT"))
+                {
+                    colour = Colour4(0.9f, 0.5f, 0.0f, 0.5f);
+                    sortPosition = OpenGLState::SORT_OVERLAY_ONE_BEFORE_LAST;
+                }
+
+                state.setColour(colour);
+                state.setSortPosition(OpenGLState::SORT_OVERLAY_FIRST);
+                state.m_linewidth = 2;
+            }
+            else if (_name == "$XY_INACTIVE_NODE")
+            {
+                Colour4 colour(0, 0, 0, 0.05f);
+                state.setColour(static_cast<float>(colour[0]),
+                    static_cast<float>(colour[1]),
+                    static_cast<float>(colour[2]),
+                    static_cast<float>(colour[3]));
+
+                state.m_blend_src = GL_SRC_ALPHA;
+                state.m_blend_dst = GL_ONE_MINUS_SRC_ALPHA;
+
+                state.setRenderFlags(RENDER_DEPTHTEST | RENDER_DEPTHWRITE | RENDER_BLEND);
+                state.setSortPosition(OpenGLState::SORT_FULLBRIGHT);
+                state.setDepthFunc(GL_LESS);
+
+                state.m_linewidth = 1;
+                state.m_pointsize = 1;
+            }
+            else if (_name == "$DEBUG_CLIPPED")
             {
               state.setRenderFlag(RENDER_DEPTHWRITE);
               state.setSortPosition(OpenGLState::SORT_LAST);
             }
-            else if (name == "$POINTFILE")
+            else if (_name == "$POINTFILE")
             {
               state.setColour(1, 0, 0, 1);
               state.setRenderFlags(RENDER_DEPTHTEST | RENDER_DEPTHWRITE);
               state.setSortPosition(OpenGLState::SORT_FULLBRIGHT);
               state.m_linewidth = 4;
             }
-            else if (name == "$WIRE_OVERLAY")
+            else if (_name == "$WIRE_OVERLAY")
             {
               state.setRenderFlags(RENDER_DEPTHWRITE
                                  | RENDER_DEPTHTEST
-                                 | RENDER_OVERRIDE 
+                                 | RENDER_OVERRIDE
 								 | RENDER_VERTEX_COLOUR);
               state.setSortPosition(OpenGLState::SORT_GUI1);
               state.setDepthFunc(GL_LEQUAL);
 
               OpenGLState& hiddenLine = appendDefaultPass();
-			  hiddenLine.setName(name + "_Hidden");
+			  hiddenLine.setName(_name + "_Hidden");
               hiddenLine.setRenderFlags(RENDER_DEPTHWRITE
                                       | RENDER_DEPTHTEST
                                       | RENDER_OVERRIDE
@@ -832,7 +954,7 @@ void OpenGLShader::construct(const std::string& name)
               hiddenLine.setSortPosition(OpenGLState::SORT_GUI0);
               hiddenLine.setDepthFunc(GL_GREATER);
             }
-            else if (name == "$FLATSHADE_OVERLAY")
+            else if (_name == "$FLATSHADE_OVERLAY")
             {
               state.setRenderFlags(RENDER_CULLFACE
                                  | RENDER_LIGHTING
@@ -846,7 +968,7 @@ void OpenGLShader::construct(const std::string& name)
               state.setDepthFunc(GL_LEQUAL);
 
               OpenGLState& hiddenLine = appendDefaultPass();
-			  hiddenLine.setName(name + "_Hidden");
+			  hiddenLine.setName(_name + "_Hidden");
               hiddenLine.setRenderFlags(RENDER_CULLFACE
                                       | RENDER_LIGHTING
                                       | RENDER_SMOOTH
@@ -859,7 +981,7 @@ void OpenGLShader::construct(const std::string& name)
               hiddenLine.setSortPosition(OpenGLState::SORT_GUI0);
               hiddenLine.setDepthFunc(GL_GREATER);
             }
-            else if (name == "$CLIPPER_OVERLAY")
+            else if (_name == "$CLIPPER_OVERLAY")
             {
               state.setColour(GlobalColourSchemeManager().getColour("clipper"));
               state.setRenderFlags(RENDER_CULLFACE
@@ -868,7 +990,7 @@ void OpenGLShader::construct(const std::string& name)
                                  | RENDER_POLYGONSTIPPLE);
               state.setSortPosition(OpenGLState::SORT_OVERLAY_FIRST);
             }
-            else if (name == "$AAS_AREA")
+            else if (_name == "$AAS_AREA")
             {
 				state.setColour(1, 1, 1, 1);
 				state.setRenderFlags(RENDER_DEPTHWRITE
@@ -896,11 +1018,22 @@ void OpenGLShader::construct(const std::string& name)
         default:
         {
             // This is not a hard-coded shader, construct from the shader system
-            constructNormalShader(name);
+            constructNormalShader();
         }
-
     } // switch (name[0])
 }
 
+void OpenGLShader::onMaterialChanged()
+{
+    // It's possible that the name of the material got changed, update it
+    if (_material && _material->getName() != _name)
+    {
+        _name = _material->getName();
+    }
+
+    unrealise();
+    realise();
+}
+
 }
 
