@@ -11,15 +11,14 @@
 #include "debugging/render.h"
 #include "debugging/gl.h"
 
-namespace render
-{
+#include "glprogram/GLSLDepthFillAlphaProgram.h"
 
-namespace
+namespace render
 {
 
 // Bind the given texture to the texture unit, if it is different from the
 // current state, then set the current state to the new texture.
-inline void setTextureState(GLint& current,
+void OpenGLShaderPass::setTextureState(GLint& current,
                             const GLint& texture,
                             GLenum textureUnit,
                             GLenum textureMode)
@@ -35,7 +34,7 @@ inline void setTextureState(GLint& current,
 }
 
 // Same as setTextureState() above without texture unit parameter
-inline void setTextureState(GLint& current,
+void OpenGLShaderPass::setTextureState(GLint& current,
                             const GLint& texture,
                             GLenum textureMode)
 {
@@ -47,6 +46,9 @@ inline void setTextureState(GLint& current,
     }
 }
 
+namespace
+{
+
 // Utility function to toggle an OpenGL state flag
 inline void setState(unsigned int state,
                      unsigned int delta,
@@ -65,7 +67,7 @@ inline void setState(unsigned int state,
     }
 }
 
-inline void evaluateStage(const ShaderLayerPtr& stage, std::size_t time, const IRenderEntity* entity)
+inline void evaluateStage(const IShaderLayer::Ptr& stage, std::size_t time, const IRenderEntity* entity)
 {
     if (stage)
     {
@@ -147,7 +149,7 @@ void OpenGLShaderPass::disableRenderBlend()
     debug::assertNoGlErrors();
 }
 
-void OpenGLShaderPass::setupTextureMatrix(GLenum textureUnit, const ShaderLayerPtr& stage)
+void OpenGLShaderPass::setupTextureMatrix(GLenum textureUnit, const IShaderLayer::Ptr& stage)
 {
     // Set the texture matrix for the given unit
     glActiveTexture(textureUnit);
@@ -155,60 +157,7 @@ void OpenGLShaderPass::setupTextureMatrix(GLenum textureUnit, const ShaderLayerP
 
     if (stage)
     {
-        static const Matrix4 transMinusHalf = Matrix4::getTranslation(Vector3(-0.5f, -0.5f, 0));
-        static const Matrix4 transPlusHalf = Matrix4::getTranslation(Vector3(+0.5f, +0.5f, 0));
-
-        Matrix4 tex = Matrix4::getIdentity();
-
-        Vector2 scale = stage->getScale();
-
-        if (stage->getStageFlags() & ShaderLayer::FLAG_CENTERSCALE)
-        {
-            // Center scale, apply translation by -0.5 first, then scale, then translate back
-            tex.multiplyBy(transMinusHalf);
-            tex.multiplyBy(Matrix4::getScale(Vector3(scale.x(), scale.y(), 1)));
-            tex.multiplyBy(transPlusHalf);
-        }
-        else
-        {
-            // Regular scale, apply translation and scale
-            tex.multiplyBy(Matrix4::getScale(Vector3(scale.x(), scale.y(), 1)));
-        }
-
-        Vector2 shear = stage->getShear();
-
-        if (shear.x() != 0 || shear.y() != 0)
-        {
-            Matrix4 shearMatrix = Matrix4::byColumns(
-                1, shear.y(), 0, 0,
-                shear.x(), 1, 0, 0,
-                0, 0, 1, 0,
-                0, 0, 0, 1
-            );
-
-            tex.multiplyBy(transMinusHalf);
-            tex.multiplyBy(shearMatrix);
-            tex.multiplyBy(transPlusHalf);
-        }
-
-        // Rotation
-        float rotate = stage->getRotation();
-
-        if (rotate != 0)
-        {
-            float angle = rotate * 2 * static_cast<float>(c_pi);
-
-            Matrix4 rot = Matrix4::getRotationAboutZ(angle);
-
-            tex.multiplyBy(transMinusHalf);
-            tex.multiplyBy(rot);
-            tex.multiplyBy(transPlusHalf);
-        }
-
-        // Apply translation as last step
-        Vector2 translation = stage->getTranslation();
-        tex.multiplyBy(Matrix4::getTranslation(Vector3(translation.x(), translation.y(), 0)));
-
+        auto tex = stage->getTextureTransform();
         glLoadMatrixd(tex);
     }
     else
@@ -338,24 +287,13 @@ void OpenGLShaderPass::applyState(OpenGLState& current,
     const unsigned changingBitsMask = requiredState ^ current.getRenderFlags();
 
     // Set the GLProgram if required
-    GLProgram* program = (requiredState & RENDER_PROGRAM) != 0
-                          ? _glState.glProgram
-                          : 0;
-
-    if (program != current.glProgram)
+    if (requiredState & RENDER_PROGRAM)
     {
-        if (current.glProgram != 0)
-        {
-            current.glProgram->disable();
-            glColor4dv(current.getColour());
-        }
-
-        current.glProgram = program;
-
-        if (current.glProgram != 0)
-        {
-            current.glProgram->enable();
-        }
+        activateShaderProgram(current);
+    }
+    else
+    {
+        deactivateShaderProgram(current);
     }
 
     // State changes. Only perform these if changingBitsMask > 0, since if there are
@@ -472,7 +410,7 @@ void OpenGLShaderPass::applyState(OpenGLState& current,
     } // end of changingBitsMask-dependent changes
 
     // Set depth function
-    if (requiredState & RENDER_DEPTHTEST 
+    if (requiredState & RENDER_DEPTHTEST
         && _glState.getDepthFunc() != current.getDepthFunc())
     {
         glDepthFunc(_glState.getDepthFunc());
@@ -530,7 +468,7 @@ void OpenGLShaderPass::applyState(OpenGLState& current,
     {
         _glState.setColour(_glState.stage0->getColour());
     }
-    glColor4dv(_glState.getColour());
+    glColor4fv(_glState.getColour());
     current.setColour(_glState.getColour());
     debug::assertNoGlErrors();
 
@@ -567,6 +505,34 @@ void OpenGLShaderPass::applyState(OpenGLState& current,
   debug::assertNoGlErrors();
 }
 
+void OpenGLShaderPass::activateShaderProgram(OpenGLState& current)
+{
+    if (current.glProgram == _glState.glProgram)
+    {
+        // nothing to do
+        return;
+    }
+
+    // Deactivate the previous program first
+    deactivateShaderProgram(current);
+
+    if (_glState.glProgram != nullptr)
+    {
+        current.glProgram = _glState.glProgram;
+        current.glProgram->enable();
+    }
+}
+
+void OpenGLShaderPass::deactivateShaderProgram(OpenGLState& current)
+{
+    if (current.glProgram == nullptr) return;
+
+    current.glProgram->disable();
+    glColor4fv(current.getColour());
+
+    current.glProgram = nullptr;
+}
+
 // Add a Renderable to this bucket
 void OpenGLShaderPass::addRenderable(const OpenGLRenderable& renderable,
                                      const Matrix4& modelview,
@@ -649,11 +615,13 @@ void OpenGLShaderPass::setUpLightingCalculation(OpenGLState& current,
                                                 const Matrix4& objTransform,
                                                 std::size_t time)
 {
-    assert(light);
-
     // Get the light shader and examine its first (and only valid) layer
-    const MaterialPtr& lightShader = light->getShader()->getMaterial();
-    ShaderLayer* layer = lightShader ? lightShader->firstLayer() : nullptr;
+    assert(light);
+    ShaderPtr shader = light->getShader();
+    assert(shader);
+
+    const MaterialPtr& lightMat = shader->getMaterial();
+    IShaderLayer* layer = lightMat ? lightMat->firstLayer() : nullptr;
     if (!layer) return;
 
     // Calculate viewer location in object space
@@ -665,7 +633,7 @@ void OpenGLShaderPass::setUpLightingCalculation(OpenGLState& current,
 
     // Get the XY and Z falloff texture numbers.
     GLuint attenuation_xy = layer->getTexture()->getGLTexNum();
-    GLuint attenuation_z = lightShader->lightFalloffImage()->getGLTexNum();
+    GLuint attenuation_z = lightMat->lightFalloffImage()->getGLTexNum();
 
     // Bind the falloff textures
     assert(current.testRenderFlag(RENDER_TEXTURE_2D));
@@ -689,7 +657,7 @@ void OpenGLShaderPass::setUpLightingCalculation(OpenGLState& current,
     GLProgram::Params parms(
         light->getLightOrigin(), layer->getColour(), world2light
     );
-    parms.ambientFactor = lightShader->isAmbientLight() ? 1.0f : 0.0f;
+    parms.isAmbientLight = lightMat->isAmbientLight();
     parms.invertVertexColour = _glState.isColourInverted();
 
     assert(current.glProgram);
@@ -702,8 +670,8 @@ void OpenGLShaderPass::renderAllContained(const Renderables& renderables,
                                           const Vector3& viewer,
                                           std::size_t time)
 {
-    // Keep a pointer to the last transform matrix and render entity used
-    const Matrix4* transform = 0;
+    // Keep a pointer to the last transform matrix used
+    const Matrix4* transform = nullptr;
 
     glPushMatrix();
 
@@ -712,10 +680,9 @@ void OpenGLShaderPass::renderAllContained(const Renderables& renderables,
     {
         // If the current iteration's transform matrix was different from the
         // last, apply it and store for the next iteration
-        if (transform == NULL ||
-            (transform != r.transform && !transform->isAffineEqual(*r.transform)))
+        if (!transform || !transform->isAffineEqual(r.transform))
         {
-            transform = r.transform;
+            transform = &r.transform;
             glPopMatrix();
             glPushMatrix();
             glMultMatrixd(*transform);
