@@ -1,15 +1,15 @@
 #pragma once
 
 #include "GLProgramAttributes.h"
-#include "iglprogram.h"
-#include "igl.h"
+#include "GLSLProgramBase.h"
 
 namespace render
 {
 
-class GLSLBumpProgram
-: public GLProgram
+class GLSLBumpProgram : 
+    public GLSLProgramBase
 {
+private:
 	// The value all lights should be scaled by, obtained from the game description
 	float _lightScale;
 
@@ -18,20 +18,16 @@ class GLSLBumpProgram
     int _locLightColour;
     int _locViewOrigin;
     int _locLightScale;
-    int _locAmbientFactor;
-    int _locVColScale;
-    int _locVColOffset;
-
-    // Program object identifier
-    GLuint _programObj;
+    int _locAmbientLight;
+    int _locInvertVCol;
 
 public:
 
     /* GLProgram implementation */
-    void create();
-    void destroy();
-    void enable();
-    void disable();
+    void create() override;
+    void enable() override;
+    void disable() override;
+
     void applyRenderParams(const Vector3& viewer,
                            const Matrix4& localToWorld,
                            const Params&);
