@@ -12,7 +12,7 @@
 #include "math/Matrix4.h"
 #include "SelectedNodeList.h"
 
-#include "ManipulationPivot.h"
+#include "SceneManipulationPivot.h"
 
 namespace selection
 {
@@ -21,7 +21,8 @@ class RadiantSelectionSystem :
 	public SelectionSystem,
 	public Renderable
 {
-	ManipulationPivot _pivot;
+private:
+	SceneManipulationPivot _pivot;
 
 	typedef std::set<Observer*> ObserverList;
 	ObserverList _observers;
@@ -44,16 +45,16 @@ private:
 
     sigc::signal<void, const ISelectable&> _sigSelectionChanged;
 
-	typedef std::map<std::size_t, ManipulatorPtr> Manipulators;
+	typedef std::map<std::size_t, ISceneManipulator::Ptr> Manipulators;
 	Manipulators _manipulators;
 
 	// The currently active manipulator
-	ManipulatorPtr _activeManipulator;
-	Manipulator::Type _defaultManipulatorType;
+    ISceneManipulator::Ptr _activeManipulator;
+    IManipulator::Type _defaultManipulatorType;
 
 	// state
 	EMode _mode;
-	EComponentMode _componentMode;
+    ComponentSelectionMode _componentMode;
 
 	std::size_t _countPrimitive;
 	std::size_t _countComponent;
@@ -68,9 +69,9 @@ private:
 
 	bool nothingSelected() const;
 
-	sigc::signal<void, selection::Manipulator::Type> _sigActiveManipulatorChanged;
+	sigc::signal<void, selection::IManipulator::Type> _sigActiveManipulatorChanged;
 	sigc::signal<void, EMode> _sigSelectionModeChanged;
-	sigc::signal<void, EComponentMode> _sigComponentModeChanged;
+	sigc::signal<void, ComponentSelectionMode> _sigComponentModeChanged;
 
 public:
 
@@ -94,21 +95,21 @@ public:
 	void SetMode(EMode mode) override;
 	EMode Mode() const override;
 
-	void SetComponentMode(EComponentMode mode) override;
-	EComponentMode ComponentMode() const override;
+	void SetComponentMode(ComponentSelectionMode mode) override;
+    ComponentSelectionMode ComponentMode() const override;
 
 	sigc::signal<void, EMode>& signal_selectionModeChanged() override;
-	sigc::signal<void, EComponentMode>& signal_componentModeChanged() override;
+	sigc::signal<void, ComponentSelectionMode>& signal_componentModeChanged() override;
 
 	// Returns the ID of the registered manipulator
-	std::size_t registerManipulator(const ManipulatorPtr& manipulator) override;
-	void unregisterManipulator(const ManipulatorPtr& manipulator) override;
+	std::size_t registerManipulator(const ISceneManipulator::Ptr& manipulator) override;
+	void unregisterManipulator(const ISceneManipulator::Ptr& manipulator) override;
 
-	Manipulator::Type getActiveManipulatorType() override;
-	const ManipulatorPtr& getActiveManipulator() override;
+    IManipulator::Type getActiveManipulatorType() override;
+	const ISceneManipulator::Ptr& getActiveManipulator() override;
 	void setActiveManipulator(std::size_t manipulatorId) override;
-	void setActiveManipulator(Manipulator::Type manipulatorType) override;
-	sigc::signal<void, selection::Manipulator::Type>& signal_activeManipulatorChanged() override;
+	void setActiveManipulator(IManipulator::Type manipulatorType) override;
+	sigc::signal<void, selection::IManipulator::Type>& signal_activeManipulatorChanged() override;
 
 	std::size_t countSelected() const override;
 	std::size_t countSelectedComponents() const override;
@@ -176,19 +177,19 @@ public:
 protected:
 	// Traverses the scene and adds any selectable nodes matching the given SelectionTest to the "targetList".
 	void testSelectScene(SelectablesList& targetList, SelectionTest& test,
-						 const VolumeTest& view, SelectionSystem::EMode mode,
-						 SelectionSystem::EComponentMode componentMode);
+        const VolumeTest& view, SelectionSystem::EMode mode,
+        ComponentSelectionMode componentMode);
 
 private:
 	bool higherEntitySelectionPriority() const;
 
 	void notifyObservers(const scene::INodePtr& node, bool isComponent);
 
-	std::size_t getManipulatorIdForType(Manipulator::Type type);
+	std::size_t getManipulatorIdForType(IManipulator::Type type);
 
 	// Command targets used to connect to the event system
 	void toggleManipulatorModeCmd(const cmd::ArgumentList& args);
-	void toggleManipulatorMode(Manipulator::Type type);
+	void toggleManipulatorMode(IManipulator::Type type);
 	void toggleManipulatorModeById(std::size_t manipId);
 
 	void activateDefaultMode();
@@ -197,7 +198,7 @@ private:
 	void toggleGroupPartMode(const cmd::ArgumentList& args);
 	void toggleMergeActionMode(const cmd::ArgumentList& args);
 
-	void toggleComponentMode(EComponentMode mode);
+	void toggleComponentMode(ComponentSelectionMode mode);
 	void toggleComponentModeCmd(const cmd::ArgumentList& args);
 
 	void onManipulatorModeChanged();
