@@ -44,13 +44,13 @@ void rotateSelected(const Quaternion& rotation)
 	if (GlobalSelectionSystem().Mode() == SelectionSystem::eComponent)
 	{
 		GlobalSelectionSystem().foreachSelectedComponent(
-			RotateComponentSelected(rotation, GlobalSelectionSystem().getPivot2World().tCol().getVector3()));
+			RotateComponentSelected(rotation, GlobalSelectionSystem().getPivot2World().translation()));
 	}
 	else
 	{
 		// Cycle through the selections and rotate them
 		GlobalSelectionSystem().foreachSelected(RotateSelected(rotation,
-			GlobalSelectionSystem().getPivot2World().tCol().getVector3()));
+			GlobalSelectionSystem().getPivot2World().translation()));
 	}
 
 	// Update the views
@@ -95,12 +95,12 @@ void scaleSelected(const Vector3& scaleXYZ)
 		if (GlobalSelectionSystem().Mode() == SelectionSystem::eComponent)
 		{
 			GlobalSelectionSystem().foreachSelectedComponent(ScaleComponentSelected(scaleXYZ,
-				GlobalSelectionSystem().getPivot2World().tCol().getVector3()));
+				GlobalSelectionSystem().getPivot2World().translation()));
 		}
 		else
 		{
 			GlobalSelectionSystem().foreachSelected(ScaleSelected(scaleXYZ,
-				GlobalSelectionSystem().getPivot2World().tCol().getVector3()));
+				GlobalSelectionSystem().getPivot2World().translation()));
 		}
 
 		// Update the scene views
@@ -383,14 +383,14 @@ void nudgeSelected(ENudgeDirection direction, float amount, EViewType viewtype)
 	//Vector3 view_direction(-axes.z);
 	Vector3 nudge(AxisBase_axisForDirection(axes, direction) * amount);
 
-	if (GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Translate ||
-        GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Drag ||
-        GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Clip)
+	if (GlobalSelectionSystem().getActiveManipulatorType() == selection::IManipulator::Translate ||
+        GlobalSelectionSystem().getActiveManipulatorType() == selection::IManipulator::Drag ||
+        GlobalSelectionSystem().getActiveManipulatorType() == selection::IManipulator::Clip)
     {
         translateSelected(nudge);
 
         // In clip mode, update the clipping plane
-        if (GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Clip)
+        if (GlobalSelectionSystem().getActiveManipulatorType() == selection::IManipulator::Clip)
         {
             GlobalClipper().update();
         }
