@@ -3,6 +3,7 @@
 #include <vector>
 #include <string>
 #include <memory>
+#include "ishaders.h"
 
 namespace shaders
 {
@@ -10,7 +11,8 @@ namespace shaders
 // Syntax:
 // table <tablename> { [snap] [clamp] { <data>, <data>, ... } }
 
-class TableDefinition
+class TableDefinition :
+    public ITableDefinition
 {
 private:
 	// The block name
