@@ -4,20 +4,24 @@
 #include "iundo.h"
 #include "imap.h"
 #include "imapformat.h"
+#include "iautosaver.h"
 #include "imapresource.h"
 #include "ifilesystem.h"
 #include "iradiant.h"
 #include "iselectiongroup.h"
 #include "ilightnode.h"
 #include "icommandsystem.h"
+#include "messages/ApplicationShutdownRequest.h"
 #include "messages/FileSelectionRequest.h"
 #include "messages/FileOverwriteConfirmation.h"
 #include "messages/MapFileOperation.h"
+#include "messages/FileSaveConfirmation.h"
 #include "algorithm/Scene.h"
 #include "algorithm/XmlUtils.h"
 #include "algorithm/Primitives.h"
 #include "os/file.h"
 #include <sigc++/connection.h>
+#include "testutil/FileSelectionHelper.h"
 
 using namespace std::chrono_literals;
 
@@ -27,39 +31,6 @@ namespace test
 namespace
 {
 
-class FileSelectionHelper
-{
-private:
-    std::size_t _msgSubscription;
-    std::string _path;
-    map::MapFormatPtr _format;
-
-public:
-    FileSelectionHelper(const std::string& path, const map::MapFormatPtr& format) :
-        _path(path),
-        _format(format)
-    {
-        // Subscribe to the event asking for the target path
-        _msgSubscription = GlobalRadiantCore().getMessageBus().addListener(
-            radiant::IMessage::Type::FileSelectionRequest,
-            radiant::TypeListener<radiant::FileSelectionRequest>(
-                [this](radiant::FileSelectionRequest& msg)
-        {
-            msg.setHandled(true);
-            msg.setResult(radiant::FileSelectionRequest::Result
-            {
-                _path,
-                _format->getMapFormatName()
-            });
-        }));
-    }
-
-    ~FileSelectionHelper()
-    {
-        GlobalRadiantCore().getMessageBus().removeListener(_msgSubscription);
-    }
-};
-
 class FileOverwriteHelper
 {
 private:
@@ -95,6 +66,41 @@ public:
     }
 };
 
+class FileSaveConfirmationHelper
+{
+private:
+    std::size_t _msgSubscription;
+    radiant::FileSaveConfirmation::Action _actionToTake;
+    bool _messageReceived;
+
+public:
+    FileSaveConfirmationHelper(radiant::FileSaveConfirmation::Action actionToTake) :
+        _actionToTake(actionToTake),
+        _messageReceived(false)
+    {
+        // Subscribe to the event asking for the target path
+        _msgSubscription = GlobalRadiantCore().getMessageBus().addListener(
+            radiant::IMessage::Type::FileSaveConfirmation,
+            radiant::TypeListener<radiant::FileSaveConfirmation>(
+                [this](radiant::FileSaveConfirmation& msg)
+        {
+            _messageReceived = true;
+            msg.setAction(_actionToTake);
+            msg.setHandled(true);
+        }));
+    }
+
+    bool messageReceived() const
+    {
+        return _messageReceived;
+    }
+
+    ~FileSaveConfirmationHelper()
+    {
+        GlobalRadiantCore().getMessageBus().removeListener(_msgSubscription);
+    }
+};
+
 }
 
 class MapFileTestBase :
@@ -1218,4 +1224,321 @@ TEST_F(MapSavingTest, saveWarnsAboutOverwriteAndUserCancels)
     EXPECT_EQ(contents.str(), tempContents);
 }
 
+// #5729: Autosaver overwrites the stored filename that has been previously used for "Save Copy As"
+TEST_F(MapSavingTest, AutoSaverDoesntChangeSaveCopyAsFilename)
+{
+    std::string modRelativePath = "maps/altar.map";
+
+    GlobalCommandSystem().executeCommand("OpenMap", modRelativePath);
+    checkAltarScene();
+
+    std::string pathThatWasSentAsDefaultPath;
+
+    fs::path tempPath = _context.getTemporaryDataPath();
+    tempPath /= "altar_copy.map";
+
+    // Subscribe to the event asking for the target path
+    auto msgSubscription = GlobalRadiantCore().getMessageBus().addListener(
+        radiant::IMessage::Type::FileSelectionRequest,
+        radiant::TypeListener<radiant::FileSelectionRequest>(
+            [&](radiant::FileSelectionRequest& msg)
+    {
+        pathThatWasSentAsDefaultPath = msg.getDefaultFile();
+
+        auto format = GlobalMapFormatManager().getMapFormatForFilename(tempPath.string());
+
+        msg.setHandled(true);
+        msg.setResult(radiant::FileSelectionRequest::Result{ tempPath.string(), format->getMapFormatName() });
+    }));
+
+    EXPECT_FALSE(os::fileOrDirExists(tempPath));
+
+    // This will ask for a file name, and we respond with the "altar_copy.map"
+    GlobalCommandSystem().executeCommand("SaveMapCopyAs");
+    GlobalCommandSystem().executeCommand("SaveMapCopyAs");
+
+    // Check that the file got created and remove it again
+    EXPECT_TRUE(os::fileOrDirExists(tempPath));
+    if (fs::exists(tempPath)) fs::remove(tempPath);
+    EXPECT_FALSE(os::fileOrDirExists(tempPath));
+
+    // Now trigger an autosave
+    GlobalAutoSaver().performAutosave();
+
+    // This will (again) ask for a file name, now we check what map file name it remembered and 
+    // sent to the request handler as default file name
+    GlobalCommandSystem().executeCommand("SaveMapCopyAs");
+
+    EXPECT_TRUE(os::fileOrDirExists(tempPath));
+    if (fs::exists(tempPath)) fs::remove(tempPath);
+
+    EXPECT_EQ(pathThatWasSentAsDefaultPath, tempPath.string()) << "Autosaver overwrote the stored file name for 'Save Copy As'";
+
+    GlobalRadiantCore().getMessageBus().removeListener(msgSubscription);
+}
+
+namespace
+{
+
+void checkBehaviourWithoutUnsavedChanges(std::function<void()> action)
+{
+    std::string modRelativePath = "maps/altar.map";
+    GlobalCommandSystem().executeCommand("OpenMap", modRelativePath);
+
+    FileSaveConfirmationHelper helper(radiant::FileSaveConfirmation::Action::SaveChanges);
+
+    // The map has not been changed
+    EXPECT_FALSE(GlobalMapModule().isModified()) << "Map was marked as modified after loading";
+
+    // Performing the action will not ask for save, since it hasn't been changed
+    action();
+
+    EXPECT_FALSE(helper.messageReceived()) << "Map shouldn't have asked for save";
+    EXPECT_FALSE(GlobalMapModule().isModified()) << "New Map should be unmodified";
+}
+
+void checkBehaviourDiscardingUnsavedChanges(const std::string& testProjectPath, std::function<void()> action, bool expectUnmodifiedMapAfterAction = true)
+{
+    std::string modRelativePath = "maps/altar.map";
+    GlobalCommandSystem().executeCommand("OpenMap", modRelativePath);
+
+    fs::path mapPath = testProjectPath + modRelativePath;
+    auto sizeBefore = fs::file_size(mapPath);
+
+    // Create a brush to mark the map as modified
+    algorithm::createCubicBrush(GlobalMapModule().findOrInsertWorldspawn());
+    EXPECT_TRUE(GlobalMapModule().isModified()) << "Map was not marked as modified after brush creation";
+
+    // Discard the changes
+    FileSaveConfirmationHelper helper(radiant::FileSaveConfirmation::Action::DiscardChanges);
+
+    // Performing the action must ask for save, since the file has been changed
+    action();
+
+    EXPECT_TRUE(helper.messageReceived()) << "Map must ask for save";
+    EXPECT_EQ(fs::file_size(mapPath), sizeBefore) << "File size has changed after discarding";
+
+    // In some scenario like app shutdown the map modified flag is not cleared
+    if (expectUnmodifiedMapAfterAction)
+    {
+        EXPECT_FALSE(GlobalMapModule().isModified()) << "Map should be unmodified again";
+    }
+}
+
+void checkBehaviourSavingUnsavedChanges(const std::string& fullMapPath, std::function<void()> action)
+{
+    GlobalCommandSystem().executeCommand("OpenMap", fullMapPath);
+
+    auto sizeBefore = fs::file_size(fullMapPath);
+
+    // Create a brush to mark the map as modified
+    algorithm::createCubicBrush(GlobalMapModule().findOrInsertWorldspawn());
+    EXPECT_TRUE(GlobalMapModule().isModified()) << "Map was not marked as modified after brush creation";
+
+    // Save the changes
+    FileSaveConfirmationHelper helper(radiant::FileSaveConfirmation::Action::SaveChanges);
+
+    // Performing the action must ask for save, since the file has been changed
+    action();
+
+    EXPECT_TRUE(helper.messageReceived()) << "Map must ask for save";
+    EXPECT_NE(fs::file_size(fullMapPath), sizeBefore) << "File size must have changed after saving";
+    EXPECT_FALSE(GlobalMapModule().isModified()) << "Map should be unmodified again";
+}
+
+void checkBehaviourCancellingMapChange(const std::string& fullMapPath, std::function<void()> action)
+{
+    GlobalCommandSystem().executeCommand("OpenMap", fullMapPath);
+
+    auto sizeBefore = fs::file_size(fullMapPath);
+
+    // Create a brush to mark the map as modified
+    algorithm::createCubicBrush(GlobalMapModule().findOrInsertWorldspawn());
+    EXPECT_TRUE(GlobalMapModule().isModified()) << "Map was not marked as modified after brush creation";
+
+    // Discard the changes
+    FileSaveConfirmationHelper helper(radiant::FileSaveConfirmation::Action::Cancel);
+
+    // Creating a new map must ask for save, since the file has been changed
+    GlobalCommandSystem().executeCommand("NewMap");
+
+    // We should still have the map loaded
+    EXPECT_TRUE(GlobalMapModule().isModified()) << "Map was not marked as modified after brush creation";
+
+    EXPECT_TRUE(helper.messageReceived()) << "Map must ask for save";
+    EXPECT_EQ(fs::file_size(fullMapPath), sizeBefore) << "File size has changed after discarding";
+}
+
+void openMapFromArchive(const radiant::TestContext& context)
+{
+    auto pakPath = fs::path(context.getTestResourcePath()) / "map_loading_test.pk4";
+    std::string archiveRelativePath = "maps/altar_packed.map";
+
+    GlobalCommandSystem().executeCommand("OpenMapFromArchive", pakPath.string(), archiveRelativePath);
+}
+
+void sendShutdownRequest(bool expectDenial)
+{
+    // Send the shutdown request, the Map Module should be receiving this
+    radiant::ApplicationShutdownRequest request;
+    GlobalRadiantCore().getMessageBus().sendMessage(request);
+
+    EXPECT_EQ(expectDenial, request.isDenied()) << "Shutdown Request denial flag has unexpected value";
+}
+
+}
+
+TEST_F(MapSavingTest, NewMapWithoutUnsavedChanges)
+{
+    checkBehaviourWithoutUnsavedChanges([]()
+    {
+        // Creating a new map will not ask for save, since it hasn't been changed
+        GlobalCommandSystem().executeCommand("NewMap");
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapWithoutUnsavedChanges)
+{
+    checkBehaviourWithoutUnsavedChanges([]()
+    {
+        // Opening a new map will not ask for save, since it hasn't been changed
+        GlobalCommandSystem().executeCommand("OpenMap", cmd::Argument("maps/csg_merge.map"));
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapFromArchiveWithoutUnsavedChanges)
+{
+    checkBehaviourWithoutUnsavedChanges([&]()
+    {
+        openMapFromArchive(_context);
+    });
+}
+
+TEST_F(MapSavingTest, RadiantShutdownWithoutUnsavedChanges)
+{
+    checkBehaviourWithoutUnsavedChanges([]()
+    {
+        sendShutdownRequest(false); // no denial
+    });
+}
+
+TEST_F(MapSavingTest, NewMapDiscardingUnsavedChanges)
+{
+    checkBehaviourDiscardingUnsavedChanges(_context.getTestProjectPath(), []()
+    {
+        // Creating a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("NewMap");
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapDiscardingUnsavedChanges)
+{
+    checkBehaviourDiscardingUnsavedChanges(_context.getTestProjectPath(), []()
+    {
+        // Opening a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("OpenMap", cmd::Argument("maps/csg_merge.map"));
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapFromArchiveDiscardingUnsavedChanges)
+{
+    checkBehaviourDiscardingUnsavedChanges(_context.getTestProjectPath(), [&]()
+    {
+        openMapFromArchive(_context);
+    });
+}
+
+TEST_F(MapSavingTest, RadiantShutdownDiscardingUnsavedChanges)
+{
+    // Pass false to expectUnmodifiedMapAfterAction => discarding the map on shutdown will not clear the modified flag
+    checkBehaviourDiscardingUnsavedChanges(_context.getTestProjectPath(), []()
+    {
+        sendShutdownRequest(false); // no denial
+    }, false);
+}
+
+TEST_F(MapSavingTest, NewMapSavingChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapSavingChanges.map");
+
+    checkBehaviourSavingUnsavedChanges(mapPath.string(), []()
+    {
+        // Creating a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("NewMap");
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapSavingChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapSavingChanges.map");
+
+    checkBehaviourSavingUnsavedChanges(mapPath.string(), []()
+    {
+        // Opening a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("OpenMap", cmd::Argument("maps/csg_merge.map"));
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapFromArchiveSavingChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapSavingChanges.map");
+
+    checkBehaviourSavingUnsavedChanges(mapPath.string(), [&]()
+    {
+        openMapFromArchive(_context);
+    });
+}
+
+TEST_F(MapSavingTest, RadiantShutdownSavingChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapSavingChanges.map");
+
+    checkBehaviourSavingUnsavedChanges(mapPath.string(), []()
+    {
+        sendShutdownRequest(false); // no denial
+    });
+}
+
+TEST_F(MapSavingTest, NewMapCancelWithUnsavedChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapCancelWithUnsavedChanges.map");
+
+    checkBehaviourCancellingMapChange(mapPath.string(), []()
+    {
+        // Creating a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("NewMap");
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapCancelWithUnsavedChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapCancelWithUnsavedChanges.map");
+
+    checkBehaviourCancellingMapChange(mapPath.string(), []()
+    {
+        // Opening a new map must ask for save, since the file has been changed
+        GlobalCommandSystem().executeCommand("OpenMap", cmd::Argument("maps/csg_merge.map"));
+    });
+}
+
+TEST_F(MapSavingTest, OpenMapFromArchiveCancelWithUnsavedChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapCancelWithUnsavedChanges.map");
+
+    checkBehaviourCancellingMapChange(mapPath.string(), [&]()
+    {
+        openMapFromArchive(_context);
+    });
+}
+
+TEST_F(MapSavingTest, RadiantShutdownCancelWithUnsavedChanges)
+{
+    auto mapPath = createMapCopyInTempDataPath("altar.map", "altar_NewMapCancelWithUnsavedChanges.map");
+
+    checkBehaviourCancellingMapChange(mapPath.string(), []()
+    {
+        sendShutdownRequest(true); // request should be denied
+    });
+}
+
 }
