@@ -63,12 +63,23 @@ protected:
 		catch (module::CoreModule::FailureException & ex)
 		{
 			// Streams are not yet initialised, so log to std::err at this point
+            std::cerr << "RadiantTest initialisation failed:\n\t";
 			std::cerr << ex.what() << std::endl;
+
+            // Re-throw the exception and abort the test. There's no point in
+            // continuing if we couldn't construct the core module.
+            throw;
 		}
 	}
 
+    /// Override this to perform custom actions before the core module starts
+    virtual void preStartup() {}
+
 	void SetUp() override
 	{
+        // Invoke any custom actions needed by subclasses
+        preStartup();
+
 		// Set up the test game environment
 		setupGameFolder();
 		setupOpenGLContext();
@@ -101,16 +112,28 @@ protected:
         GlobalMapModule().createNewMap();
 	}
 
+    /// Override this to perform custom actions before the main module shuts down
+    virtual void preShutdown() {}
+
 	void TearDown() override
 	{
+        // Invoke any pre-shutdown custom code
+        preShutdown();
+
 		_coreModule->get()->getMessageBus().removeListener(_notificationListener);
 		_coreModule->get()->getMessageBus().removeListener(_gameSetupListener);
 
 		// Issue a shutdown() call to all the modules
 		module::GlobalModuleRegistry().shutdownModules();
+
+        // Invoke any post-shutdown custom code
+        postShutdown();
 	}
 
-	~RadiantTest()
+    /// Override this to perform custom actions after the main module shuts down
+    virtual void postShutdown() {}
+
+	virtual ~RadiantTest()
 	{
         _coreModule->get()->getLogWriter().detach(_testLogFile.get());
         _testLogFile->close();
