@@ -118,7 +118,7 @@ TEST_F(SelectionTest, PivotIsResetAfterCancelingOperation)
     auto worldspawn = GlobalMapModule().findOrInsertWorldspawn();
     auto brush = algorithm::findFirstBrushWithMaterial(worldspawn, "textures/numbers/1");
 
-    GlobalSelectionSystem().setActiveManipulator(selection::Manipulator::Translate);
+    GlobalSelectionSystem().setActiveManipulator(selection::IManipulator::Translate);
 
     // Select the node, the pivot should now be at the node center
     Node_setSelected(brush, true);
@@ -126,7 +126,7 @@ TEST_F(SelectionTest, PivotIsResetAfterCancelingOperation)
     Vector3 originalBrushPosition = brush->worldAABB().getOrigin();
 
     Matrix4 originalPivot = GlobalSelectionSystem().getPivot2World();
-    EXPECT_EQ(originalPivot.tCol().getVector3(), originalBrushPosition);
+    EXPECT_EQ(originalPivot.translation(), originalBrushPosition);
 
     const auto& activeManipulator = GlobalSelectionSystem().getActiveManipulator();
 
@@ -149,7 +149,7 @@ TEST_F(SelectionTest, PivotIsResetAfterCancelingOperation)
     // The brush should have been moved
     EXPECT_NE(brush->worldAABB().getOrigin(), originalBrushPosition);
     // Pivot should have been moved
-    EXPECT_NE(GlobalSelectionSystem().getPivot2World().tCol().getVector3(), originalBrushPosition);
+    EXPECT_NE(GlobalSelectionSystem().getPivot2World().translation(), originalBrushPosition);
 
     // Now cancel the operation
     GlobalSelectionSystem().onManipulationCancelled();
@@ -157,7 +157,7 @@ TEST_F(SelectionTest, PivotIsResetAfterCancelingOperation)
     // Brush should be back at its original position
     EXPECT_EQ(brush->worldAABB().getOrigin(), originalBrushPosition);
     // And as of #4846 the pivot should be back as well
-    EXPECT_EQ(GlobalSelectionSystem().getPivot2World().tCol().getVector3(), originalBrushPosition);
+    EXPECT_EQ(GlobalSelectionSystem().getPivot2World().translation(), originalBrushPosition);
 }
 
 // #5460: Workzone not recalculated after selection change if XY view "Show Size Info" setting is off
@@ -185,14 +185,14 @@ TEST_F(SelectionTest, WorkzoneIsRecalculatedAfterSelectionChange)
     auto tallBrushTest = algorithm::constructOrthoviewSelectionTest(orthoView);
 
     // Select and de-select first brush
-    GlobalSelectionSystem().selectPoint(tallBrushTest, SelectionSystem::eToggle, false);
+    GlobalSelectionSystem().selectPoint(tallBrushTest, selection::SelectionSystem::eToggle, false);
     EXPECT_TRUE(Node_isSelected(tallBrush));
 
     // Workzone should match the size of the tall brush
     EXPECT_EQ(GlobalSelectionSystem().getWorkZone().bounds, tallBounds);
 
     // De-select the tall brush
-    GlobalSelectionSystem().selectPoint(tallBrushTest, SelectionSystem::eToggle, false);
+    GlobalSelectionSystem().selectPoint(tallBrushTest, selection::SelectionSystem::eToggle, false);
     EXPECT_FALSE(Node_isSelected(tallBrush));
 
     // Workzone should still match the size of the tall brush
@@ -203,9 +203,9 @@ TEST_F(SelectionTest, WorkzoneIsRecalculatedAfterSelectionChange)
     auto smallBrushTest = algorithm::constructOrthoviewSelectionTest(orthoView);
 
     // Select and de-select second brush (no getWorkZone() call in between)
-    GlobalSelectionSystem().selectPoint(smallBrushTest, SelectionSystem::eToggle, false);
+    GlobalSelectionSystem().selectPoint(smallBrushTest, selection::SelectionSystem::eToggle, false);
     EXPECT_TRUE(Node_isSelected(smallBrush));
-    GlobalSelectionSystem().selectPoint(smallBrushTest, SelectionSystem::eToggle, false);
+    GlobalSelectionSystem().selectPoint(smallBrushTest, selection::SelectionSystem::eToggle, false);
     EXPECT_FALSE(Node_isSelected(smallBrush));
 
     // Workzone should match the size of the small brush now
@@ -229,7 +229,7 @@ protected:
         EXPECT_FALSE(Node_isSelected(node));
 
         SelectionVolume test(view);
-        GlobalSelectionSystem().selectPoint(test, SelectionSystem::eToggle, false);
+        GlobalSelectionSystem().selectPoint(test, selection::SelectionSystem::eToggle, false);
 
         EXPECT_EQ(Node_isSelected(node), expectNodeIsSelectable);
 
@@ -305,16 +305,7 @@ protected:
 
     virtual void constructView(render::View& view, const AABB& objectAABB) override
     {
-        // Position the camera top-down, similar to what an XY view is seeing
-        auto objectHeight = std::max(objectAABB.getExtents().z(), 20.0); // use a minimum height
-        Vector3 origin = objectAABB.getOrigin() + Vector3(0, 0, objectHeight * 3);
-        Vector3 angles(-90, 0, 0);
-
-        auto farClip = 32768.0f;
-        Matrix4 projection = camera::calculateProjectionMatrix(farClip / 4096.0f, farClip, 75.0f, algorithm::DeviceWidth, algorithm::DeviceHeight);
-        Matrix4 modelview = camera::calculateModelViewMatrix(origin, angles);
-
-        view.construct(projection, modelview, algorithm::DeviceWidth, algorithm::DeviceHeight);
+        algorithm::constructCameraView(view, objectAABB, Vector3(0, 0, -1), Vector3(-90, 0, 0));
     }
 };
 
